Class: Files::AgentNodeConnection
- Inherits:
-
Object
- Object
- Files::AgentNodeConnection
- Defined in:
- lib/files.com/models/agent_node_connection.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#initialize(attributes = {}, options = {}) ⇒ AgentNodeConnection
constructor
A new instance of AgentNodeConnection.
-
#last_seen_at ⇒ Object
date-time - Most recent successful observation for this connection.
-
#mode ⇒ Object
string - How the Agent process uses this proxy connection.
-
#status ⇒ Object
string - Whether this connection was observed recently and has not disconnected.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ AgentNodeConnection
Returns a new instance of AgentNodeConnection.
7 8 9 10 |
# File 'lib/files.com/models/agent_node_connection.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/agent_node_connection.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/agent_node_connection.rb', line 5 def @options end |
Instance Method Details
#last_seen_at ⇒ Object
date-time - Most recent successful observation for this connection
23 24 25 |
# File 'lib/files.com/models/agent_node_connection.rb', line 23 def last_seen_at @attributes[:last_seen_at] end |
#mode ⇒ Object
string - How the Agent process uses this proxy connection
13 14 15 |
# File 'lib/files.com/models/agent_node_connection.rb', line 13 def mode @attributes[:mode] end |
#status ⇒ Object
string - Whether this connection was observed recently and has not disconnected
18 19 20 |
# File 'lib/files.com/models/agent_node_connection.rb', line 18 def status @attributes[:status] end |