Class: Files::AgentNodeInstance
- Inherits:
-
Object
- Object
- Files::AgentNodeInstance
- Defined in:
- lib/files.com/models/agent_node_instance.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#agent_version ⇒ Object
string - Agent version reported by this process.
-
#connections ⇒ Object
array(object) - Proxy connections observed for this process.
-
#initialize(attributes = {}, options = {}) ⇒ AgentNodeInstance
constructor
A new instance of AgentNodeInstance.
-
#instance_id ⇒ Object
string - Ephemeral ID for this running Agent process.
-
#is_default ⇒ Object
boolean - Whether this process receives new unscoped work for its node.
-
#last_seen_at ⇒ Object
date-time - Most recent successful observation for this process.
-
#process_state ⇒ Object
string - Role of this process during an Agent update.
-
#status ⇒ Object
string - Whether this process has an available proxy connection.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ AgentNodeInstance
Returns a new instance of AgentNodeInstance.
7 8 9 10 |
# File 'lib/files.com/models/agent_node_instance.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/agent_node_instance.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/agent_node_instance.rb', line 5 def @options end |
Instance Method Details
#agent_version ⇒ Object
string - Agent version reported by this process
33 34 35 |
# File 'lib/files.com/models/agent_node_instance.rb', line 33 def agent_version @attributes[:agent_version] end |
#connections ⇒ Object
array(object) - Proxy connections observed for this process
43 44 45 |
# File 'lib/files.com/models/agent_node_instance.rb', line 43 def connections @attributes[:connections] end |
#instance_id ⇒ Object
string - Ephemeral ID for this running Agent process
13 14 15 |
# File 'lib/files.com/models/agent_node_instance.rb', line 13 def instance_id @attributes[:instance_id] end |
#is_default ⇒ Object
boolean - Whether this process receives new unscoped work for its node
28 29 30 |
# File 'lib/files.com/models/agent_node_instance.rb', line 28 def is_default @attributes[:is_default] end |
#last_seen_at ⇒ Object
date-time - Most recent successful observation for this process
38 39 40 |
# File 'lib/files.com/models/agent_node_instance.rb', line 38 def last_seen_at @attributes[:last_seen_at] end |
#process_state ⇒ Object
string - Role of this process during an Agent update
18 19 20 |
# File 'lib/files.com/models/agent_node_instance.rb', line 18 def process_state @attributes[:process_state] end |
#status ⇒ Object
string - Whether this process has an available proxy connection
23 24 25 |
# File 'lib/files.com/models/agent_node_instance.rb', line 23 def status @attributes[:status] end |