Class: Files::BlogPost
- Inherits:
-
Object
- Object
- Files::BlogPost
- Defined in:
- lib/files.com/models/blog_post.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create_export(params = {}, options = {}) ⇒ Object
Parameters: sort_by - object - If set, sort records by the specified field in either
ascordescdirection. -
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
Instance Method Summary collapse
-
#content ⇒ Object
string - Blog Post's Content.
-
#id ⇒ Object
int64 - Blog Post ID.
-
#initialize(attributes = {}, options = {}) ⇒ BlogPost
constructor
A new instance of BlogPost.
-
#link ⇒ Object
date-time - Blog Post's Permanent Link.
-
#published_at ⇒ Object
date-time - Blog Post's Published Date.
-
#title ⇒ Object
string - Blog Post's Title.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ BlogPost
Returns a new instance of BlogPost.
7 8 9 10 |
# File 'lib/files.com/models/blog_post.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/blog_post.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/blog_post.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
61 62 63 |
# File 'lib/files.com/models/blog_post.rb', line 61 def self.all(params = {}, = {}) list(params, ) end |
.create_export(params = {}, options = {}) ⇒ Object
Parameters:
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `published_at`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `published_at`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `published_at`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `published_at`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `published_at`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `published_at`.
72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/files.com/models/blog_post.rb', line 72 def self.create_export(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash) response, = Api.send_request("/blog_posts/create_export", :post, params, ) Export.new(response.data, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `published_at`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `published_at`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `published_at`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `published_at`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `published_at`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `published_at`.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/files.com/models/blog_post.rb', line 46 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash) List.new(BlogPost, params) do Api.send_request("/blog_posts", :get, params, ) end end |
Instance Method Details
#content ⇒ Object
string - Blog Post's Content
23 24 25 |
# File 'lib/files.com/models/blog_post.rb', line 23 def content @attributes[:content] end |
#id ⇒ Object
int64 - Blog Post ID
13 14 15 |
# File 'lib/files.com/models/blog_post.rb', line 13 def id @attributes[:id] end |
#link ⇒ Object
date-time - Blog Post's Permanent Link
28 29 30 |
# File 'lib/files.com/models/blog_post.rb', line 28 def link @attributes[:link] end |
#published_at ⇒ Object
date-time - Blog Post's Published Date
33 34 35 |
# File 'lib/files.com/models/blog_post.rb', line 33 def published_at @attributes[:published_at] end |
#title ⇒ Object
string - Blog Post's Title
18 19 20 |
# File 'lib/files.com/models/blog_post.rb', line 18 def title @attributes[:title] end |