Class: Files::BundleNotification

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/bundle_notification.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ BundleNotification

Returns a new instance of BundleNotification.



7
8
9
10
# File 'lib/files.com/models/bundle_notification.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/bundle_notification.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/bundle_notification.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



123
124
125
# File 'lib/files.com/models/bundle_notification.rb', line 123

def self.all(params = {}, options = {})
  list(params, options)
end

.create(params = {}, options = {}) ⇒ Object

Parameters:

user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
bundle_id (required) - int64 - Bundle ID to notify on
notify_user_id - int64 - The id of the user to notify.
notify_on_registration - boolean - Triggers bundle notification when a registration action occurs for it.
notify_on_upload - boolean - Triggers bundle notification when a upload action occurs for it.


149
150
151
152
153
154
155
156
157
# File 'lib/files.com/models/bundle_notification.rb', line 149

def self.create(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: user_id must be an Integer") if params[:user_id] and !params[:user_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: bundle_id must be an Integer") if params[:bundle_id] and !params[:bundle_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: notify_user_id must be an Integer") if params[:notify_user_id] and !params[:notify_user_id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: bundle_id") unless params[:bundle_id]

  response, options = Api.send_request("/bundle_notifications", :post, params, options)
  BundleNotification.new(response.data, options)
end

.delete(id, params = {}, options = {}) ⇒ Object



172
173
174
175
176
177
178
179
180
# File 'lib/files.com/models/bundle_notification.rb', line 172

def self.delete(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  Api.send_request("/bundle_notifications/#{params[:id]}", :delete, params, options)
  nil
end

.destroy(id, params = {}, options = {}) ⇒ Object



182
183
184
185
# File 'lib/files.com/models/bundle_notification.rb', line 182

def self.destroy(id, params = {}, options = {})
  delete(id, params, options)
  nil
end

.find(id, params = {}, options = {}) ⇒ Object

Parameters:

id (required) - int64 - Bundle Notification ID.


129
130
131
132
133
134
135
136
137
# File 'lib/files.com/models/bundle_notification.rb', line 129

def self.find(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  response, options = Api.send_request("/bundle_notifications/#{params[:id]}", :get, params, options)
  BundleNotification.new(response.data, options)
end

.get(id, params = {}, options = {}) ⇒ Object



139
140
141
# File 'lib/files.com/models/bundle_notification.rb', line 139

def self.get(id, params = {}, options = {})
  find(id, params, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `bundle_id`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `bundle_id`.


111
112
113
114
115
116
117
118
119
120
121
# File 'lib/files.com/models/bundle_notification.rb', line 111

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: user_id must be an Integer") if params[:user_id] and !params[:user_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash)

  List.new(BundleNotification, params) do
    Api.send_request("/bundle_notifications", :get, params, options)
  end
end

.update(id, params = {}, options = {}) ⇒ Object

Parameters:

notify_on_registration - boolean - Triggers bundle notification when a registration action occurs for it.
notify_on_upload - boolean - Triggers bundle notification when a upload action occurs for it.


162
163
164
165
166
167
168
169
170
# File 'lib/files.com/models/bundle_notification.rb', line 162

def self.update(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  response, options = Api.send_request("/bundle_notifications/#{params[:id]}", :patch, params, options)
  BundleNotification.new(response.data, options)
end

Instance Method Details

#bundle_idObject

int64 - Bundle ID to notify on



13
14
15
# File 'lib/files.com/models/bundle_notification.rb', line 13

def bundle_id
  @attributes[:bundle_id]
end

#bundle_id=(value) ⇒ Object



17
18
19
# File 'lib/files.com/models/bundle_notification.rb', line 17

def bundle_id=(value)
  @attributes[:bundle_id] = value
end

#delete(params = {}) ⇒ Object



79
80
81
82
83
84
85
86
87
# File 'lib/files.com/models/bundle_notification.rb', line 79

def delete(params = {})
  params ||= {}
  params[:id] = @attributes[:id]
  raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id]
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  Api.send_request("/bundle_notifications/#{@attributes[:id]}", :delete, params, @options)
end

#destroy(params = {}) ⇒ Object



89
90
91
92
# File 'lib/files.com/models/bundle_notification.rb', line 89

def destroy(params = {})
  delete(params)
  nil
end

#idObject

int64 - Bundle Notification ID



22
23
24
# File 'lib/files.com/models/bundle_notification.rb', line 22

def id
  @attributes[:id]
end

#id=(value) ⇒ Object



26
27
28
# File 'lib/files.com/models/bundle_notification.rb', line 26

def id=(value)
  @attributes[:id] = value
end

#notify_on_registrationObject

boolean - Triggers bundle notification when a registration action occurs for it.



31
32
33
# File 'lib/files.com/models/bundle_notification.rb', line 31

def notify_on_registration
  @attributes[:notify_on_registration]
end

#notify_on_registration=(value) ⇒ Object



35
36
37
# File 'lib/files.com/models/bundle_notification.rb', line 35

def notify_on_registration=(value)
  @attributes[:notify_on_registration] = value
end

#notify_on_uploadObject

boolean - Triggers bundle notification when a upload action occurs for it.



40
41
42
# File 'lib/files.com/models/bundle_notification.rb', line 40

def notify_on_upload
  @attributes[:notify_on_upload]
end

#notify_on_upload=(value) ⇒ Object



44
45
46
# File 'lib/files.com/models/bundle_notification.rb', line 44

def notify_on_upload=(value)
  @attributes[:notify_on_upload] = value
end

#notify_user_idObject

int64 - The id of the user to notify.



49
50
51
# File 'lib/files.com/models/bundle_notification.rb', line 49

def notify_user_id
  @attributes[:notify_user_id]
end

#notify_user_id=(value) ⇒ Object



53
54
55
# File 'lib/files.com/models/bundle_notification.rb', line 53

def notify_user_id=(value)
  @attributes[:notify_user_id] = value
end

#saveObject



94
95
96
97
98
99
100
101
102
103
# File 'lib/files.com/models/bundle_notification.rb', line 94

def save
  if @attributes[:id]
    new_obj = update(@attributes)
  else
    new_obj = BundleNotification.create(@attributes, @options)
  end

  @attributes = new_obj.attributes
  true
end

#update(params = {}) ⇒ Object

Parameters:

notify_on_registration - boolean - Triggers bundle notification when a registration action occurs for it.
notify_on_upload - boolean - Triggers bundle notification when a upload action occurs for it.


69
70
71
72
73
74
75
76
77
# File 'lib/files.com/models/bundle_notification.rb', line 69

def update(params = {})
  params ||= {}
  params[:id] = @attributes[:id]
  raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id]
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  Api.send_request("/bundle_notifications/#{@attributes[:id]}", :patch, params, @options)
end

#user_idObject

int64 - User ID. Provide a value of ‘0` to operate the current session’s user.



58
59
60
# File 'lib/files.com/models/bundle_notification.rb', line 58

def user_id
  @attributes[:user_id]
end

#user_id=(value) ⇒ Object



62
63
64
# File 'lib/files.com/models/bundle_notification.rb', line 62

def user_id=(value)
  @attributes[:user_id] = value
end