Class: Files::CustomDomain

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/custom_domain.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ CustomDomain

Returns a new instance of CustomDomain.



7
8
9
10
# File 'lib/files.com/models/custom_domain.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/custom_domain.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/custom_domain.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



144
145
146
# File 'lib/files.com/models/custom_domain.rb', line 144

def self.all(params = {}, options = {})
  list(params, options)
end

.create(params = {}, options = {}) ⇒ Object

Parameters:

destination - string - Where this custom domain routes. Can be `site_alias`, `public_hosting`, or `s3_endpoint`.
folder_behavior_id - int64 - Public Hosting behavior ID when this domain routes to a specific Public Hosting behavior.
ssl_certificate_id - int64 - Current SSL certificate ID.
domain (required) - string - Customer-owned domain name.


169
170
171
172
173
174
175
176
177
178
# File 'lib/files.com/models/custom_domain.rb', line 169

def self.create(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: destination must be an String") if params[:destination] and !params[:destination].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: folder_behavior_id must be an Integer") if params[:folder_behavior_id] and !params[:folder_behavior_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: ssl_certificate_id must be an Integer") if params[:ssl_certificate_id] and !params[:ssl_certificate_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: domain must be an String") if params[:domain] and !params[:domain].is_a?(String)
  raise MissingParameterError.new("Parameter missing: domain") unless params[:domain]

  response, options = Api.send_request("/custom_domains", :post, params, options)
  CustomDomain.new(response.data, options)
end

.delete(id, params = {}, options = {}) ⇒ Object



199
200
201
202
203
204
205
206
207
# File 'lib/files.com/models/custom_domain.rb', line 199

def self.delete(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  Api.send_request("/custom_domains/#{params[:id]}", :delete, params, options)
  nil
end

.destroy(id, params = {}, options = {}) ⇒ Object



209
210
211
212
# File 'lib/files.com/models/custom_domain.rb', line 209

def self.destroy(id, params = {}, options = {})
  delete(id, params, options)
  nil
end

.find(id, params = {}, options = {}) ⇒ Object

Parameters:

id (required) - int64 - Custom Domain ID.


150
151
152
153
154
155
156
157
158
# File 'lib/files.com/models/custom_domain.rb', line 150

def self.find(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  response, options = Api.send_request("/custom_domains/#{params[:id]}", :get, params, options)
  CustomDomain.new(response.data, options)
end

.get(id, params = {}, options = {}) ⇒ Object



160
161
162
# File 'lib/files.com/models/custom_domain.rb', line 160

def self.get(id, params = {}, options = {})
  find(id, params, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `id`.


134
135
136
137
138
139
140
141
142
# File 'lib/files.com/models/custom_domain.rb', line 134

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash)

  List.new(CustomDomain, params) do
    Api.send_request("/custom_domains", :get, params, options)
  end
end

.update(id, params = {}, options = {}) ⇒ Object

Parameters:

destination - string - Where this custom domain routes. Can be `site_alias`, `public_hosting`, or `s3_endpoint`.
folder_behavior_id - int64 - Public Hosting behavior ID when this domain routes to a specific Public Hosting behavior.
ssl_certificate_id - int64 - Current SSL certificate ID.
domain - string - Customer-owned domain name.


185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/files.com/models/custom_domain.rb', line 185

def self.update(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: destination must be an String") if params[:destination] and !params[:destination].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: folder_behavior_id must be an Integer") if params[:folder_behavior_id] and !params[:folder_behavior_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: ssl_certificate_id must be an Integer") if params[:ssl_certificate_id] and !params[:ssl_certificate_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: domain must be an String") if params[:domain] and !params[:domain].is_a?(String)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  response, options = Api.send_request("/custom_domains/#{params[:id]}", :patch, params, options)
  CustomDomain.new(response.data, options)
end

Instance Method Details

#brick_managedObject

boolean - Is this domain’s SSL certificate automatically managed and renewed by Files.com?



58
59
60
# File 'lib/files.com/models/custom_domain.rb', line 58

def brick_managed
  @attributes[:brick_managed]
end

#brick_managed=(value) ⇒ Object



62
63
64
# File 'lib/files.com/models/custom_domain.rb', line 62

def brick_managed=(value)
  @attributes[:brick_managed] = value
end

#created_atObject

date-time - When this Custom Domain was created.



76
77
78
# File 'lib/files.com/models/custom_domain.rb', line 76

def created_at
  @attributes[:created_at]
end

#delete(params = {}) ⇒ Object



104
105
106
107
108
109
110
111
112
# File 'lib/files.com/models/custom_domain.rb', line 104

def delete(params = {})
  params ||= {}
  params[:id] = @attributes[:id]
  raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id]
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  Api.send_request("/custom_domains/#{@attributes[:id]}", :delete, params, @options)
end

#destinationObject

string - Where this custom domain routes. Can be ‘site_alias`, `public_hosting`, or `s3_endpoint`.



31
32
33
# File 'lib/files.com/models/custom_domain.rb', line 31

def destination
  @attributes[:destination]
end

#destination=(value) ⇒ Object



35
36
37
# File 'lib/files.com/models/custom_domain.rb', line 35

def destination=(value)
  @attributes[:destination] = value
end

#destroy(params = {}) ⇒ Object



114
115
116
117
# File 'lib/files.com/models/custom_domain.rb', line 114

def destroy(params = {})
  delete(params)
  nil
end

#dns_statusObject

string - Current DNS verification status.



40
41
42
# File 'lib/files.com/models/custom_domain.rb', line 40

def dns_status
  @attributes[:dns_status]
end

#dns_status=(value) ⇒ Object



44
45
46
# File 'lib/files.com/models/custom_domain.rb', line 44

def dns_status=(value)
  @attributes[:dns_status] = value
end

#domainObject

string - Customer-owned domain name.



22
23
24
# File 'lib/files.com/models/custom_domain.rb', line 22

def domain
  @attributes[:domain]
end

#domain=(value) ⇒ Object



26
27
28
# File 'lib/files.com/models/custom_domain.rb', line 26

def domain=(value)
  @attributes[:domain] = value
end

#folder_behavior_idObject

int64 - Public Hosting behavior ID when this domain routes to a specific Public Hosting behavior.



67
68
69
# File 'lib/files.com/models/custom_domain.rb', line 67

def folder_behavior_id
  @attributes[:folder_behavior_id]
end

#folder_behavior_id=(value) ⇒ Object



71
72
73
# File 'lib/files.com/models/custom_domain.rb', line 71

def folder_behavior_id=(value)
  @attributes[:folder_behavior_id] = value
end

#idObject

int64 - Custom Domain ID.



13
14
15
# File 'lib/files.com/models/custom_domain.rb', line 13

def id
  @attributes[:id]
end

#id=(value) ⇒ Object



17
18
19
# File 'lib/files.com/models/custom_domain.rb', line 17

def id=(value)
  @attributes[:id] = value
end

#saveObject



119
120
121
122
123
124
125
126
127
128
# File 'lib/files.com/models/custom_domain.rb', line 119

def save
  if @attributes[:id]
    new_obj = update(@attributes)
  else
    new_obj = CustomDomain.create(@attributes, @options)
  end

  @attributes = new_obj.attributes
  true
end

#ssl_certificate_idObject

int64 - Current SSL certificate ID.



49
50
51
# File 'lib/files.com/models/custom_domain.rb', line 49

def ssl_certificate_id
  @attributes[:ssl_certificate_id]
end

#ssl_certificate_id=(value) ⇒ Object



53
54
55
# File 'lib/files.com/models/custom_domain.rb', line 53

def ssl_certificate_id=(value)
  @attributes[:ssl_certificate_id] = value
end

#update(params = {}) ⇒ Object

Parameters:

destination - string - Where this custom domain routes. Can be `site_alias`, `public_hosting`, or `s3_endpoint`.
folder_behavior_id - int64 - Public Hosting behavior ID when this domain routes to a specific Public Hosting behavior.
ssl_certificate_id - int64 - Current SSL certificate ID.
domain - string - Customer-owned domain name.


90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/files.com/models/custom_domain.rb', line 90

def update(params = {})
  params ||= {}
  params[:id] = @attributes[:id]
  raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id]
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: destination must be an String") if params[:destination] and !params[:destination].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: folder_behavior_id must be an Integer") if params[:folder_behavior_id] and !params[:folder_behavior_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: ssl_certificate_id must be an Integer") if params[:ssl_certificate_id] and !params[:ssl_certificate_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: domain must be an String") if params[:domain] and !params[:domain].is_a?(String)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  Api.send_request("/custom_domains/#{@attributes[:id]}", :patch, params, @options)
end

#updated_atObject

date-time - When this Custom Domain was last updated.



81
82
83
# File 'lib/files.com/models/custom_domain.rb', line 81

def updated_at
  @attributes[:updated_at]
end