Class: Files::EmailLog

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/email_log.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ EmailLog

Returns a new instance of EmailLog.



7
8
9
10
# File 'lib/files.com/models/email_log.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/email_log.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/email_log.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



84
85
86
# File 'lib/files.com/models/email_log.rb', line 84

def self.all(params = {}, options = {})
  list(params, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `status` and `created_at`. Valid field combinations are `[ status ]`, `[ created_at ]` or `[ status, created_at ]`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`. Valid field combinations are `[ status ]`, `[ created_at ]` or `[ status, created_at ]`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `created_at`. Valid field combinations are `[ status ]`, `[ created_at ]` or `[ status, created_at ]`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`. Valid field combinations are `[ status ]`, `[ created_at ]` or `[ status, created_at ]`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `created_at`. Valid field combinations are `[ status ]`, `[ created_at ]` or `[ status, created_at ]`.


70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/files.com/models/email_log.rb', line 70

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash)

  List.new(EmailLog, params) do
    Api.send_request("/email_logs", :get, params, options)
  end
end

Instance Method Details

#ccObject

string - CC field of E-Mail



38
39
40
# File 'lib/files.com/models/email_log.rb', line 38

def cc
  @attributes[:cc]
end

#created_atObject

date-time - Start Time of Action



58
59
60
# File 'lib/files.com/models/email_log.rb', line 58

def created_at
  @attributes[:created_at]
end

#delivery_methodObject

string - How was the email delivered? ‘customer_smtp` or `files.com`



43
44
45
# File 'lib/files.com/models/email_log.rb', line 43

def delivery_method
  @attributes[:delivery_method]
end

#messageObject

string - Log Message



18
19
20
# File 'lib/files.com/models/email_log.rb', line 18

def message
  @attributes[:message]
end

#smtp_hostnameObject

string - Customer SMTP Hostname used.



48
49
50
# File 'lib/files.com/models/email_log.rb', line 48

def smtp_hostname
  @attributes[:smtp_hostname]
end

#smtp_ipObject

string - Customer SMTP IP address as resolved for use (useful for troubleshooting DNS issues with customer SMTP).



53
54
55
# File 'lib/files.com/models/email_log.rb', line 53

def smtp_ip
  @attributes[:smtp_ip]
end

#statusObject

string - Status of E-Mail delivery



23
24
25
# File 'lib/files.com/models/email_log.rb', line 23

def status
  @attributes[:status]
end

#subjectObject

string - Subject line of E-Mail



28
29
30
# File 'lib/files.com/models/email_log.rb', line 28

def subject
  @attributes[:subject]
end

#timestampObject

date-time - Start Time of Action. Deprecrated: Use created_at.



13
14
15
# File 'lib/files.com/models/email_log.rb', line 13

def timestamp
  @attributes[:timestamp]
end

#toObject

string - To field of E-Mail



33
34
35
# File 'lib/files.com/models/email_log.rb', line 33

def to
  @attributes[:to]
end