Class: Files::IpAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/ip_address.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ IpAddress

Returns a new instance of IpAddress.



7
8
9
10
# File 'lib/files.com/models/ip_address.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/ip_address.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/ip_address.rb', line 5

def options
  @options
end

Class Method Details

.active_create_export(params = {}, options = {}) ⇒ Object



96
97
98
99
# File 'lib/files.com/models/ip_address.rb', line 96

def self.active_create_export(params = {}, options = {})
  response, options = Api.send_request("/ip_addresses/active/create_export", :post, params, options)
  Export.new(response.data, options)
end

.all(params = {}, options = {}) ⇒ Object



44
45
46
# File 'lib/files.com/models/ip_address.rb', line 44

def self.all(params = {}, options = {})
  list(params, options)
end

.create_export(params = {}, options = {}) ⇒ Object



116
117
118
119
# File 'lib/files.com/models/ip_address.rb', line 116

def self.create_export(params = {}, options = {})
  response, options = Api.send_request("/ip_addresses/create_export", :post, params, options)
  Export.new(response.data, options)
end

.exavault_reserved_create_export(params = {}, options = {}) ⇒ Object



106
107
108
109
# File 'lib/files.com/models/ip_address.rb', line 106

def self.exavault_reserved_create_export(params = {}, options = {})
  response, options = Api.send_request("/ip_addresses/exavault-reserved/create_export", :post, params, options)
  Export.new(response.data, options)
end

.get_active(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).


51
52
53
54
55
56
57
58
# File 'lib/files.com/models/ip_address.rb', line 51

def self.get_active(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(PublicIpAddress, params) do
    Api.send_request("/ip_addresses/active", :get, params, options)
  end
end

.get_exavault_reserved(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).


75
76
77
78
79
80
81
82
# File 'lib/files.com/models/ip_address.rb', line 75

def self.get_exavault_reserved(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(PublicIpAddress, params) do
    Api.send_request("/ip_addresses/exavault-reserved", :get, params, options)
  end
end

.get_reserved(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).


87
88
89
90
91
92
93
94
# File 'lib/files.com/models/ip_address.rb', line 87

def self.get_reserved(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(PublicIpAddress, params) do
    Api.send_request("/ip_addresses/reserved", :get, params, options)
  end
end

.get_smartfile_reserved(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).


63
64
65
66
67
68
69
70
# File 'lib/files.com/models/ip_address.rb', line 63

def self.get_smartfile_reserved(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(PublicIpAddress, params) do
    Api.send_request("/ip_addresses/smartfile-reserved", :get, params, options)
  end
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).


35
36
37
38
39
40
41
42
# File 'lib/files.com/models/ip_address.rb', line 35

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(IpAddress, params) do
    Api.send_request("/ip_addresses", :get, params, options)
  end
end

.reserved_create_export(params = {}, options = {}) ⇒ Object



111
112
113
114
# File 'lib/files.com/models/ip_address.rb', line 111

def self.reserved_create_export(params = {}, options = {})
  response, options = Api.send_request("/ip_addresses/reserved/create_export", :post, params, options)
  Export.new(response.data, options)
end

.smartfile_reserved_create_export(params = {}, options = {}) ⇒ Object



101
102
103
104
# File 'lib/files.com/models/ip_address.rb', line 101

def self.smartfile_reserved_create_export(params = {}, options = {})
  response, options = Api.send_request("/ip_addresses/smartfile-reserved/create_export", :post, params, options)
  Export.new(response.data, options)
end

Instance Method Details

#associated_withObject

string - The object that this public IP address list is associated with.



18
19
20
# File 'lib/files.com/models/ip_address.rb', line 18

def associated_with
  @attributes[:associated_with]
end

#group_idObject

int64 - Group ID



23
24
25
# File 'lib/files.com/models/ip_address.rb', line 23

def group_id
  @attributes[:group_id]
end

#idObject

string - Unique label for list; used by Zapier and other integrations.



13
14
15
# File 'lib/files.com/models/ip_address.rb', line 13

def id
  @attributes[:id]
end

#ip_addressesObject

array(string) - A list of IP addresses.



28
29
30
# File 'lib/files.com/models/ip_address.rb', line 28

def ip_addresses
  @attributes[:ip_addresses]
end