Class: Files::KeyLifecycleRule
- Inherits:
-
Object
- Object
- Files::KeyLifecycleRule
- Defined in:
- lib/files.com/models/key_lifecycle_rule.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: apply_to_all_workspaces - boolean - If true, a default-workspace rule also applies to keys in all workspaces.
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Key Lifecycle Rule ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: apply_to_all_workspaces - boolean - If true, a default-workspace rule also applies to keys in all workspaces.
Instance Method Summary collapse
-
#apply_to_all_workspaces ⇒ Object
boolean - If true, a default-workspace rule also applies to keys in all workspaces.
- #apply_to_all_workspaces=(value) ⇒ Object
- #delete(params = {}) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#id ⇒ Object
int64 - Key Lifecycle Rule ID.
- #id=(value) ⇒ Object
-
#inactivity_days ⇒ Object
int64 - Number of days of inactivity before the rule applies.
- #inactivity_days=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ KeyLifecycleRule
constructor
A new instance of KeyLifecycleRule.
-
#key_type ⇒ Object
string - Key type for which the rule will apply (gpg or ssh).
- #key_type=(value) ⇒ Object
-
#name ⇒ Object
string - Key Lifecycle Rule name.
- #name=(value) ⇒ Object
- #save ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: apply_to_all_workspaces - boolean - If true, a default-workspace rule also applies to keys in all workspaces.
-
#workspace_id ⇒ Object
int64 - Workspace ID.
- #workspace_id=(value) ⇒ Object
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ KeyLifecycleRule
Returns a new instance of KeyLifecycleRule.
7 8 9 10 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
128 129 130 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 128 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
apply_to_all_workspaces - boolean - If true, a default-workspace rule also applies to keys in all workspaces.
key_type - string - Key type for which the rule will apply (gpg or ssh).
inactivity_days - int64 - Number of days of inactivity before the rule applies.
name - string - Key Lifecycle Rule name
workspace_id - int64 - Workspace ID. `0` means the default workspace.
154 155 156 157 158 159 160 161 162 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 154 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: key_type must be an String") if params[:key_type] and !params[:key_type].is_a?(String) raise InvalidParameterError.new("Bad parameter: inactivity_days must be an Integer") if params[:inactivity_days] and !params[:inactivity_days].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: workspace_id must be an Integer") if params[:workspace_id] and !params[:workspace_id].is_a?(Integer) response, = Api.send_request("/key_lifecycle_rules", :post, params, ) KeyLifecycleRule.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
184 185 186 187 188 189 190 191 192 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 184 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/key_lifecycle_rules/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
194 195 196 197 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 194 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Key Lifecycle Rule ID.
134 135 136 137 138 139 140 141 142 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 134 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/key_lifecycle_rules/#{params[:id]}", :get, params, ) KeyLifecycleRule.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
144 145 146 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 144 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `workspace_id` and `key_type`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `key_type` and `workspace_id`. Valid field combinations are `[ workspace_id, key_type ]`.
117 118 119 120 121 122 123 124 125 126 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 117 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) List.new(KeyLifecycleRule, params) do Api.send_request("/key_lifecycle_rules", :get, params, ) end end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
apply_to_all_workspaces - boolean - If true, a default-workspace rule also applies to keys in all workspaces.
key_type - string - Key type for which the rule will apply (gpg or ssh).
inactivity_days - int64 - Number of days of inactivity before the rule applies.
name - string - Key Lifecycle Rule name
workspace_id - int64 - Workspace ID. `0` means the default workspace.
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 170 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: key_type must be an String") if params[:key_type] and !params[:key_type].is_a?(String) raise InvalidParameterError.new("Bad parameter: inactivity_days must be an Integer") if params[:inactivity_days] and !params[:inactivity_days].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: workspace_id must be an Integer") if params[:workspace_id] and !params[:workspace_id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/key_lifecycle_rules/#{params[:id]}", :patch, params, ) KeyLifecycleRule.new(response.data, ) end |
Instance Method Details
#apply_to_all_workspaces ⇒ Object
boolean - If true, a default-workspace rule also applies to keys in all workspaces.
40 41 42 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 40 def apply_to_all_workspaces @attributes[:apply_to_all_workspaces] end |
#apply_to_all_workspaces=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 44 def apply_to_all_workspaces=(value) @attributes[:apply_to_all_workspaces] = value end |
#delete(params = {}) ⇒ Object
86 87 88 89 90 91 92 93 94 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 86 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/key_lifecycle_rules/#{@attributes[:id]}", :delete, params, @options) end |
#destroy(params = {}) ⇒ Object
96 97 98 99 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 96 def destroy(params = {}) delete(params) nil end |
#id ⇒ Object
int64 - Key Lifecycle Rule ID
13 14 15 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 17 def id=(value) @attributes[:id] = value end |
#inactivity_days ⇒ Object
int64 - Number of days of inactivity before the rule applies.
31 32 33 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 31 def inactivity_days @attributes[:inactivity_days] end |
#inactivity_days=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 35 def inactivity_days=(value) @attributes[:inactivity_days] = value end |
#key_type ⇒ Object
string - Key type for which the rule will apply (gpg or ssh).
22 23 24 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 22 def key_type @attributes[:key_type] end |
#key_type=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 26 def key_type=(value) @attributes[:key_type] = value end |
#name ⇒ Object
string - Key Lifecycle Rule name
49 50 51 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 49 def name @attributes[:name] end |
#name=(value) ⇒ Object
53 54 55 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 53 def name=(value) @attributes[:name] = value end |
#save ⇒ Object
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 101 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = KeyLifecycleRule.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#update(params = {}) ⇒ Object
Parameters:
apply_to_all_workspaces - boolean - If true, a default-workspace rule also applies to keys in all workspaces.
key_type - string - Key type for which the rule will apply (gpg or ssh).
inactivity_days - int64 - Number of days of inactivity before the rule applies.
name - string - Key Lifecycle Rule name
workspace_id - int64 - Workspace ID. `0` means the default workspace.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 72 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: key_type must be an String") if params[:key_type] and !params[:key_type].is_a?(String) raise InvalidParameterError.new("Bad parameter: inactivity_days must be an Integer") if params[:inactivity_days] and !params[:inactivity_days].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: workspace_id must be an Integer") if params[:workspace_id] and !params[:workspace_id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/key_lifecycle_rules/#{@attributes[:id]}", :patch, params, @options) end |
#workspace_id ⇒ Object
int64 - Workspace ID. ‘0` means the default workspace.
58 59 60 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 58 def workspace_id @attributes[:workspace_id] end |
#workspace_id=(value) ⇒ Object
62 63 64 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 62 def workspace_id=(value) @attributes[:workspace_id] = value end |