Class: Files::MetadataCategory
- Inherits:
-
Object
- Object
- Files::MetadataCategory
- Defined in:
- lib/files.com/models/metadata_category.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: name (required) - string - Name of the metadata category.
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Metadata Category ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: name - string - Name of the metadata category.
Instance Method Summary collapse
-
#default_columns ⇒ Object
array(string) - Metadata keys that should appear as columns in the UI by default.
- #default_columns=(value) ⇒ Object
-
#definitions ⇒ Object
hash(string,array(string)) - Map of key names to arrays of allowed values.
- #definitions=(value) ⇒ Object
- #delete(params = {}) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#id ⇒ Object
int64 - Metadata Category ID.
- #id=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ MetadataCategory
constructor
A new instance of MetadataCategory.
-
#name ⇒ Object
string - Name of the metadata category.
- #name=(value) ⇒ Object
- #save ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: name - string - Name of the metadata category.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ MetadataCategory
Returns a new instance of MetadataCategory.
7 8 9 10 |
# File 'lib/files.com/models/metadata_category.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/metadata_category.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/metadata_category.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
103 104 105 |
# File 'lib/files.com/models/metadata_category.rb', line 103 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
name (required) - string - Name of the metadata category.
default_columns - array(string) - Metadata keys that should appear as columns in the UI by default.
126 127 128 129 130 131 132 133 |
# File 'lib/files.com/models/metadata_category.rb', line 126 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: default_columns must be an Array") if params[:default_columns] and !params[:default_columns].is_a?(Array) raise MissingParameterError.new("Parameter missing: name") unless params[:name] response, = Api.send_request("/metadata_categories", :post, params, ) MetadataCategory.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
150 151 152 153 154 155 156 157 158 |
# File 'lib/files.com/models/metadata_category.rb', line 150 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/metadata_categories/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
160 161 162 163 |
# File 'lib/files.com/models/metadata_category.rb', line 160 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Metadata Category ID.
109 110 111 112 113 114 115 116 117 |
# File 'lib/files.com/models/metadata_category.rb', line 109 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/metadata_categories/#{params[:id]}", :get, params, ) MetadataCategory.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
119 120 121 |
# File 'lib/files.com/models/metadata_category.rb', line 119 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are .
93 94 95 96 97 98 99 100 101 |
# File 'lib/files.com/models/metadata_category.rb', line 93 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) List.new(MetadataCategory, params) do Api.send_request("/metadata_categories", :get, params, ) end end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
name - string - Name of the metadata category.
default_columns - array(string) - Metadata keys that should appear as columns in the UI by default.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/files.com/models/metadata_category.rb', line 138 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: default_columns must be an Array") if params[:default_columns] and !params[:default_columns].is_a?(Array) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/metadata_categories/#{params[:id]}", :patch, params, ) MetadataCategory.new(response.data, ) end |
Instance Method Details
#default_columns ⇒ Object
array(string) - Metadata keys that should appear as columns in the UI by default.
40 41 42 |
# File 'lib/files.com/models/metadata_category.rb', line 40 def default_columns @attributes[:default_columns] end |
#default_columns=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/metadata_category.rb', line 44 def default_columns=(value) @attributes[:default_columns] = value end |
#definitions ⇒ Object
hash(string,array(string)) - Map of key names to arrays of allowed values. An empty array means free-form text.
31 32 33 |
# File 'lib/files.com/models/metadata_category.rb', line 31 def definitions @attributes[:definitions] end |
#definitions=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/metadata_category.rb', line 35 def definitions=(value) @attributes[:definitions] = value end |
#delete(params = {}) ⇒ Object
63 64 65 66 67 68 69 70 71 |
# File 'lib/files.com/models/metadata_category.rb', line 63 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/metadata_categories/#{@attributes[:id]}", :delete, params, @options) end |
#destroy(params = {}) ⇒ Object
73 74 75 76 |
# File 'lib/files.com/models/metadata_category.rb', line 73 def destroy(params = {}) delete(params) nil end |
#id ⇒ Object
int64 - Metadata Category ID
13 14 15 |
# File 'lib/files.com/models/metadata_category.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/metadata_category.rb', line 17 def id=(value) @attributes[:id] = value end |
#name ⇒ Object
string - Name of the metadata category.
22 23 24 |
# File 'lib/files.com/models/metadata_category.rb', line 22 def name @attributes[:name] end |
#name=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/metadata_category.rb', line 26 def name=(value) @attributes[:name] = value end |
#save ⇒ Object
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/files.com/models/metadata_category.rb', line 78 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = MetadataCategory.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#update(params = {}) ⇒ Object
Parameters:
name - string - Name of the metadata category.
default_columns - array(string) - Metadata keys that should appear as columns in the UI by default.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/files.com/models/metadata_category.rb', line 51 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: default_columns must be an Array") if params[:default_columns] and !params[:default_columns].is_a?(Array) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/metadata_categories/#{@attributes[:id]}", :patch, params, @options) end |