Class: Files::MonitoringStat
- Inherits:
-
Object
- Object
- Files::MonitoringStat
- Defined in:
- lib/files.com/models/monitoring_stat.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
- .create_export(params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
Instance Method Summary collapse
-
#alerts ⇒ Object
array(string).
-
#info ⇒ Object
object.
-
#initialize(attributes = {}, options = {}) ⇒ MonitoringStat
constructor
A new instance of MonitoringStat.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ MonitoringStat
Returns a new instance of MonitoringStat.
7 8 9 10 |
# File 'lib/files.com/models/monitoring_stat.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/monitoring_stat.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/monitoring_stat.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
34 35 36 |
# File 'lib/files.com/models/monitoring_stat.rb', line 34 def self.all(params = {}, = {}) list(params, ) end |
.create_export(params = {}, options = {}) ⇒ Object
38 39 40 41 |
# File 'lib/files.com/models/monitoring_stat.rb', line 38 def self.create_export(params = {}, = {}) response, = Api.send_request("/monitoring_stats/create_export", :post, params, ) Export.new(response.data, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10000, 1,000 or less is recommended).
25 26 27 28 29 30 31 32 |
# File 'lib/files.com/models/monitoring_stat.rb', line 25 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) List.new(MonitoringStats, params) do Api.send_request("/monitoring_stats", :get, params, ) end end |
Instance Method Details
#alerts ⇒ Object
array(string)
13 14 15 |
# File 'lib/files.com/models/monitoring_stat.rb', line 13 def alerts @attributes[:alerts] end |
#info ⇒ Object
object
18 19 20 |
# File 'lib/files.com/models/monitoring_stat.rb', line 18 def info @attributes[:info] end |