Class: Files::PendingWorkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/pending_work_event.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ PendingWorkEvent

Returns a new instance of PendingWorkEvent.



7
8
9
10
# File 'lib/files.com/models/pending_work_event.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/pending_work_event.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/pending_work_event.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



76
77
78
# File 'lib/files.com/models/pending_work_event.rb', line 76

def self.all(params = {}, options = {})
  list(params, options)
end

.find(id, params = {}, options = {}) ⇒ Object

Parameters:

id (required) - int64 - Pending Work Event ID.


82
83
84
85
86
87
88
89
90
# File 'lib/files.com/models/pending_work_event.rb', line 82

def self.find(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  response, options = Api.send_request("/pending_work_events/#{params[:id]}", :get, params, options)
  PendingWorkEvent.new(response.data, options)
end

.get(id, params = {}, options = {}) ⇒ Object



92
93
94
# File 'lib/files.com/models/pending_work_event.rb', line 92

def self.get(id, params = {}, options = {})
  find(id, params, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `created_at`, `status` or `folder_behavior_id`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at`, `folder_behavior_id` or `status`. Valid field combinations are `[ folder_behavior_id, created_at ]`, `[ status, created_at ]`, `[ folder_behavior_id, status ]` or `[ folder_behavior_id, status, created_at ]`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `created_at`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `created_at`.


61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/files.com/models/pending_work_event.rb', line 61

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash)

  List.new(PendingWorkEvent, params) do
    Api.send_request("/pending_work_events", :get, params, options)
  end
end

Instance Method Details

#bodyObject

string - Event body.



28
29
30
# File 'lib/files.com/models/pending_work_event.rb', line 28

def body
  @attributes[:body]
end

#body_urlObject

string - Link to log file.



43
44
45
# File 'lib/files.com/models/pending_work_event.rb', line 43

def body_url
  @attributes[:body_url]
end

#created_atObject

date-time - Event create date/time.



38
39
40
# File 'lib/files.com/models/pending_work_event.rb', line 38

def created_at
  @attributes[:created_at]
end

#event_errorsObject

array(string) - Event errors.



33
34
35
# File 'lib/files.com/models/pending_work_event.rb', line 33

def event_errors
  @attributes[:event_errors]
end

#event_typeObject

string - Type of pending work event being recorded.



18
19
20
# File 'lib/files.com/models/pending_work_event.rb', line 18

def event_type
  @attributes[:event_type]
end

#folder_behavior_idObject

int64 - Folder Behavior ID.



48
49
50
# File 'lib/files.com/models/pending_work_event.rb', line 48

def folder_behavior_id
  @attributes[:folder_behavior_id]
end

#idObject

int64 - Event ID



13
14
15
# File 'lib/files.com/models/pending_work_event.rb', line 13

def id
  @attributes[:id]
end

#statusObject

string - Status of event.



23
24
25
# File 'lib/files.com/models/pending_work_event.rb', line 23

def status
  @attributes[:status]
end