Class: Files::PublicHostingRequestLog

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/public_hosting_request_log.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ PublicHostingRequestLog

Returns a new instance of PublicHostingRequestLog.



7
8
9
10
# File 'lib/files.com/models/public_hosting_request_log.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/public_hosting_request_log.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/public_hosting_request_log.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



91
92
93
# File 'lib/files.com/models/public_hosting_request_log.rb', line 91

def self.all(params = {}, options = {})
  list(params, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `path`, `remote_ip`, `success` or `created_at`. Valid field combinations are `[ path ]`, `[ remote_ip ]`, `[ success ]`, `[ created_at ]`, `[ path, remote_ip ]`, `[ path, success ]`, `[ path, created_at ]`, `[ remote_ip, success ]`, `[ remote_ip, created_at ]`, `[ success, created_at ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, created_at ]`, `[ path, success, created_at ]`, `[ remote_ip, success, created_at ]` or `[ path, remote_ip, success, created_at ]`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`. Valid field combinations are `[ path ]`, `[ remote_ip ]`, `[ success ]`, `[ created_at ]`, `[ path, remote_ip ]`, `[ path, success ]`, `[ path, created_at ]`, `[ remote_ip, success ]`, `[ remote_ip, created_at ]`, `[ success, created_at ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, created_at ]`, `[ path, success, created_at ]`, `[ remote_ip, success, created_at ]` or `[ path, remote_ip, success, created_at ]`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `created_at`. Valid field combinations are `[ path ]`, `[ remote_ip ]`, `[ success ]`, `[ created_at ]`, `[ path, remote_ip ]`, `[ path, success ]`, `[ path, created_at ]`, `[ remote_ip, success ]`, `[ remote_ip, created_at ]`, `[ success, created_at ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, created_at ]`, `[ path, success, created_at ]`, `[ remote_ip, success, created_at ]` or `[ path, remote_ip, success, created_at ]`.
filter_prefix - object - If set, return records where the specified field is prefixed by the supplied value. Valid fields are `path`. Valid field combinations are `[ path ]`, `[ remote_ip ]`, `[ success ]`, `[ created_at ]`, `[ path, remote_ip ]`, `[ path, success ]`, `[ path, created_at ]`, `[ remote_ip, success ]`, `[ remote_ip, created_at ]`, `[ success, created_at ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, created_at ]`, `[ path, success, created_at ]`, `[ remote_ip, success, created_at ]` or `[ path, remote_ip, success, created_at ]`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`. Valid field combinations are `[ path ]`, `[ remote_ip ]`, `[ success ]`, `[ created_at ]`, `[ path, remote_ip ]`, `[ path, success ]`, `[ path, created_at ]`, `[ remote_ip, success ]`, `[ remote_ip, created_at ]`, `[ success, created_at ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, created_at ]`, `[ path, success, created_at ]`, `[ remote_ip, success, created_at ]` or `[ path, remote_ip, success, created_at ]`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `created_at`. Valid field combinations are `[ path ]`, `[ remote_ip ]`, `[ success ]`, `[ created_at ]`, `[ path, remote_ip ]`, `[ path, success ]`, `[ path, created_at ]`, `[ remote_ip, success ]`, `[ remote_ip, created_at ]`, `[ success, created_at ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, created_at ]`, `[ path, success, created_at ]`, `[ remote_ip, success, created_at ]` or `[ path, remote_ip, success, created_at ]`.


76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/files.com/models/public_hosting_request_log.rb', line 76

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_prefix must be an Hash") if params[:filter_prefix] and !params[:filter_prefix].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash)

  List.new(PublicHostingRequestLog, params) do
    Api.send_request("/public_hosting_request_logs", :get, params, options)
  end
end

Instance Method Details

#bytes_transferredObject

int64 - The number of bytes transferred for file downloads.



58
59
60
# File 'lib/files.com/models/public_hosting_request_log.rb', line 58

def bytes_transferred
  @attributes[:bytes_transferred]
end

#created_atObject

date-time - Start Time of Action.



53
54
55
# File 'lib/files.com/models/public_hosting_request_log.rb', line 53

def created_at
  @attributes[:created_at]
end

#duration_msObject

int64 - Duration (in milliseconds).



48
49
50
# File 'lib/files.com/models/public_hosting_request_log.rb', line 48

def duration_ms
  @attributes[:duration_ms]
end

#hostnameObject

string - HTTP Request Hostname.



28
29
30
# File 'lib/files.com/models/public_hosting_request_log.rb', line 28

def hostname
  @attributes[:hostname]
end

#http_methodObject

string - Method of the HTTP call.



63
64
65
# File 'lib/files.com/models/public_hosting_request_log.rb', line 63

def http_method
  @attributes[:http_method]
end

#pathObject

string - HTTP Request Path. This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.



33
34
35
# File 'lib/files.com/models/public_hosting_request_log.rb', line 33

def path
  @attributes[:path]
end

#remote_ipObject

string - IP Address of Public Hosting Client.



18
19
20
# File 'lib/files.com/models/public_hosting_request_log.rb', line 18

def remote_ip
  @attributes[:remote_ip]
end

#response_codeObject

int64 - HTTP Response Code.



38
39
40
# File 'lib/files.com/models/public_hosting_request_log.rb', line 38

def response_code
  @attributes[:responseCode]
end

#server_ipObject

string - IP Address of Public Hosting Server.



23
24
25
# File 'lib/files.com/models/public_hosting_request_log.rb', line 23

def server_ip
  @attributes[:server_ip]
end

#successObject

boolean - Whether SFTP Action was successful.



43
44
45
# File 'lib/files.com/models/public_hosting_request_log.rb', line 43

def success
  @attributes[:success]
end

#timestampObject

date-time - Start Time of Action. Deprecrated: Use created_at.



13
14
15
# File 'lib/files.com/models/public_hosting_request_log.rb', line 13

def timestamp
  @attributes[:timestamp]
end