Class: Files::PublicHostingSessionPairing
- Inherits:
-
Object
- Object
- Files::PublicHostingSessionPairing
- Defined in:
- lib/files.com/models/public_hosting_session_pairing.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#expires_at ⇒ Object
date-time - When the pairing key expires.
-
#initialize(attributes = {}, options = {}) ⇒ PublicHostingSessionPairing
constructor
A new instance of PublicHostingSessionPairing.
-
#pairing_key ⇒ Object
string - One-time pairing key for the Public Hosting session.
-
#redirect_uri ⇒ Object
string - Public Hosting URL that exchanges the pairing key for a Public Hosting session cookie.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ PublicHostingSessionPairing
Returns a new instance of PublicHostingSessionPairing.
7 8 9 10 |
# File 'lib/files.com/models/public_hosting_session_pairing.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/public_hosting_session_pairing.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/public_hosting_session_pairing.rb', line 5 def @options end |
Instance Method Details
#expires_at ⇒ Object
date-time - When the pairing key expires
23 24 25 |
# File 'lib/files.com/models/public_hosting_session_pairing.rb', line 23 def expires_at @attributes[:expires_at] end |
#pairing_key ⇒ Object
string - One-time pairing key for the Public Hosting session
13 14 15 |
# File 'lib/files.com/models/public_hosting_session_pairing.rb', line 13 def pairing_key @attributes[:pairing_key] end |
#redirect_uri ⇒ Object
string - Public Hosting URL that exchanges the pairing key for a Public Hosting session cookie
18 19 20 |
# File 'lib/files.com/models/public_hosting_session_pairing.rb', line 18 def redirect_uri @attributes[:redirect_uri] end |