Class: Files::Revision

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/revision.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ Revision

Returns a new instance of Revision.



7
8
9
10
# File 'lib/files.com/models/revision.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/revision.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/revision.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



44
45
46
# File 'lib/files.com/models/revision.rb', line 44

def self.all(params = {}, options = {})
  list(params, options)
end

.create_export(params = {}, options = {}) ⇒ Object



48
49
50
51
# File 'lib/files.com/models/revision.rb', line 48

def self.create_export(params = {}, options = {})
  response, options = Api.send_request("/revisions/create_export", :post, params, options)
  Export.new(response.data, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).


35
36
37
38
39
40
41
42
# File 'lib/files.com/models/revision.rb', line 35

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(Revision, params) do
    Api.send_request("/revisions", :get, params, options)
  end
end

Instance Method Details

#currentObject

string - The commit hash of the latest deployed revision.



13
14
15
# File 'lib/files.com/models/revision.rb', line 13

def current
  @attributes[:current]
end

#priorObject

string - The commit hash of the previously deployed revision.



18
19
20
# File 'lib/files.com/models/revision.rb', line 18

def prior
  @attributes[:prior]
end

#revisionObject

string - The commit hash of the currently running revision.



23
24
25
# File 'lib/files.com/models/revision.rb', line 23

def revision
  @attributes[:revision]
end

#up_to_dateObject

boolean - True if the currently running revision is the latest deployed revision.



28
29
30
# File 'lib/files.com/models/revision.rb', line 28

def up_to_date
  @attributes[:up_to_date]
end