Class: Files::SessionAvailableSite
- Inherits:
-
Object
- Object
- Files::SessionAvailableSite
- Defined in:
- lib/files.com/models/session_available_site.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#color2_top ⇒ Object
string - Top bar background color.
-
#domain ⇒ Object
string - Custom domain.
-
#folder_permissions_groups_only ⇒ Object
boolean - If true, permissions for this site must be bound to a group (not a user).
-
#id ⇒ Object
int64 - Site Id.
-
#initialize(attributes = {}, options = {}) ⇒ SessionAvailableSite
constructor
A new instance of SessionAvailableSite.
-
#logo ⇒ Object
Image - Branded logo.
-
#name ⇒ Object
string - Site name.
-
#subdomain ⇒ Object
string - Site subdomain.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ SessionAvailableSite
Returns a new instance of SessionAvailableSite.
7 8 9 10 |
# File 'lib/files.com/models/session_available_site.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/session_available_site.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/session_available_site.rb', line 5 def @options end |
Instance Method Details
#color2_top ⇒ Object
string - Top bar background color
38 39 40 |
# File 'lib/files.com/models/session_available_site.rb', line 38 def color2_top @attributes[:color2_top] end |
#domain ⇒ Object
string - Custom domain
23 24 25 |
# File 'lib/files.com/models/session_available_site.rb', line 23 def domain @attributes[:domain] end |
#folder_permissions_groups_only ⇒ Object
boolean - If true, permissions for this site must be bound to a group (not a user).
43 44 45 |
# File 'lib/files.com/models/session_available_site.rb', line 43 def @attributes[:folder_permissions_groups_only] end |
#id ⇒ Object
int64 - Site Id
13 14 15 |
# File 'lib/files.com/models/session_available_site.rb', line 13 def id @attributes[:id] end |
#logo ⇒ Object
Image - Branded logo
33 34 35 |
# File 'lib/files.com/models/session_available_site.rb', line 33 def logo @attributes[:logo] end |
#name ⇒ Object
string - Site name
18 19 20 |
# File 'lib/files.com/models/session_available_site.rb', line 18 def name @attributes[:name] end |
#subdomain ⇒ Object
string - Site subdomain
28 29 30 |
# File 'lib/files.com/models/session_available_site.rb', line 28 def subdomain @attributes[:subdomain] end |