Class: Files::Settings

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ Settings

Returns a new instance of Settings.



7
8
9
10
# File 'lib/files.com/models/settings.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/settings.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/settings.rb', line 5

def options
  @options
end

Instance Method Details

#active_region_countObject

int64 - Number of active Storage Regions in use



663
664
665
# File 'lib/files.com/models/settings.rb', line 663

def active_region_count
  @attributes[:active_region_count]
end

#additional_text_file_typesObject

array(string) - Additional extensions that are considered text files



673
674
675
# File 'lib/files.com/models/settings.rb', line 673

def additional_text_file_types
  @attributes[:additional_text_file_types]
end

#admins_bypass_locked_subfoldersObject

boolean - Allow admins to bypass the locked subfolders setting.



668
669
670
# File 'lib/files.com/models/settings.rb', line 668

def admins_bypass_locked_subfolders
  @attributes[:admins_bypass_locked_subfolders]
end

#ai_assistant_personality_idObject

int64 - AI Assistant Personality ID for the in-app AI Assistant.



478
479
480
# File 'lib/files.com/models/settings.rb', line 478

def ai_assistant_personality_id
  @attributes[:ai_assistant_personality_id]
end

#ai_assistant_personality_system_promptObject

string - System prompt for the in-app AI Assistant.



483
484
485
# File 'lib/files.com/models/settings.rb', line 483

def ai_assistant_personality_system_prompt
  @attributes[:ai_assistant_personality_system_prompt]
end

#allow_bundle_namesObject

boolean - Are manual Bundle names allowed?



718
719
720
# File 'lib/files.com/models/settings.rb', line 718

def allow_bundle_names
  @attributes[:allow_bundle_names]
end

#allow_bypassing_2fa_policiesObject

boolean - Can users bypass 2FA policies?



93
94
95
# File 'lib/files.com/models/settings.rb', line 93

def allow_bypassing_2fa_policies
  @attributes[:allow_bypassing_2fa_policies]
end

#allow_credential_changesObject

boolean - Can partner admins manage user credentials?



98
99
100
# File 'lib/files.com/models/settings.rb', line 98

def allow_credential_changes
  @attributes[:allow_credential_changes]
end

#allow_providing_gpg_keysObject

boolean - Can partner admins provide their own GPG keys?



103
104
105
# File 'lib/files.com/models/settings.rb', line 103

def allow_providing_gpg_keys
  @attributes[:allow_providing_gpg_keys]
end

#allow_user_creationObject

boolean - Can partner admins create new users?



108
109
110
# File 'lib/files.com/models/settings.rb', line 108

def allow_user_creation
  @attributes[:allow_user_creation]
end

#allow_user_level_2fa_overrideObject

boolean - Allow the site-wide two-factor authentication requirement to be overriden on a per-user-basis?



723
724
725
# File 'lib/files.com/models/settings.rb', line 723

def allow_user_level_2fa_override
  @attributes[:allow_user_level_2fa_override]
end

#allow_user_level_allowed_ip_overrideObject

boolean - Allow the site-wide allowed IP restriction to be overriden on a per-user-basis?



733
734
735
# File 'lib/files.com/models/settings.rb', line 733

def allow_user_level_allowed_ip_override
  @attributes[:allow_user_level_allowed_ip_override]
end

#allow_user_level_ssl_overrideObject

boolean - Allow the site-wide FTP SSL requirement to be overriden on a per-user-basis?



738
739
740
# File 'lib/files.com/models/settings.rb', line 738

def allow_user_level_ssl_override
  @attributes[:allow_user_level_ssl_override]
end

#allowed_2fa_method_bypass_for_ftp_sftp_davObject

boolean - Are users allowed to configure their two factor authentication to be bypassed for FTP/SFTP/WebDAV?



683
684
685
# File 'lib/files.com/models/settings.rb', line 683

def allowed_2fa_method_bypass_for_ftp_sftp_dav
  @attributes[:allowed_2fa_method_bypass_for_ftp_sftp_dav]
end

#allowed_2fa_method_emailObject

boolean - Is OTP via email two factor authentication allowed?



708
709
710
# File 'lib/files.com/models/settings.rb', line 708

def allowed_2fa_method_email
  @attributes[:allowed_2fa_method_email]
end

#allowed_2fa_method_smsObject

boolean - Is SMS two factor authentication allowed?



688
689
690
# File 'lib/files.com/models/settings.rb', line 688

def allowed_2fa_method_sms
  @attributes[:allowed_2fa_method_sms]
end

#allowed_2fa_method_staticObject

boolean - Is OTP via static codes for two factor authentication allowed?



713
714
715
# File 'lib/files.com/models/settings.rb', line 713

def allowed_2fa_method_static
  @attributes[:allowed_2fa_method_static]
end

#allowed_2fa_method_totpObject

boolean - Is TOTP two factor authentication allowed?



693
694
695
# File 'lib/files.com/models/settings.rb', line 693

def allowed_2fa_method_totp
  @attributes[:allowed_2fa_method_totp]
end

#allowed_2fa_method_webauthnObject

boolean - Is WebAuthn two factor authentication allowed?



698
699
700
# File 'lib/files.com/models/settings.rb', line 698

def allowed_2fa_method_webauthn
  @attributes[:allowed_2fa_method_webauthn]
end

#allowed_2fa_method_yubiObject

boolean - Is yubikey two factor authentication allowed?



703
704
705
# File 'lib/files.com/models/settings.rb', line 703

def allowed_2fa_method_yubi
  @attributes[:allowed_2fa_method_yubi]
end

#attachments_permissionObject

boolean



403
404
405
# File 'lib/files.com/models/settings.rb', line 403

def attachments_permission
  @attributes[:attachments_permission]
end

#audio_regexObject

string - All supported audio types



23
24
25
# File 'lib/files.com/models/settings.rb', line 23

def audio_regex
  @attributes[:audio_regex]
end

#authentication_methodObject

string - Authentication method for the user. Can be password, sso, or none



408
409
410
# File 'lib/files.com/models/settings.rb', line 408

def authentication_method
  @attributes[:authentication_method]
end

#avatar_urlObject

string - URL holding the user's avatar



413
414
415
# File 'lib/files.com/models/settings.rb', line 413

def avatar_url
  @attributes[:avatar_url]
end

#beta_feature2Object

boolean - Is beta feature 2 available?



123
124
125
# File 'lib/files.com/models/settings.rb', line 123

def beta_feature2
  @attributes[:beta_feature2]
end

#beta_feature3Object

boolean - Is beta feature 3 available?



128
129
130
# File 'lib/files.com/models/settings.rb', line 128

def beta_feature3
  @attributes[:beta_feature3]
end

#beta_featuresObject

boolean - Is beta feature 1 available?



118
119
120
# File 'lib/files.com/models/settings.rb', line 118

def beta_features
  @attributes[:beta_features]
end

#billing_permissionObject

boolean - Allow this user to perform operations on the account, payments, and invoices?



418
419
420
# File 'lib/files.com/models/settings.rb', line 418

def billing_permission
  @attributes[:billing_permission]
end

#bundle_activity_notificationsObject

string - Do Bundle owners receive activity notifications?



753
754
755
# File 'lib/files.com/models/settings.rb', line 753

def bundle_activity_notifications
  @attributes[:bundle_activity_notifications]
end

#bundle_expirationObject

int64 - Site-wide bundle expiration in days



758
759
760
# File 'lib/files.com/models/settings.rb', line 758

def bundle_expiration
  @attributes[:bundle_expiration]
end

#bundle_not_found_messageObject

string - Custom error message to show when bundle is not found.



113
114
115
# File 'lib/files.com/models/settings.rb', line 113

def bundle_not_found_message
  @attributes[:bundle_not_found_message]
end

#bundle_password_requiredObject

boolean - Do bundle shares require password protection?



763
764
765
# File 'lib/files.com/models/settings.rb', line 763

def bundle_password_required
  @attributes[:bundle_password_required]
end

#bundle_recipient_blacklist_domainsObject

array(string) - List of domains that are not allowed for bundle and inbox recipients



748
749
750
# File 'lib/files.com/models/settings.rb', line 748

def bundle_recipient_blacklist_domains
  @attributes[:bundle_recipient_blacklist_domains]
end

#bundle_recipient_blacklist_free_email_domainsObject

boolean - Are free email domains allowed for bundle and inbox recipients?



743
744
745
# File 'lib/files.com/models/settings.rb', line 743

def bundle_recipient_blacklist_free_email_domains
  @attributes[:bundle_recipient_blacklist_free_email_domains]
end

#bundle_registration_notificationsObject

string - Do Bundle owners receive registration notification?



768
769
770
# File 'lib/files.com/models/settings.rb', line 768

def bundle_registration_notifications
  @attributes[:bundle_registration_notifications]
end

#bundle_require_noteObject

boolean - Do bundles require a note?



783
784
785
# File 'lib/files.com/models/settings.rb', line 783

def bundle_require_note
  @attributes[:bundle_require_note]
end

#bundle_require_registrationObject

boolean - Do Bundles require registration?



773
774
775
# File 'lib/files.com/models/settings.rb', line 773

def bundle_require_registration
  @attributes[:bundle_require_registration]
end

#bundle_require_share_recipientObject

boolean - Do bundles require recipients for sharing?



778
779
780
# File 'lib/files.com/models/settings.rb', line 778

def bundle_require_share_recipient
  @attributes[:bundle_require_share_recipient]
end

#bundle_upload_receipt_notificationsObject

string - Do Bundle uploaders receive upload confirmation notification?



788
789
790
# File 'lib/files.com/models/settings.rb', line 788

def bundle_upload_receipt_notifications
  @attributes[:bundle_upload_receipt_notifications]
end

#cached_permissionsObject

array(object) - All permissions applicable to this user, including permissions inherited via groups.



423
424
425
# File 'lib/files.com/models/settings.rb', line 423

def cached_permissions
  @attributes[:cached_permissions]
end

#calculate_file_checksums_crc32Object

boolean - Calculate CRC32 checksum for incoming files?



133
134
135
# File 'lib/files.com/models/settings.rb', line 133

def calculate_file_checksums_crc32
  @attributes[:calculate_file_checksums_crc32]
end

#calculate_file_checksums_md5Object

boolean - Calculate MD5 checksum for incoming files?



138
139
140
# File 'lib/files.com/models/settings.rb', line 138

def calculate_file_checksums_md5
  @attributes[:calculate_file_checksums_md5]
end

#calculate_file_checksums_sha1Object

boolean - Calculate SHA1 checksum for incoming files?



143
144
145
# File 'lib/files.com/models/settings.rb', line 143

def calculate_file_checksums_sha1
  @attributes[:calculate_file_checksums_sha1]
end

#calculate_file_checksums_sha256Object

boolean - Calculate SHA256 checksum for incoming files?



148
149
150
# File 'lib/files.com/models/settings.rb', line 148

def calculate_file_checksums_sha256
  @attributes[:calculate_file_checksums_sha256]
end

#can_admin_somewhereObject

boolean - If true, user has admin permissions somewhere on the site.



428
429
430
# File 'lib/files.com/models/settings.rb', line 428

def can_admin_somewhere
  @attributes[:can_admin_somewhere]
end

#can_bundle_somewhereObject

boolean - If true, user has bundle permissions somewhere on the site.



433
434
435
# File 'lib/files.com/models/settings.rb', line 433

def can_bundle_somewhere
  @attributes[:can_bundle_somewhere]
end

#can_write_somewhereObject

boolean - If true, user has write, full, or admin permissions somewhere on the site.



438
439
440
# File 'lib/files.com/models/settings.rb', line 438

def can_write_somewhere
  @attributes[:can_write_somewhere]
end

#child_site_count_for_planObject

int64 - Number of child sites available



793
794
795
# File 'lib/files.com/models/settings.rb', line 793

def child_site_count_for_plan
  @attributes[:child_site_count_for_plan]
end

#color2_leftObject

string - Page link and button color



153
154
155
# File 'lib/files.com/models/settings.rb', line 153

def color2_left
  @attributes[:color2_left]
end

string - Top bar link color



158
159
160
# File 'lib/files.com/models/settings.rb', line 158

def color2_link
  @attributes[:color2_link]
end

#color2_textObject

string - Page link and button color



163
164
165
# File 'lib/files.com/models/settings.rb', line 163

def color2_text
  @attributes[:color2_text]
end

#color2_topObject

string - Top bar background color



168
169
170
# File 'lib/files.com/models/settings.rb', line 168

def color2_top
  @attributes[:color2_top]
end

#color2_top_textObject

string - Top bar text color



173
174
175
# File 'lib/files.com/models/settings.rb', line 173

def color2_top_text
  @attributes[:color2_top_text]
end

#current_languageObject

string - Current language locale setting



33
34
35
# File 'lib/files.com/models/settings.rb', line 33

def current_language
  @attributes[:current_language]
end

#current_timeObject

date-time - Current Time in UTC



38
39
40
# File 'lib/files.com/models/settings.rb', line 38

def current_time
  @attributes[:current_time]
end

#dav_permissionObject

boolean - Can the user connect with WebDAV?



443
444
445
# File 'lib/files.com/models/settings.rb', line 443

def dav_permission
  @attributes[:dav_permission]
end

#days_remaining_until_password_expireObject

int64 - Number of days remaining until password expires



448
449
450
# File 'lib/files.com/models/settings.rb', line 448

def days_remaining_until_password_expire
  @attributes[:days_remaining_until_password_expire]
end

#default_workspace_idObject

int64 - Workspace ID the user should land in by default when more than one Workspace is available.



238
239
240
# File 'lib/files.com/models/settings.rb', line 238

def default_workspace_id
  @attributes[:default_workspace_id]
end

#desktop_appObject

boolean - Is the desktop app enabled?



798
799
800
# File 'lib/files.com/models/settings.rb', line 798

def desktop_app
  @attributes[:desktop_app]
end

#desktop_drive_mappingsObject

object - Mappings from drive letters to paths for the desktop application.



213
214
215
# File 'lib/files.com/models/settings.rb', line 213

def desktop_drive_mappings
  @attributes[:desktop_drive_mappings]
end

#disable_drive_mountingObject

boolean - Whether the desktop app should hide drive mounting, prevent new drive mounts, and unmount active drive mounts.



208
209
210
# File 'lib/files.com/models/settings.rb', line 208

def disable_drive_mounting
  @attributes[:disable_drive_mounting]
end

#disable_password_resetObject

boolean - Is password reset disabled?



188
189
190
# File 'lib/files.com/models/settings.rb', line 188

def disable_password_reset
  @attributes[:disable_password_reset]
end

#document_edits_in_bundle_allowedObject

boolean - If true, allow public viewers of Bundles with full permissions to use document editing integrations.



178
179
180
# File 'lib/files.com/models/settings.rb', line 178

def document_edits_in_bundle_allowed
  @attributes[:document_edits_in_bundle_allowed]
end

#domainObject

string - Custom domain



183
184
185
# File 'lib/files.com/models/settings.rb', line 183

def domain
  @attributes[:domain]
end

#emailObject

email - User email address



453
454
455
# File 'lib/files.com/models/settings.rb', line 453

def email
  @attributes[:email]
end

string - Custom footer text for system-generated emails. Supports strftime patterns like %Y (4-digit year), %m (month), %d (day).



313
314
315
# File 'lib/files.com/models/settings.rb', line 313

def email_footer_custom_text_markdown
  @attributes[:email_footer_custom_text_markdown]
end

#exavault_api_availableObject

boolean - Is legacy ExaVault API Available?



803
804
805
# File 'lib/files.com/models/settings.rb', line 803

def exavault_api_available
  @attributes[:exavault_api_available]
end

#externally_managedObject

boolean - Is this user automatically managed?



598
599
600
# File 'lib/files.com/models/settings.rb', line 598

def externally_managed
  @attributes[:externally_managed]
end

#feature_bundle_ecaObject

boolean - Does the site's plan include the ECA Feature bundle?



808
809
810
# File 'lib/files.com/models/settings.rb', line 808

def feature_bundle_eca
  @attributes[:feature_bundle_eca]
end

#feature_bundle_powerObject

boolean - Does the site's plan include the Power Feature bundle?



813
814
815
# File 'lib/files.com/models/settings.rb', line 813

def feature_bundle_power
  @attributes[:feature_bundle_power]
end

#feature_bundle_premierObject

boolean - Does the site's plan include the Enterprise Feature bundle?



818
819
820
# File 'lib/files.com/models/settings.rb', line 818

def feature_bundle_premier
  @attributes[:feature_bundle_premier]
end

#file_transform_capabilitiesObject

object - Supported file transform input and output formats



488
489
490
# File 'lib/files.com/models/settings.rb', line 488

def file_transform_capabilities
  @attributes[:file_transform_capabilities]
end

#folder_permissions_groups_onlyObject

boolean - If true, permissions for this site must be bound to a group (not a user).



823
824
825
# File 'lib/files.com/models/settings.rb', line 823

def folder_permissions_groups_only
  @attributes[:folder_permissions_groups_only]
end

#ftp_permissionObject

boolean - Can the user access with FTP/FTPS?



458
459
460
# File 'lib/files.com/models/settings.rb', line 458

def ftp_permission
  @attributes[:ftp_permission]
end

#group_adminObject

boolean - Is a group administrator?



463
464
465
# File 'lib/files.com/models/settings.rb', line 463

def group_admin
  @attributes[:group_admin]
end

#group_admins_can_add_usersObject

boolean - Allow group admins to create users in their groups



828
829
830
# File 'lib/files.com/models/settings.rb', line 828

def group_admins_can_add_users
  @attributes[:group_admins_can_add_users]
end

#group_admins_can_bypass_user_lifecycle_rulesObject

boolean - Allow group admins to exempt users in their groups from lifecycle rules



848
849
850
# File 'lib/files.com/models/settings.rb', line 848

def group_admins_can_bypass_user_lifecycle_rules
  @attributes[:group_admins_can_bypass_user_lifecycle_rules]
end

#group_admins_can_delete_usersObject

boolean - Allow group admins to delete users in their groups



833
834
835
# File 'lib/files.com/models/settings.rb', line 833

def group_admins_can_delete_users
  @attributes[:group_admins_can_delete_users]
end

#group_admins_can_enable_disable_usersObject

boolean - Allow group admins to enable or disable users in their groups



838
839
840
# File 'lib/files.com/models/settings.rb', line 838

def group_admins_can_enable_disable_users
  @attributes[:group_admins_can_enable_disable_users]
end

#group_admins_can_modify_usersObject

boolean - Allow group admins to modify users in their groups



843
844
845
# File 'lib/files.com/models/settings.rb', line 843

def group_admins_can_modify_users
  @attributes[:group_admins_can_modify_users]
end

#group_admins_can_reset_passwordsObject

boolean - Allow group admins to reset passwords for users in their groups



853
854
855
# File 'lib/files.com/models/settings.rb', line 853

def group_admins_can_reset_passwords
  @attributes[:group_admins_can_reset_passwords]
end

#group_admins_can_set_user_passwordObject

boolean - Allow group admins set password authentication method



858
859
860
# File 'lib/files.com/models/settings.rb', line 858

def group_admins_can_set_user_password
  @attributes[:group_admins_can_set_user_password]
end

#has_accessible_gpg_keysObject

boolean - True if the current user has access to any GPG keys.



233
234
235
# File 'lib/files.com/models/settings.rb', line 233

def has_accessible_gpg_keys
  @attributes[:has_accessible_gpg_keys]
end

#has_accountObject

boolean - Connected to an account?



863
864
865
# File 'lib/files.com/models/settings.rb', line 863

def 
  @attributes[:has_account]
end

#has_workspacesObject

boolean - True if the current user can access any named Workspaces (id > 0).



228
229
230
# File 'lib/files.com/models/settings.rb', line 228

def has_workspaces
  @attributes[:has_workspaces]
end

#header_textObject

string - Text to display to the user in the header of the UI



468
469
470
# File 'lib/files.com/models/settings.rb', line 468

def header_text
  @attributes[:header_text]
end

#hide_billingObject

boolean - Hide billing information?



868
869
870
# File 'lib/files.com/models/settings.rb', line 868

def hide_billing
  @attributes[:hide_billing]
end

#high_users_countObject

boolean - Does the site have a large number of users? (Used to hide some UI features that may be slow in this case.)



873
874
875
# File 'lib/files.com/models/settings.rb', line 873

def high_users_count
  @attributes[:high_users_count]
end

#history_unavailableObject

boolean - Is history unavailable?



878
879
880
# File 'lib/files.com/models/settings.rb', line 878

def history_unavailable
  @attributes[:history_unavailable]
end

#icon128Object

Image - Branded icon 128x128



363
364
365
# File 'lib/files.com/models/settings.rb', line 363

def icon128
  @attributes[:icon128]
end

#icon16Object

Image - Branded icon 16x16



368
369
370
# File 'lib/files.com/models/settings.rb', line 368

def icon16
  @attributes[:icon16]
end

#icon32Object

Image - Branded icon 32x32



373
374
375
# File 'lib/files.com/models/settings.rb', line 373

def icon32
  @attributes[:icon32]
end

#icon48Object

Image - Branded icon 48x48



378
379
380
# File 'lib/files.com/models/settings.rb', line 378

def icon48
  @attributes[:icon48]
end

#idObject

int64 - User ID



493
494
495
# File 'lib/files.com/models/settings.rb', line 493

def id
  @attributes[:id]
end

#image_regexObject

string - All supported image types



13
14
15
# File 'lib/files.com/models/settings.rb', line 13

def image_regex
  @attributes[:image_regex]
end

#immutable_filesObject

boolean - Are files protected from modification?



883
884
885
# File 'lib/files.com/models/settings.rb', line 883

def immutable_files
  @attributes[:immutable_files]
end

#impersonator_user_idObject

int64 - User ID of the Site Admin who initiated a Read-Only session impersonating this session's user



1068
1069
1070
# File 'lib/files.com/models/settings.rb', line 1068

def impersonator_user_id
  @attributes[:impersonator_user_id]
end

#in_app_ai_assistant_availableObject

boolean - Is the in-app AI assistant available to the current user?



473
474
475
# File 'lib/files.com/models/settings.rb', line 473

def in_app_ai_assistant_available
  @attributes[:in_app_ai_assistant_available]
end

#intersitial_pageObject

string - Intersitial page to show



888
889
890
# File 'lib/files.com/models/settings.rb', line 888

def intersitial_page
  @attributes[:intersitial_page]
end

#is_child_siteObject

boolean - Is this a child site?



893
894
895
# File 'lib/files.com/models/settings.rb', line 893

def is_child_site
  @attributes[:is_child_site]
end

#last_read_announcements_atObject

date-time - The last date/time this user has read announcements



498
499
500
# File 'lib/files.com/models/settings.rb', line 498

def last_read_announcements_at
  @attributes[:last_read_announcements_at]
end

#left_navigation_visibilityObject

object - Visibility settings for account navigation



898
899
900
# File 'lib/files.com/models/settings.rb', line 898

def left_navigation_visibility
  @attributes[:left_navigation_visibility]
end

#legacy_checksums_modeObject

boolean - Use legacy checksums mode?



243
244
245
# File 'lib/files.com/models/settings.rb', line 243

def legacy_checksums_mode
  @attributes[:legacy_checksums_mode]
end

#linode_regionsObject

array(object) - Region name and description



43
44
45
# File 'lib/files.com/models/settings.rb', line 43

def linode_regions
  @attributes[:linode_regions]
end

#login_clickwrap_bodyObject

string - Clickwrap body text to show on every web login.



193
194
195
# File 'lib/files.com/models/settings.rb', line 193

def 
  @attributes[:login_clickwrap_body]
end

#login_help_textObject

string - Login help text (as HTML). Unsafe! Deprecated! Do Not Use!



248
249
250
# File 'lib/files.com/models/settings.rb', line 248

def 
  @attributes[:login_help_text]
end

#login_help_text_markdownObject

string - Login help text (as Markdown)



253
254
255
# File 'lib/files.com/models/settings.rb', line 253

def 
  @attributes[:login_help_text_markdown]
end

#login_page_background_imageObject

Image - Branded login page background



388
389
390
# File 'lib/files.com/models/settings.rb', line 388

def 
  @attributes[:login_page_background_image]
end

#login_page_background_image_thumbnailObject

Image - Branded login page background thumbnail



398
399
400
# File 'lib/files.com/models/settings.rb', line 398

def 
  @attributes[:login_page_background_image_thumbnail]
end

#logoObject

Image - Branded logo



383
384
385
# File 'lib/files.com/models/settings.rb', line 383

def 
  @attributes[:logo]
end

#logo_thumbnailObject

Image - Branded Logo thumbnail



393
394
395
# File 'lib/files.com/models/settings.rb', line 393

def logo_thumbnail
  @attributes[:logo_thumbnail]
end

#migrate_remote_server_sync_to_syncObject

boolean - If true, we will migrate all remote server syncs to the new Sync model.



1053
1054
1055
# File 'lib/files.com/models/settings.rb', line 1053

def migrate_remote_server_sync_to_sync
  @attributes[:migrate_remote_server_sync_to_sync]
end

#min_remote_sync_intervalObject

int64 - Minimum remote server sync interval allowed by plan (in minutes)



903
904
905
# File 'lib/files.com/models/settings.rb', line 903

def min_remote_sync_interval
  @attributes[:min_remote_sync_interval]
end

#nameObject

string - User name



503
504
505
# File 'lib/files.com/models/settings.rb', line 503

def name
  @attributes[:name]
end

#non_sso_groups_allowedObject

boolean - If true, groups can be manually created / modified / deleted by Site Admins. Otherwise, groups can only be managed via your SSO provider.



908
909
910
# File 'lib/files.com/models/settings.rb', line 908

def non_sso_groups_allowed
  @attributes[:non_sso_groups_allowed]
end

#non_sso_users_allowedObject

boolean - If true, users can be manually created / modified / deleted by Site Admins. Otherwise, users can only be managed via your SSO provider.



913
914
915
# File 'lib/files.com/models/settings.rb', line 913

def non_sso_users_allowed
  @attributes[:non_sso_users_allowed]
end

#notification_daily_send_timeObject

int64 - Hour of the day at which daily notifications should be sent. Can be in range 0 to 23



508
509
510
# File 'lib/files.com/models/settings.rb', line 508

def notification_daily_send_time
  @attributes[:notification_daily_send_time]
end

#notify_on_all_automation_failuresObject

boolean - Should the user receive automation failures via email?



543
544
545
# File 'lib/files.com/models/settings.rb', line 543

def notify_on_all_automation_failures
  @attributes[:notify_on_all_automation_failures]
end

#notify_on_all_expectation_failuresObject

boolean - Should the user receive expectation failures and misses via email?



548
549
550
# File 'lib/files.com/models/settings.rb', line 548

def notify_on_all_expectation_failures
  @attributes[:notify_on_all_expectation_failures]
end

#notify_on_all_pending_work_failuresObject

boolean - Should the user receive pending work failures via email?



528
529
530
# File 'lib/files.com/models/settings.rb', line 528

def notify_on_all_pending_work_failures
  @attributes[:notify_on_all_pending_work_failures]
end

#notify_on_all_siem_http_destination_failuresObject

boolean - Should the user receive siem failures via email?



533
534
535
# File 'lib/files.com/models/settings.rb', line 533

def notify_on_all_siem_http_destination_failures
  @attributes[:notify_on_all_siem_http_destination_failures]
end

#notify_on_all_site_warningsObject

boolean - Should the user receive site warnings via email?



513
514
515
# File 'lib/files.com/models/settings.rb', line 513

def notify_on_all_site_warnings
  @attributes[:notify_on_all_site_warnings]
end

#notify_on_all_sso_failuresObject

boolean - Should the user receive sso/scim/ldap configuration/sync failures via email?



518
519
520
# File 'lib/files.com/models/settings.rb', line 518

def notify_on_all_sso_failures
  @attributes[:notify_on_all_sso_failures]
end

#notify_on_all_sync_failuresObject

boolean - Should the user receive sync failures via email?



538
539
540
# File 'lib/files.com/models/settings.rb', line 538

def notify_on_all_sync_failures
  @attributes[:notify_on_all_sync_failures]
end

#notify_on_all_user_security_eventsObject

boolean - Should the user receive user security events via email?



523
524
525
# File 'lib/files.com/models/settings.rb', line 523

def notify_on_all_user_security_events
  @attributes[:notify_on_all_user_security_events]
end

#nps_response_requestedObject

boolean - Has the user been asked to respond to an NPS survey?



658
659
660
# File 'lib/files.com/models/settings.rb', line 658

def nps_response_requested
  @attributes[:nps_response_requested]
end

#office_integration_availableObject

boolean - If true, allows users to use a document editing integration.



283
284
285
# File 'lib/files.com/models/settings.rb', line 283

def office_integration_available
  @attributes[:office_integration_available]
end

#office_integration_enabledObject

boolean - If true, allows users to use a document editing integration.



268
269
270
# File 'lib/files.com/models/settings.rb', line 268

def office_integration_enabled
  @attributes[:office_integration_enabled]
end

#office_integration_hostObject

string - Document editing integration hostname for API calls.



273
274
275
# File 'lib/files.com/models/settings.rb', line 273

def office_integration_host
  @attributes[:office_integration_host]
end

#office_integration_typeObject

string - Which document editing integration to support. Files.com Editor or Microsoft Office for the Web.



263
264
265
# File 'lib/files.com/models/settings.rb', line 263

def office_integration_type
  @attributes[:office_integration_type]
end

string - Link to scheduling a meeting with our Sales team



278
279
280
# File 'lib/files.com/models/settings.rb', line 278

def oncehub_link
  @attributes[:oncehub_link]
end

#overdueObject

boolean - Is billing overdue?



918
919
920
# File 'lib/files.com/models/settings.rb', line 918

def overdue
  @attributes[:overdue]
end

#partner_adminObject

boolean - Is this user a Partner administrator?



553
554
555
# File 'lib/files.com/models/settings.rb', line 553

def partner_admin
  @attributes[:partner_admin]
end

#partner_idObject

int64 - Partner ID, if applicable.



563
564
565
# File 'lib/files.com/models/settings.rb', line 563

def partner_id
  @attributes[:partner_id]
end

#password_min_lengthObject

int64 - Shortest password length for users



928
929
930
# File 'lib/files.com/models/settings.rb', line 928

def password_min_length
  @attributes[:password_min_length]
end

#password_require_letterObject

boolean - Require a letter in passwords?



933
934
935
# File 'lib/files.com/models/settings.rb', line 933

def password_require_letter
  @attributes[:password_require_letter]
end

#password_require_mixedObject

boolean - Require lower and upper case letters in passwords?



938
939
940
# File 'lib/files.com/models/settings.rb', line 938

def password_require_mixed
  @attributes[:password_require_mixed]
end

#password_require_numberObject

boolean - Require a number in passwords?



943
944
945
# File 'lib/files.com/models/settings.rb', line 943

def password_require_number
  @attributes[:password_require_number]
end

#password_require_specialObject

boolean - Require special characters in password?



948
949
950
# File 'lib/files.com/models/settings.rb', line 948

def password_require_special
  @attributes[:password_require_special]
end

#password_require_unbreachedObject

boolean - Require passwords that have not been previously breached? (see https://haveibeenpwned.com/)



953
954
955
# File 'lib/files.com/models/settings.rb', line 953

def password_require_unbreached
  @attributes[:password_require_unbreached]
end

#password_requirements_apply_to_bundlesObject

boolean - Do site-wide password requirements apply to bundles?



958
959
960
# File 'lib/files.com/models/settings.rb', line 958

def password_requirements_apply_to_bundles
  @attributes[:password_requirements_apply_to_bundles]
end

#pdf_regexObject

string - All supported PDF types



28
29
30
# File 'lib/files.com/models/settings.rb', line 28

def pdf_regex
  @attributes[:pdf_regex]
end

#pending_clickwrap_bodyObject

string - Body of clickwrap the user must accept.



203
204
205
# File 'lib/files.com/models/settings.rb', line 203

def pending_clickwrap_body
  @attributes[:pending_clickwrap_body]
end

#pending_clickwrap_idObject

int64 - ID of clickwrap the user must accept.



198
199
200
# File 'lib/files.com/models/settings.rb', line 198

def pending_clickwrap_id
  @attributes[:pending_clickwrap_id]
end

#plan_as2_includedObject

boolean - Does current plan include AS2 functionality?



963
964
965
# File 'lib/files.com/models/settings.rb', line 963

def plan_as2_included
  @attributes[:plan_as2_included]
end

#prevent_root_permissions_for_non_site_adminsObject

boolean - Prevent regular users to be granted with root folder permissions



968
969
970
# File 'lib/files.com/models/settings.rb', line 968

def prevent_root_permissions_for_non_site_admins
  @attributes[:prevent_root_permissions_for_non_site_admins]
end

#primary_group_idObject

int64 - Primary group ID for Group Admin scoping



558
559
560
# File 'lib/files.com/models/settings.rb', line 558

def primary_group_id
  @attributes[:primary_group_id]
end

#primary_sub_domain_baseObject

string - Primary domain name base of the site



53
54
55
# File 'lib/files.com/models/settings.rb', line 53

def primary_sub_domain_base
  @attributes[:primary_sub_domain_base]
end

#protocol_access_groups_onlyObject

boolean - If true, protocol access permissions on users will be ignored, and only protocol access permissions set on Groups will be honored. Make sure that your current user is a member of a group with API permission when changing this value to avoid locking yourself out of your site.



973
974
975
# File 'lib/files.com/models/settings.rb', line 973

def protocol_access_groups_only
  @attributes[:protocol_access_groups_only]
end

#public_sharing_allowedObject

boolean - Is public sharing allowed?



983
984
985
# File 'lib/files.com/models/settings.rb', line 983

def public_sharing_allowed
  @attributes[:public_sharing_allowed]
end

#public_urlObject

string - Site public url



978
979
980
# File 'lib/files.com/models/settings.rb', line 978

def public_url
  @attributes[:public_url]
end

#read_onlyObject

boolean - Is this session read only?



58
59
60
# File 'lib/files.com/models/settings.rb', line 58

def read_only
  @attributes[:read_only]
end

#readonly_site_adminObject

boolean - Is the user a read-only administrator for this site?



588
589
590
# File 'lib/files.com/models/settings.rb', line 588

def readonly_site_admin
  @attributes[:readonly_site_admin]
end

#reauthObject

boolean - Password check skipped?



63
64
65
# File 'lib/files.com/models/settings.rb', line 63

def reauth
  @attributes[:reauth]
end

#reauth_2faObject

string - 2fa type



613
614
615
# File 'lib/files.com/models/settings.rb', line 613

def reauth_2fa
  @attributes[:reauth_2fa]
end

#regionsObject

array(object) - Region name and description



68
69
70
# File 'lib/files.com/models/settings.rb', line 68

def regions
  @attributes[:regions]
end

#remote_desktop_debug_logging_enabledObject

boolean - Whether remote desktop debug log upload is enabled for this user.



218
219
220
# File 'lib/files.com/models/settings.rb', line 218

def remote_desktop_debug_logging_enabled
  @attributes[:remote_desktop_debug_logging_enabled]
end

#remote_desktop_debug_logging_expires_atObject

date-time - When remote desktop debug logging expires for this user.



223
224
225
# File 'lib/files.com/models/settings.rb', line 223

def remote_desktop_debug_logging_expires_at
  @attributes[:remote_desktop_debug_logging_expires_at]
end

#require_2faObject

boolean - Require two-factor authentication for the current user?



988
989
990
# File 'lib/files.com/models/settings.rb', line 988

def require_2fa
  @attributes[:require_2fa]
end

#require_2fa_exempt_all_sso_usersObject

boolean - If true, SSO users using the default user-level two-factor authentication setting are exempt from the site-wide two-factor authentication requirement.



728
729
730
# File 'lib/files.com/models/settings.rb', line 728

def require_2fa_exempt_all_sso_users
  @attributes[:require_2fa_exempt_all_sso_users]
end

#require_logout_from_bundles_and_inboxesObject

boolean - If true, we will hide the 'Remember Me' box on Inbox and Bundle registration pages, requiring that the user logout and log back in every time they visit the page.



288
289
290
# File 'lib/files.com/models/settings.rb', line 288

def require_logout_from_bundles_and_inboxes
  @attributes[:require_logout_from_bundles_and_inboxes]
end

#revoke_bundle_access_on_disable_or_deleteObject

boolean - Auto-removes bundles for disabled/deleted users and enforces bundle expiry within user access period.



998
999
1000
# File 'lib/files.com/models/settings.rb', line 998

def revoke_bundle_access_on_disable_or_delete
  @attributes[:revoke_bundle_access_on_disable_or_delete]
end

#root_folder_restrictedObject

boolean - Does this user use a File System Layout that restricts creating Files, Folders, or Settings in the Root Folder?



568
569
570
# File 'lib/files.com/models/settings.rb', line 568

def root_folder_restricted
  @attributes[:root_folder_restricted]
end

#root_regionObject

string - Root region of site. Used for SSL certificate termination, IP Address assignment, and regional pinning of remote servers. If blank, assume us-east-1.



993
994
995
# File 'lib/files.com/models/settings.rb', line 993

def root_region
  @attributes[:root_region]
end

#s3_regionsObject

array(object) - Region name and description



73
74
75
# File 'lib/files.com/models/settings.rb', line 73

def s3_regions
  @attributes[:s3_regions]
end

#sales_tax_regionsObject

array(object) - States with applicable sales tax



78
79
80
# File 'lib/files.com/models/settings.rb', line 78

def sales_tax_regions
  @attributes[:sales_tax_regions]
end

#self_managedObject

boolean - Does this user manage it's own credentials?



573
574
575
# File 'lib/files.com/models/settings.rb', line 573

def self_managed
  @attributes[:self_managed]
end

#self_signup_eligibleObject

boolean - Is self signup available?



293
294
295
# File 'lib/files.com/models/settings.rb', line 293

def 
  @attributes[:self_signup_eligible]
end

#session_available_sitesObject

array(object) - All sites that this user has access to.



1063
1064
1065
# File 'lib/files.com/models/settings.rb', line 1063

def session_available_sites
  @attributes[:session_available_sites]
end

#session_languageObject

string - Session locale setting



83
84
85
# File 'lib/files.com/models/settings.rb', line 83

def session_language
  @attributes[:session_language]
end

#sftp_permissionObject

boolean - Can the user access with SFTP?



578
579
580
# File 'lib/files.com/models/settings.rb', line 578

def sftp_permission
  @attributes[:sftp_permission]
end

#sharing_enabledObject

boolean - Allow bundle creation



1003
1004
1005
# File 'lib/files.com/models/settings.rb', line 1003

def sharing_enabled
  @attributes[:sharing_enabled]
end

boolean - Show request access link for users without access?



298
299
300
# File 'lib/files.com/models/settings.rb', line 298

def show_request_access_link
  @attributes[:show_request_access_link]
end

#site_adminObject

boolean - Is the user an administrator for this site?



583
584
585
# File 'lib/files.com/models/settings.rb', line 583

def site_admin
  @attributes[:site_admin]
end

string - Site footer for branding (as Markdown) on authenticated (logged-in) user pages



303
304
305
# File 'lib/files.com/models/settings.rb', line 303

def site_footer_markdown
  @attributes[:site_footer_markdown]
end

#site_header_markdownObject

string - Site header for branding (as Markdown) on authenticated (logged-in) user pages



308
309
310
# File 'lib/files.com/models/settings.rb', line 308

def site_header_markdown
  @attributes[:site_header_markdown]
end

#site_idObject

int64 - Site ID



333
334
335
# File 'lib/files.com/models/settings.rb', line 333

def site_id
  @attributes[:site_id]
end

#site_languageObject

string - Site language locale



328
329
330
# File 'lib/files.com/models/settings.rb', line 328

def site_language
  @attributes[:site_language]
end

#site_nameObject

string - Site name



258
259
260
# File 'lib/files.com/models/settings.rb', line 258

def site_name
  @attributes[:site_name]
end

string - Site footer for branding (as Markdown) on public (unauthenticated) pages.



323
324
325
# File 'lib/files.com/models/settings.rb', line 323

def site_public_footer_markdown
  @attributes[:site_public_footer_markdown]
end

#site_public_header_markdownObject

string - Site header for branding (as Markdown) on public (unauthenticated) pages.



318
319
320
# File 'lib/files.com/models/settings.rb', line 318

def site_public_header_markdown
  @attributes[:site_public_header_markdown]
end

#site_unavailableObject

boolean - Is the site unavailable?



923
924
925
# File 'lib/files.com/models/settings.rb', line 923

def site_unavailable
  @attributes[:site_unavailable]
end

#skip_welcome_screenObject

boolean - Skip the welcome screen?



593
594
595
# File 'lib/files.com/models/settings.rb', line 593

def skip_welcome_screen
  @attributes[:skip_welcome_screen]
end

#snapshot_sharing_enabledObject

boolean - Allow snapshot bundle creation



1008
1009
1010
# File 'lib/files.com/models/settings.rb', line 1008

def snapshot_sharing_enabled
  @attributes[:snapshot_sharing_enabled]
end

#sso_strategiesObject

SsoStrategy - SSO strategies in use



338
339
340
# File 'lib/files.com/models/settings.rb', line 338

def sso_strategies
  @attributes[:sso_strategies]
end

#staging_site_count_for_planObject

int64 - Number of child sites available



1013
1014
1015
# File 'lib/files.com/models/settings.rb', line 1013

def staging_site_count_for_plan
  @attributes[:staging_site_count_for_plan]
end

#subdomainObject

string - Site subdomain



343
344
345
# File 'lib/files.com/models/settings.rb', line 343

def subdomain
  @attributes[:subdomain]
end

#tab_configObject

string - Deprecated



88
89
90
# File 'lib/files.com/models/settings.rb', line 88

def tab_config
  @attributes[:tab_config]
end

#text_preview_extensionsObject

array(string) - Extensions that are treated as text previews.



678
679
680
# File 'lib/files.com/models/settings.rb', line 678

def text_preview_extensions
  @attributes[:text_preview_extensions]
end

#time_zoneObject

string - User time zone



603
604
605
# File 'lib/files.com/models/settings.rb', line 603

def time_zone
  @attributes[:time_zone]
end

#trial_days_leftObject

int64 - Number of days left in trial



1023
1024
1025
# File 'lib/files.com/models/settings.rb', line 1023

def trial_days_left
  @attributes[:trial_days_left]
end

#trial_flagged_as_duplicateObject

boolean - Has this site been flagged as a duplicate of another trial?



1018
1019
1020
# File 'lib/files.com/models/settings.rb', line 1018

def trial_flagged_as_duplicate
  @attributes[:trial_flagged_as_duplicate]
end

#trial_lockedObject

boolean - Is this site a free trial that is locked due to fraud concerns?



1028
1029
1030
# File 'lib/files.com/models/settings.rb', line 1028

def trial_locked
  @attributes[:trial_locked]
end

#trial_untilObject

date-time - When does this Site trial expire?



1033
1034
1035
# File 'lib/files.com/models/settings.rb', line 1033

def trial_until
  @attributes[:trial_until]
end

#type_of_2faObject

string - 2fa type



608
609
610
# File 'lib/files.com/models/settings.rb', line 608

def type_of_2fa
  @attributes[:type_of_2fa]
end

#usage_includedObject

int64 - Usage included in site's plan, in GB



1038
1039
1040
# File 'lib/files.com/models/settings.rb', line 1038

def usage_included
  @attributes[:usage_included]
end

#use_provided_modified_atObject

boolean - Allow setting provided_modified_at?



348
349
350
# File 'lib/files.com/models/settings.rb', line 348

def use_provided_modified_at
  @attributes[:use_provided_modified_at]
end

#user_idObject

int64 - User ID



618
619
620
# File 'lib/files.com/models/settings.rb', line 618

def user_id
  @attributes[:user_id]
end

#user_languageObject

string - Preferred language



623
624
625
# File 'lib/files.com/models/settings.rb', line 623

def user_language
  @attributes[:user_language]
end

#user_login_urlObject

string - URL where this user can login



628
629
630
# File 'lib/files.com/models/settings.rb', line 628

def 
  @attributes[:user_login_url]
end

#user_requests_enabledObject

boolean - Is the user requests feature enabled?



353
354
355
# File 'lib/files.com/models/settings.rb', line 353

def user_requests_enabled
  @attributes[:user_requests_enabled]
end

#user_rootObject

string - User filesystem root



633
634
635
# File 'lib/files.com/models/settings.rb', line 633

def user_root
  @attributes[:user_root]
end

#usernameObject

string - User's username



638
639
640
# File 'lib/files.com/models/settings.rb', line 638

def username
  @attributes[:username]
end

#users_can_create_api_keysObject

boolean - Allow users to create their own API keys?



1043
1044
1045
# File 'lib/files.com/models/settings.rb', line 1043

def users_can_create_api_keys
  @attributes[:users_can_create_api_keys]
end

#users_can_create_ssh_keysObject

boolean - Allow users to create their own SSH keys?



1048
1049
1050
# File 'lib/files.com/models/settings.rb', line 1048

def users_can_create_ssh_keys
  @attributes[:users_can_create_ssh_keys]
end

#users_countObject

int64 - Count of users on the site. Only exposed for site admins.



1058
1059
1060
# File 'lib/files.com/models/settings.rb', line 1058

def users_count
  @attributes[:users_count]
end

#video_regexObject

string - All supported video types



18
19
20
# File 'lib/files.com/models/settings.rb', line 18

def video_regex
  @attributes[:video_regex]
end

#wasabi_regionsObject

array(object) - Region name and description



48
49
50
# File 'lib/files.com/models/settings.rb', line 48

def wasabi_regions
  @attributes[:wasabi_regions]
end

#web_rootObject

string - Root web folder



643
644
645
# File 'lib/files.com/models/settings.rb', line 643

def web_root
  @attributes[:web_root]
end

#welcome_screenObject

string - Does the welcome screen appear? Can be enabled, hidden, or disabled



358
359
360
# File 'lib/files.com/models/settings.rb', line 358

def welcome_screen
  @attributes[:welcome_screen]
end

#workspace_adminObject

boolean - Is the user a Workspace administrator?



648
649
650
# File 'lib/files.com/models/settings.rb', line 648

def workspace_admin
  @attributes[:workspace_admin]
end

#workspace_scopedObject

boolean - Is the current response scoped to a specific workspace?



653
654
655
# File 'lib/files.com/models/settings.rb', line 653

def workspace_scoped
  @attributes[:workspace_scoped]
end