Class: Files::SslCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/ssl_certificate.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ SslCertificate

Returns a new instance of SslCertificate.



7
8
9
10
# File 'lib/files.com/models/ssl_certificate.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/ssl_certificate.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/ssl_certificate.rb', line 5

def options
  @options
end

Instance Method Details

#certificateObject

string - The text of the certificate itself.



18
19
20
# File 'lib/files.com/models/ssl_certificate.rb', line 18

def certificate
  @attributes[:certificate]
end

#domain_hsts_headerObject

boolean - True if a HSTS header should be rendered for the site



43
44
45
# File 'lib/files.com/models/ssl_certificate.rb', line 43

def domain_hsts_header
  @attributes[:domain_hsts_header]
end

#domainsObject

array(string) - Domains associated with this certificate.



73
74
75
# File 'lib/files.com/models/ssl_certificate.rb', line 73

def domains
  @attributes[:domains]
end

#ftps_enabledObject

boolean - Whether or not this certificate can be used for FTPS.



48
49
50
# File 'lib/files.com/models/ssl_certificate.rb', line 48

def ftps_enabled
  @attributes[:ftps_enabled]
end

#https_enabledObject

boolean - Whether or not this certificate can be used for HTTPS. Always true.



53
54
55
# File 'lib/files.com/models/ssl_certificate.rb', line 53

def https_enabled
  @attributes[:https_enabled]
end

#idObject

int64 - ID of the site associated with this certificate, including group id if available.



38
39
40
# File 'lib/files.com/models/ssl_certificate.rb', line 38

def id
  @attributes[:id]
end

#intermediatesObject

string - Intermediate certificates, if available.



33
34
35
# File 'lib/files.com/models/ssl_certificate.rb', line 33

def intermediates
  @attributes[:intermediates]
end

#keyObject

object - Private key encrypted with our secret key.



28
29
30
# File 'lib/files.com/models/ssl_certificate.rb', line 28

def key
  @attributes[:key]
end

#nameObject

string - The name of the site associated with this SSL certificate.



13
14
15
# File 'lib/files.com/models/ssl_certificate.rb', line 13

def name
  @attributes[:name]
end

#private_keyObject

string - Private key used to generate the certificate.



23
24
25
# File 'lib/files.com/models/ssl_certificate.rb', line 23

def private_key
  @attributes[:private_key]
end

#sftp_insecure_ciphersObject

boolean - True if the site associated with this certificate has the "Allow Insecure SFTP Ciphers" feature turned on.



58
59
60
# File 'lib/files.com/models/ssl_certificate.rb', line 58

def sftp_insecure_ciphers
  @attributes[:sftp_insecure_ciphers]
end

#subdomainObject

string - Site subdomain.



68
69
70
# File 'lib/files.com/models/ssl_certificate.rb', line 68

def subdomain
  @attributes[:subdomain]
end

#tls_disabledObject

boolean - True if the site associated with this certificate has the "Security Opt Out" feature turned on.



63
64
65
# File 'lib/files.com/models/ssl_certificate.rb', line 63

def tls_disabled
  @attributes[:tls_disabled]
end