Class: Files::SsoEvent
- Inherits:
-
Object
- Object
- Files::SsoEvent
- Defined in:
- lib/files.com/models/sso_event.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Sso Event ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
Instance Method Summary collapse
-
#body ⇒ Object
string - Event body.
-
#body_url ⇒ Object
string - Link to log file.
-
#created_at ⇒ Object
date-time - Event create date/time.
-
#event_errors ⇒ Object
array(string) - Event errors.
-
#event_type ⇒ Object
string - Type of SSO event being recorded.
-
#id ⇒ Object
int64 - Event ID.
-
#idp_uid ⇒ Object
string - Identity Provider UID for the SSO login attempt.
-
#initialize(attributes = {}, options = {}) ⇒ SsoEvent
constructor
A new instance of SsoEvent.
-
#ip ⇒ Object
string - IP address for the SSO login attempt.
-
#provider ⇒ Object
string - SSO provider for the SSO login attempt.
-
#provider_label ⇒ Object
string - SSO provider label for the SSO login attempt.
-
#region ⇒ Object
string - Region for the SSO login attempt.
-
#status ⇒ Object
string - Status of event.
-
#user_id ⇒ Object
int64 - User ID.
-
#username ⇒ Object
string - Username on Files.com for the SSO login attempt.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ SsoEvent
Returns a new instance of SsoEvent.
7 8 9 10 |
# File 'lib/files.com/models/sso_event.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/sso_event.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/sso_event.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
108 109 110 |
# File 'lib/files.com/models/sso_event.rb', line 108 def self.all(params = {}, = {}) list(params, ) end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Sso Event ID.
114 115 116 117 118 119 120 121 122 |
# File 'lib/files.com/models/sso_event.rb', line 114 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/sso_events/#{params[:id]}", :get, params, ) SsoEvent.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
124 125 126 |
# File 'lib/files.com/models/sso_event.rb', line 124 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `created_at`, `event_type`, `status` or `user_id`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at`, `event_type`, `idp_uid`, `ip`, `provider`, `status`, `user_id` or `username`. Valid field combinations are `[ event_type, created_at ]`, `[ idp_uid, created_at ]`, `[ ip, created_at ]`, `[ provider, created_at ]`, `[ status, created_at ]`, `[ user_id, created_at ]`, `[ username, created_at ]`, `[ event_type, status ]`, `[ idp_uid, status ]`, `[ ip, status ]`, `[ provider, status ]`, `[ user_id, status ]`, `[ username, status ]`, `[ event_type, status, created_at ]`, `[ idp_uid, status, created_at ]`, `[ ip, status, created_at ]`, `[ provider, status, created_at ]`, `[ user_id, status, created_at ]` or `[ username, status, created_at ]`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `created_at`.
filter_prefix - object - If set, return records where the specified field is prefixed by the supplied value. Valid fields are `idp_uid`, `ip`, `provider` or `username`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `created_at`.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/files.com/models/sso_event.rb', line 92 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_prefix must be an Hash") if params[:filter_prefix] and !params[:filter_prefix].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash) List.new(SsoEvent, params) do Api.send_request("/sso_events", :get, params, ) end end |
Instance Method Details
#body ⇒ Object
string - Event body.
28 29 30 |
# File 'lib/files.com/models/sso_event.rb', line 28 def body @attributes[:body] end |
#body_url ⇒ Object
string - Link to log file.
43 44 45 |
# File 'lib/files.com/models/sso_event.rb', line 43 def body_url @attributes[:body_url] end |
#created_at ⇒ Object
date-time - Event create date/time.
38 39 40 |
# File 'lib/files.com/models/sso_event.rb', line 38 def created_at @attributes[:created_at] end |
#event_errors ⇒ Object
array(string) - Event errors.
33 34 35 |
# File 'lib/files.com/models/sso_event.rb', line 33 def event_errors @attributes[:event_errors] end |
#event_type ⇒ Object
string - Type of SSO event being recorded.
18 19 20 |
# File 'lib/files.com/models/sso_event.rb', line 18 def event_type @attributes[:event_type] end |
#id ⇒ Object
int64 - Event ID
13 14 15 |
# File 'lib/files.com/models/sso_event.rb', line 13 def id @attributes[:id] end |
#idp_uid ⇒ Object
string - Identity Provider UID for the SSO login attempt.
58 59 60 |
# File 'lib/files.com/models/sso_event.rb', line 58 def idp_uid @attributes[:idp_uid] end |
#ip ⇒ Object
string - IP address for the SSO login attempt.
73 74 75 |
# File 'lib/files.com/models/sso_event.rb', line 73 def ip @attributes[:ip] end |
#provider ⇒ Object
string - SSO provider for the SSO login attempt.
63 64 65 |
# File 'lib/files.com/models/sso_event.rb', line 63 def provider @attributes[:provider] end |
#provider_label ⇒ Object
string - SSO provider label for the SSO login attempt.
68 69 70 |
# File 'lib/files.com/models/sso_event.rb', line 68 def provider_label @attributes[:provider_label] end |
#region ⇒ Object
string - Region for the SSO login attempt.
78 79 80 |
# File 'lib/files.com/models/sso_event.rb', line 78 def region @attributes[:region] end |
#status ⇒ Object
string - Status of event.
23 24 25 |
# File 'lib/files.com/models/sso_event.rb', line 23 def status @attributes[:status] end |
#user_id ⇒ Object
int64 - User ID.
48 49 50 |
# File 'lib/files.com/models/sso_event.rb', line 48 def user_id @attributes[:user_id] end |
#username ⇒ Object
string - Username on Files.com for the SSO login attempt.
53 54 55 |
# File 'lib/files.com/models/sso_event.rb', line 53 def username @attributes[:username] end |