Class: Files::UserCipherUse
- Inherits:
-
Object
- Object
- Files::UserCipherUse
- Defined in:
- lib/files.com/models/user_cipher_use.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: user_id - int64 - User ID.
Instance Method Summary collapse
-
#created_at ⇒ Object
date-time - The earliest recorded use of this combination of interface and protocol and cipher (for this user).
-
#id ⇒ Object
int64 - UserCipherUse ID.
-
#initialize(attributes = {}, options = {}) ⇒ UserCipherUse
constructor
A new instance of UserCipherUse.
-
#insecure ⇒ Object
boolean - Is this cipher considered insecure?.
-
#interface ⇒ Object
string - The interface accessed.
-
#protocol_cipher ⇒ Object
string - The protocol and cipher employed.
-
#updated_at ⇒ Object
date-time - The most recent use of this combination of interface and protocol and cipher (for this user).
-
#user_id ⇒ Object
int64 - ID of the user who performed this access.
-
#username ⇒ Object
string - Username of the user who performed this access.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ UserCipherUse
Returns a new instance of UserCipherUse.
7 8 9 10 |
# File 'lib/files.com/models/user_cipher_use.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/user_cipher_use.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/user_cipher_use.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
78 79 80 |
# File 'lib/files.com/models/user_cipher_use.rb', line 78 def self.all(params = {}, = {}) list(params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
user_id - int64 - User ID. If provided, will return uses for this user.
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `updated_at`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `insecure` and `updated_at`. Valid field combinations are `[ insecure, updated_at ]`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `updated_at`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `updated_at`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `updated_at`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `updated_at`.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/files.com/models/user_cipher_use.rb', line 62 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: user_id must be an Integer") if params[:user_id] and !params[:user_id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash) List.new(UserCipherUse, params) do Api.send_request("/user_cipher_uses", :get, params, ) end end |
Instance Method Details
#created_at ⇒ Object
date-time - The earliest recorded use of this combination of interface and protocol and cipher (for this user)
33 34 35 |
# File 'lib/files.com/models/user_cipher_use.rb', line 33 def created_at @attributes[:created_at] end |
#id ⇒ Object
int64 - UserCipherUse ID
13 14 15 |
# File 'lib/files.com/models/user_cipher_use.rb', line 13 def id @attributes[:id] end |
#insecure ⇒ Object
boolean - Is this cipher considered insecure?
38 39 40 |
# File 'lib/files.com/models/user_cipher_use.rb', line 38 def insecure @attributes[:insecure] end |
#interface ⇒ Object
string - The interface accessed
43 44 45 |
# File 'lib/files.com/models/user_cipher_use.rb', line 43 def interface @attributes[:interface] end |
#protocol_cipher ⇒ Object
string - The protocol and cipher employed
28 29 30 |
# File 'lib/files.com/models/user_cipher_use.rb', line 28 def protocol_cipher @attributes[:protocol_cipher] end |
#updated_at ⇒ Object
date-time - The most recent use of this combination of interface and protocol and cipher (for this user)
48 49 50 |
# File 'lib/files.com/models/user_cipher_use.rb', line 48 def updated_at @attributes[:updated_at] end |
#user_id ⇒ Object
int64 - ID of the user who performed this access
18 19 20 |
# File 'lib/files.com/models/user_cipher_use.rb', line 18 def user_id @attributes[:user_id] end |
#username ⇒ Object
string - Username of the user who performed this access
23 24 25 |
# File 'lib/files.com/models/user_cipher_use.rb', line 23 def username @attributes[:username] end |