Class: Files::Warning

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/warning.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ Warning

Returns a new instance of Warning.



7
8
9
10
# File 'lib/files.com/models/warning.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/warning.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/warning.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



29
30
31
# File 'lib/files.com/models/warning.rb', line 29

def self.all(params = {}, options = {})
  list(params, options)
end

.create_export(params = {}, options = {}) ⇒ Object



33
34
35
36
# File 'lib/files.com/models/warning.rb', line 33

def self.create_export(params = {}, options = {})
  response, options = Api.send_request("/warnings/create_export", :post, params, options)
  Export.new(response.data, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).


20
21
22
23
24
25
26
27
# File 'lib/files.com/models/warning.rb', line 20

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(Warning, params) do
    Api.send_request("/warnings", :get, params, options)
  end
end

Instance Method Details

#warningsObject

array(object) - A list of warnings



13
14
15
# File 'lib/files.com/models/warning.rb', line 13

def warnings
  @attributes[:warnings]
end