Class: Files::ZipDownloadFiles
- Inherits:
-
Object
- Object
- Files::ZipDownloadFiles
- Defined in:
- lib/files.com/models/zip_download_files.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#bundle_id ⇒ Object
int64 - Bundle Id.
-
#bundle_registration_id ⇒ Object
int64 - Bundle Registration Id.
-
#cursor ⇒ Object
string - Cursor for fetching more files in subsequent requests.
-
#files ⇒ Object
array(object) - A list of file names, sizes, and signed download URLs.
-
#initialize(attributes = {}, options = {}) ⇒ ZipDownloadFiles
constructor
A new instance of ZipDownloadFiles.
-
#site_id ⇒ Object
int64 - Site Id.
-
#user_id ⇒ Object
int64 - User Id.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ ZipDownloadFiles
Returns a new instance of ZipDownloadFiles.
7 8 9 10 |
# File 'lib/files.com/models/zip_download_files.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/zip_download_files.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/zip_download_files.rb', line 5 def @options end |
Instance Method Details
#bundle_id ⇒ Object
int64 - Bundle Id
23 24 25 |
# File 'lib/files.com/models/zip_download_files.rb', line 23 def bundle_id @attributes[:bundle_id] end |
#bundle_registration_id ⇒ Object
int64 - Bundle Registration Id
28 29 30 |
# File 'lib/files.com/models/zip_download_files.rb', line 28 def bundle_registration_id @attributes[:bundle_registration_id] end |
#cursor ⇒ Object
string - Cursor for fetching more files in subsequent requests.
38 39 40 |
# File 'lib/files.com/models/zip_download_files.rb', line 38 def cursor @attributes[:cursor] end |
#files ⇒ Object
array(object) - A list of file names, sizes, and signed download URLs.
33 34 35 |
# File 'lib/files.com/models/zip_download_files.rb', line 33 def files @attributes[:files] end |
#site_id ⇒ Object
int64 - Site Id
13 14 15 |
# File 'lib/files.com/models/zip_download_files.rb', line 13 def site_id @attributes[:site_id] end |
#user_id ⇒ Object
int64 - User Id
18 19 20 |
# File 'lib/files.com/models/zip_download_files.rb', line 18 def user_id @attributes[:user_id] end |