Class: Files::AiTask
- Inherits:
-
Object
- Object
- Files::AiTask
- Defined in:
- lib/files.com/models/ai_task.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: description - string - AI Task description.
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Ai Task ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.manual_run(id, params = {}, options = {}) ⇒ Object
Manually Run AI Task.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: description - string - AI Task description.
Instance Method Summary collapse
-
#created_at ⇒ Object
date-time - Creation time.
- #delete(params = {}) ⇒ Object
-
#description ⇒ Object
string - AI Task description.
- #description=(value) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#disabled ⇒ Object
boolean - If true, this AI Task will not run.
- #disabled=(value) ⇒ Object
-
#holiday_region ⇒ Object
string - Optional holiday region used by scheduled AI Tasks.
- #holiday_region=(value) ⇒ Object
-
#human_readable_schedule ⇒ Object
string - Human-readable schedule description.
- #human_readable_schedule=(value) ⇒ Object
-
#id ⇒ Object
int64 - AI Task ID.
- #id=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ AiTask
constructor
A new instance of AiTask.
-
#interval ⇒ Object
string - If trigger is ‘daily`, this specifies how often to run the AI Task.
- #interval=(value) ⇒ Object
-
#last_run_at ⇒ Object
date-time - Most recent successful invocation time.
- #last_run_at=(value) ⇒ Object
-
#manual_run(params = {}) ⇒ Object
Manually Run AI Task.
-
#master_admin_user_id ⇒ Object
int64 - Master User ID used for AI Task invocations.
- #master_admin_user_id=(value) ⇒ Object
-
#name ⇒ Object
string - AI Task name.
- #name=(value) ⇒ Object
-
#path ⇒ Object
string - Path scope used for action-triggered AI Tasks.
- #path=(value) ⇒ Object
-
#prompt ⇒ Object
string - Prompt sent when this AI Task is invoked.
- #prompt=(value) ⇒ Object
-
#recurring_day ⇒ Object
int64 - If trigger is ‘daily`, this selects the day number inside the chosen interval.
- #recurring_day=(value) ⇒ Object
- #save ⇒ Object
-
#schedule_days_of_week ⇒ Object
array(int64) - If trigger is ‘custom_schedule`, the 0-based weekdays used by the schedule.
- #schedule_days_of_week=(value) ⇒ Object
-
#schedule_time_zone ⇒ Object
string - Time zone used by the AI Task schedule.
- #schedule_time_zone=(value) ⇒ Object
-
#schedule_times_of_day ⇒ Object
array(string) - Times of day in HH:MM format for scheduled AI Tasks.
- #schedule_times_of_day=(value) ⇒ Object
-
#source ⇒ Object
string - Source glob used with ‘path` for action-triggered AI Tasks.
- #source=(value) ⇒ Object
-
#trigger ⇒ Object
string - How this AI Task is triggered.
- #trigger=(value) ⇒ Object
-
#trigger_actions ⇒ Object
array(string) - If trigger is ‘action`, the file action types that invoke this AI Task.
- #trigger_actions=(value) ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: description - string - AI Task description.
-
#updated_at ⇒ Object
date-time - Last update time.
-
#workspace_id ⇒ Object
int64 - Workspace ID.
- #workspace_id=(value) ⇒ Object
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ AiTask
Returns a new instance of AiTask.
7 8 9 10 |
# File 'lib/files.com/models/ai_task.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/ai_task.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/ai_task.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
286 287 288 |
# File 'lib/files.com/models/ai_task.rb', line 286 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
description - string - AI Task description.
disabled - boolean - If true, this AI Task will not run.
holiday_region - string - Optional holiday region used by scheduled AI Tasks.
interval - string - If trigger is `daily`, this specifies how often to run the AI Task.
name (required) - string - AI Task name.
path - string - Path scope used for action-triggered AI Tasks.
prompt (required) - string - Prompt sent when this AI Task is invoked.
recurring_day - int64 - If trigger is `daily`, this selects the day number inside the chosen interval.
schedule_days_of_week - array(int64) - If trigger is `custom_schedule`, the 0-based weekdays used by the schedule.
schedule_time_zone - string - Time zone used by the AI Task schedule.
schedule_times_of_day - array(string) - Times of day in HH:MM format for scheduled AI Tasks.
source - string - Source glob used with `path` for action-triggered AI Tasks.
trigger - string - How this AI Task is triggered.
trigger_actions - array(string) - If trigger is `action`, the file action types that invoke this AI Task. Valid actions are create, copy, move, archived_delete, update, read, destroy.
workspace_id - int64 - Workspace ID. `0` means the default workspace.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/files.com/models/ai_task.rb', line 322 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: description must be an String") if params[:description] and !params[:description].is_a?(String) raise InvalidParameterError.new("Bad parameter: holiday_region must be an String") if params[:holiday_region] and !params[:holiday_region].is_a?(String) raise InvalidParameterError.new("Bad parameter: interval must be an String") if params[:interval] and !params[:interval].is_a?(String) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: path must be an String") if params[:path] and !params[:path].is_a?(String) raise InvalidParameterError.new("Bad parameter: prompt must be an String") if params[:prompt] and !params[:prompt].is_a?(String) raise InvalidParameterError.new("Bad parameter: recurring_day must be an Integer") if params[:recurring_day] and !params[:recurring_day].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: schedule_days_of_week must be an Array") if params[:schedule_days_of_week] and !params[:schedule_days_of_week].is_a?(Array) raise InvalidParameterError.new("Bad parameter: schedule_time_zone must be an String") if params[:schedule_time_zone] and !params[:schedule_time_zone].is_a?(String) raise InvalidParameterError.new("Bad parameter: schedule_times_of_day must be an Array") if params[:schedule_times_of_day] and !params[:schedule_times_of_day].is_a?(Array) raise InvalidParameterError.new("Bad parameter: source must be an String") if params[:source] and !params[:source].is_a?(String) raise InvalidParameterError.new("Bad parameter: trigger must be an String") if params[:trigger] and !params[:trigger].is_a?(String) raise InvalidParameterError.new("Bad parameter: trigger_actions must be an Array") if params[:trigger_actions] and !params[:trigger_actions].is_a?(Array) raise InvalidParameterError.new("Bad parameter: workspace_id must be an Integer") if params[:workspace_id] and !params[:workspace_id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: name") unless params[:name] raise MissingParameterError.new("Parameter missing: prompt") unless params[:prompt] response, = Api.send_request("/ai_tasks", :post, params, ) AiTask.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
395 396 397 398 399 400 401 402 403 |
# File 'lib/files.com/models/ai_task.rb', line 395 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/ai_tasks/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
405 406 407 408 |
# File 'lib/files.com/models/ai_task.rb', line 405 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Ai Task ID.
292 293 294 295 296 297 298 299 300 |
# File 'lib/files.com/models/ai_task.rb', line 292 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/ai_tasks/#{params[:id]}", :get, params, ) AiTask.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
302 303 304 |
# File 'lib/files.com/models/ai_task.rb', line 302 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `workspace_id`, `id`, `disabled` or `updated_at`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `disabled`, `trigger` or `workspace_id`. Valid field combinations are `[ workspace_id, disabled ]`.
275 276 277 278 279 280 281 282 283 284 |
# File 'lib/files.com/models/ai_task.rb', line 275 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) List.new(AiTask, params) do Api.send_request("/ai_tasks", :get, params, ) end end |
.manual_run(id, params = {}, options = {}) ⇒ Object
Manually Run AI Task
345 346 347 348 349 350 351 352 353 |
# File 'lib/files.com/models/ai_task.rb', line 345 def self.manual_run(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/ai_tasks/#{params[:id]}/manual_run", :post, params, ) nil end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
description - string - AI Task description.
disabled - boolean - If true, this AI Task will not run.
holiday_region - string - Optional holiday region used by scheduled AI Tasks.
interval - string - If trigger is `daily`, this specifies how often to run the AI Task.
name - string - AI Task name.
path - string - Path scope used for action-triggered AI Tasks.
prompt - string - Prompt sent when this AI Task is invoked.
recurring_day - int64 - If trigger is `daily`, this selects the day number inside the chosen interval.
schedule_days_of_week - array(int64) - If trigger is `custom_schedule`, the 0-based weekdays used by the schedule.
schedule_time_zone - string - Time zone used by the AI Task schedule.
schedule_times_of_day - array(string) - Times of day in HH:MM format for scheduled AI Tasks.
source - string - Source glob used with `path` for action-triggered AI Tasks.
trigger - string - How this AI Task is triggered.
trigger_actions - array(string) - If trigger is `action`, the file action types that invoke this AI Task. Valid actions are create, copy, move, archived_delete, update, read, destroy.
workspace_id - int64 - Workspace ID. `0` means the default workspace.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/files.com/models/ai_task.rb', line 371 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: description must be an String") if params[:description] and !params[:description].is_a?(String) raise InvalidParameterError.new("Bad parameter: holiday_region must be an String") if params[:holiday_region] and !params[:holiday_region].is_a?(String) raise InvalidParameterError.new("Bad parameter: interval must be an String") if params[:interval] and !params[:interval].is_a?(String) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: path must be an String") if params[:path] and !params[:path].is_a?(String) raise InvalidParameterError.new("Bad parameter: prompt must be an String") if params[:prompt] and !params[:prompt].is_a?(String) raise InvalidParameterError.new("Bad parameter: recurring_day must be an Integer") if params[:recurring_day] and !params[:recurring_day].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: schedule_days_of_week must be an Array") if params[:schedule_days_of_week] and !params[:schedule_days_of_week].is_a?(Array) raise InvalidParameterError.new("Bad parameter: schedule_time_zone must be an String") if params[:schedule_time_zone] and !params[:schedule_time_zone].is_a?(String) raise InvalidParameterError.new("Bad parameter: schedule_times_of_day must be an Array") if params[:schedule_times_of_day] and !params[:schedule_times_of_day].is_a?(Array) raise InvalidParameterError.new("Bad parameter: source must be an String") if params[:source] and !params[:source].is_a?(String) raise InvalidParameterError.new("Bad parameter: trigger must be an String") if params[:trigger] and !params[:trigger].is_a?(String) raise InvalidParameterError.new("Bad parameter: trigger_actions must be an Array") if params[:trigger_actions] and !params[:trigger_actions].is_a?(Array) raise InvalidParameterError.new("Bad parameter: workspace_id must be an Integer") if params[:workspace_id] and !params[:workspace_id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/ai_tasks/#{params[:id]}", :patch, params, ) AiTask.new(response.data, ) end |
Instance Method Details
#created_at ⇒ Object
date-time - Creation time.
184 185 186 |
# File 'lib/files.com/models/ai_task.rb', line 184 def created_at @attributes[:created_at] end |
#delete(params = {}) ⇒ Object
244 245 246 247 248 249 250 251 252 |
# File 'lib/files.com/models/ai_task.rb', line 244 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/ai_tasks/#{@attributes[:id]}", :delete, params, @options) end |
#description ⇒ Object
string - AI Task description.
40 41 42 |
# File 'lib/files.com/models/ai_task.rb', line 40 def description @attributes[:description] end |
#description=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/ai_task.rb', line 44 def description=(value) @attributes[:description] = value end |
#destroy(params = {}) ⇒ Object
254 255 256 257 |
# File 'lib/files.com/models/ai_task.rb', line 254 def destroy(params = {}) delete(params) nil end |
#disabled ⇒ Object
boolean - If true, this AI Task will not run.
76 77 78 |
# File 'lib/files.com/models/ai_task.rb', line 76 def disabled @attributes[:disabled] end |
#disabled=(value) ⇒ Object
80 81 82 |
# File 'lib/files.com/models/ai_task.rb', line 80 def disabled=(value) @attributes[:disabled] = value end |
#holiday_region ⇒ Object
string - Optional holiday region used by scheduled AI Tasks.
148 149 150 |
# File 'lib/files.com/models/ai_task.rb', line 148 def holiday_region @attributes[:holiday_region] end |
#holiday_region=(value) ⇒ Object
152 153 154 |
# File 'lib/files.com/models/ai_task.rb', line 152 def holiday_region=(value) @attributes[:holiday_region] = value end |
#human_readable_schedule ⇒ Object
string - Human-readable schedule description.
157 158 159 |
# File 'lib/files.com/models/ai_task.rb', line 157 def human_readable_schedule @attributes[:human_readable_schedule] end |
#human_readable_schedule=(value) ⇒ Object
161 162 163 |
# File 'lib/files.com/models/ai_task.rb', line 161 def human_readable_schedule=(value) @attributes[:human_readable_schedule] = value end |
#id ⇒ Object
int64 - AI Task ID.
13 14 15 |
# File 'lib/files.com/models/ai_task.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/ai_task.rb', line 17 def id=(value) @attributes[:id] = value end |
#interval ⇒ Object
string - If trigger is ‘daily`, this specifies how often to run the AI Task.
103 104 105 |
# File 'lib/files.com/models/ai_task.rb', line 103 def interval @attributes[:interval] end |
#interval=(value) ⇒ Object
107 108 109 |
# File 'lib/files.com/models/ai_task.rb', line 107 def interval=(value) @attributes[:interval] = value end |
#last_run_at ⇒ Object
date-time - Most recent successful invocation time.
166 167 168 |
# File 'lib/files.com/models/ai_task.rb', line 166 def last_run_at @attributes[:last_run_at] end |
#last_run_at=(value) ⇒ Object
170 171 172 |
# File 'lib/files.com/models/ai_task.rb', line 170 def last_run_at=(value) @attributes[:last_run_at] = value end |
#manual_run(params = {}) ⇒ Object
Manually Run AI Task
194 195 196 197 198 199 200 201 202 |
# File 'lib/files.com/models/ai_task.rb', line 194 def manual_run(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/ai_tasks/#{@attributes[:id]}/manual_run", :post, params, @options) end |
#master_admin_user_id ⇒ Object
int64 - Master User ID used for AI Task invocations.
175 176 177 |
# File 'lib/files.com/models/ai_task.rb', line 175 def master_admin_user_id @attributes[:master_admin_user_id] end |
#master_admin_user_id=(value) ⇒ Object
179 180 181 |
# File 'lib/files.com/models/ai_task.rb', line 179 def master_admin_user_id=(value) @attributes[:master_admin_user_id] = value end |
#name ⇒ Object
string - AI Task name.
31 32 33 |
# File 'lib/files.com/models/ai_task.rb', line 31 def name @attributes[:name] end |
#name=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/ai_task.rb', line 35 def name=(value) @attributes[:name] = value end |
#path ⇒ Object
string - Path scope used for action-triggered AI Tasks. This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.
58 59 60 |
# File 'lib/files.com/models/ai_task.rb', line 58 def path @attributes[:path] end |
#path=(value) ⇒ Object
62 63 64 |
# File 'lib/files.com/models/ai_task.rb', line 62 def path=(value) @attributes[:path] = value end |
#prompt ⇒ Object
string - Prompt sent when this AI Task is invoked.
49 50 51 |
# File 'lib/files.com/models/ai_task.rb', line 49 def prompt @attributes[:prompt] end |
#prompt=(value) ⇒ Object
53 54 55 |
# File 'lib/files.com/models/ai_task.rb', line 53 def prompt=(value) @attributes[:prompt] = value end |
#recurring_day ⇒ Object
int64 - If trigger is ‘daily`, this selects the day number inside the chosen interval.
112 113 114 |
# File 'lib/files.com/models/ai_task.rb', line 112 def recurring_day @attributes[:recurring_day] end |
#recurring_day=(value) ⇒ Object
116 117 118 |
# File 'lib/files.com/models/ai_task.rb', line 116 def recurring_day=(value) @attributes[:recurring_day] = value end |
#save ⇒ Object
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/files.com/models/ai_task.rb', line 259 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = AiTask.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#schedule_days_of_week ⇒ Object
array(int64) - If trigger is ‘custom_schedule`, the 0-based weekdays used by the schedule.
121 122 123 |
# File 'lib/files.com/models/ai_task.rb', line 121 def schedule_days_of_week @attributes[:schedule_days_of_week] end |
#schedule_days_of_week=(value) ⇒ Object
125 126 127 |
# File 'lib/files.com/models/ai_task.rb', line 125 def schedule_days_of_week=(value) @attributes[:schedule_days_of_week] = value end |
#schedule_time_zone ⇒ Object
string - Time zone used by the AI Task schedule.
139 140 141 |
# File 'lib/files.com/models/ai_task.rb', line 139 def schedule_time_zone @attributes[:schedule_time_zone] end |
#schedule_time_zone=(value) ⇒ Object
143 144 145 |
# File 'lib/files.com/models/ai_task.rb', line 143 def schedule_time_zone=(value) @attributes[:schedule_time_zone] = value end |
#schedule_times_of_day ⇒ Object
array(string) - Times of day in HH:MM format for scheduled AI Tasks.
130 131 132 |
# File 'lib/files.com/models/ai_task.rb', line 130 def schedule_times_of_day @attributes[:schedule_times_of_day] end |
#schedule_times_of_day=(value) ⇒ Object
134 135 136 |
# File 'lib/files.com/models/ai_task.rb', line 134 def schedule_times_of_day=(value) @attributes[:schedule_times_of_day] = value end |
#source ⇒ Object
string - Source glob used with ‘path` for action-triggered AI Tasks.
67 68 69 |
# File 'lib/files.com/models/ai_task.rb', line 67 def source @attributes[:source] end |
#source=(value) ⇒ Object
71 72 73 |
# File 'lib/files.com/models/ai_task.rb', line 71 def source=(value) @attributes[:source] = value end |
#trigger ⇒ Object
string - How this AI Task is triggered.
85 86 87 |
# File 'lib/files.com/models/ai_task.rb', line 85 def trigger @attributes[:trigger] end |
#trigger=(value) ⇒ Object
89 90 91 |
# File 'lib/files.com/models/ai_task.rb', line 89 def trigger=(value) @attributes[:trigger] = value end |
#trigger_actions ⇒ Object
array(string) - If trigger is ‘action`, the file action types that invoke this AI Task. Valid actions are create, copy, move, archived_delete, update, read, destroy.
94 95 96 |
# File 'lib/files.com/models/ai_task.rb', line 94 def trigger_actions @attributes[:trigger_actions] end |
#trigger_actions=(value) ⇒ Object
98 99 100 |
# File 'lib/files.com/models/ai_task.rb', line 98 def trigger_actions=(value) @attributes[:trigger_actions] = value end |
#update(params = {}) ⇒ Object
Parameters:
description - string - AI Task description.
disabled - boolean - If true, this AI Task will not run.
holiday_region - string - Optional holiday region used by scheduled AI Tasks.
interval - string - If trigger is `daily`, this specifies how often to run the AI Task.
name - string - AI Task name.
path - string - Path scope used for action-triggered AI Tasks.
prompt - string - Prompt sent when this AI Task is invoked.
recurring_day - int64 - If trigger is `daily`, this selects the day number inside the chosen interval.
schedule_days_of_week - array(int64) - If trigger is `custom_schedule`, the 0-based weekdays used by the schedule.
schedule_time_zone - string - Time zone used by the AI Task schedule.
schedule_times_of_day - array(string) - Times of day in HH:MM format for scheduled AI Tasks.
source - string - Source glob used with `path` for action-triggered AI Tasks.
trigger - string - How this AI Task is triggered.
trigger_actions - array(string) - If trigger is `action`, the file action types that invoke this AI Task. Valid actions are create, copy, move, archived_delete, update, read, destroy.
workspace_id - int64 - Workspace ID. `0` means the default workspace.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/files.com/models/ai_task.rb', line 220 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: description must be an String") if params[:description] and !params[:description].is_a?(String) raise InvalidParameterError.new("Bad parameter: holiday_region must be an String") if params[:holiday_region] and !params[:holiday_region].is_a?(String) raise InvalidParameterError.new("Bad parameter: interval must be an String") if params[:interval] and !params[:interval].is_a?(String) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: path must be an String") if params[:path] and !params[:path].is_a?(String) raise InvalidParameterError.new("Bad parameter: prompt must be an String") if params[:prompt] and !params[:prompt].is_a?(String) raise InvalidParameterError.new("Bad parameter: recurring_day must be an Integer") if params[:recurring_day] and !params[:recurring_day].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: schedule_days_of_week must be an Array") if params[:schedule_days_of_week] and !params[:schedule_days_of_week].is_a?(Array) raise InvalidParameterError.new("Bad parameter: schedule_time_zone must be an String") if params[:schedule_time_zone] and !params[:schedule_time_zone].is_a?(String) raise InvalidParameterError.new("Bad parameter: schedule_times_of_day must be an Array") if params[:schedule_times_of_day] and !params[:schedule_times_of_day].is_a?(Array) raise InvalidParameterError.new("Bad parameter: source must be an String") if params[:source] and !params[:source].is_a?(String) raise InvalidParameterError.new("Bad parameter: trigger must be an String") if params[:trigger] and !params[:trigger].is_a?(String) raise InvalidParameterError.new("Bad parameter: trigger_actions must be an Array") if params[:trigger_actions] and !params[:trigger_actions].is_a?(Array) raise InvalidParameterError.new("Bad parameter: workspace_id must be an Integer") if params[:workspace_id] and !params[:workspace_id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/ai_tasks/#{@attributes[:id]}", :patch, params, @options) end |
#updated_at ⇒ Object
date-time - Last update time.
189 190 191 |
# File 'lib/files.com/models/ai_task.rb', line 189 def updated_at @attributes[:updated_at] end |
#workspace_id ⇒ Object
int64 - Workspace ID. ‘0` means the default workspace.
22 23 24 |
# File 'lib/files.com/models/ai_task.rb', line 22 def workspace_id @attributes[:workspace_id] end |
#workspace_id=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/ai_task.rb', line 26 def workspace_id=(value) @attributes[:workspace_id] = value end |