Class: Files::AutomationRun

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/automation_run.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ AutomationRun

Returns a new instance of AutomationRun.



7
8
9
10
# File 'lib/files.com/models/automation_run.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/automation_run.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/automation_run.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



139
140
141
# File 'lib/files.com/models/automation_run.rb', line 139

def self.all(params = {}, options = {})
  list(params, options)
end

.cancel(id, params = {}, options = {}) ⇒ Object

Cancel Automation Run



160
161
162
163
164
165
166
167
168
# File 'lib/files.com/models/automation_run.rb', line 160

def self.cancel(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  response, options = Api.send_request("/automation_runs/#{params[:id]}/cancel", :post, params, options)
  AutomationRun.new(response.data, options)
end

.find(id, params = {}, options = {}) ⇒ Object

Parameters:

id (required) - int64 - Automation Run ID.


145
146
147
148
149
150
151
152
153
# File 'lib/files.com/models/automation_run.rb', line 145

def self.find(id, params = {}, options = {})
  params ||= {}
  params[:id] = id
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  response, options = Api.send_request("/automation_runs/#{params[:id]}", :get, params, options)
  AutomationRun.new(response.data, options)
end

.get(id, params = {}, options = {}) ⇒ Object



155
156
157
# File 'lib/files.com/models/automation_run.rb', line 155

def self.get(id, params = {}, options = {})
  find(id, params, options)
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `automation_id`, `created_at` or `status`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `status`, `workspace_id` or `automation_id`. Valid field combinations are `[ workspace_id, status ]`, `[ automation_id, status ]`, `[ workspace_id, automation_id ]` or `[ workspace_id, automation_id, status ]`.
automation_id (required) - int64 - ID of the associated Automation.


125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/files.com/models/automation_run.rb', line 125

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: user_id must be an Integer") if params[:user_id] and !params[:user_id].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)
  raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash)
  raise InvalidParameterError.new("Bad parameter: automation_id must be an Integer") if params[:automation_id] and !params[:automation_id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: automation_id") unless params[:automation_id]

  List.new(AutomationRun, params) do
    Api.send_request("/automation_runs", :get, params, options)
  end
end

Instance Method Details

#automation_idObject

int64 - ID of the associated Automation.



18
19
20
# File 'lib/files.com/models/automation_run.rb', line 18

def automation_id
  @attributes[:automation_id]
end

#automation_version_idObject

int64 - ID of the immutable Automation version pinned by this run.



23
24
25
# File 'lib/files.com/models/automation_run.rb', line 23

def automation_version_id
  @attributes[:automation_version_id]
end

#cancel(params = {}) ⇒ Object

Cancel Automation Run



108
109
110
111
112
113
114
115
116
# File 'lib/files.com/models/automation_run.rb', line 108

def cancel(params = {})
  params ||= {}
  params[:id] = @attributes[:id]
  raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id]
  raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer)
  raise MissingParameterError.new("Parameter missing: id") unless params[:id]

  Api.send_request("/automation_runs/#{@attributes[:id]}/cancel", :post, params, @options)
end

#cancel_requested_atObject

date-time - Date/time at which cancellation was requested.



33
34
35
# File 'lib/files.com/models/automation_run.rb', line 33

def cancel_requested_at
  @attributes[:cancel_requested_at]
end

#completed_atObject

date-time - Automation run completion/failure date/time.



38
39
40
# File 'lib/files.com/models/automation_run.rb', line 38

def completed_at
  @attributes[:completed_at]
end

#created_atObject

date-time - Automation run start date/time.



43
44
45
# File 'lib/files.com/models/automation_run.rb', line 43

def created_at
  @attributes[:created_at]
end

#definitionObject

object - Automation definition snapshot pinned by this run. For performance reasons, this is not provided when listing Automation runs.



88
89
90
# File 'lib/files.com/models/automation_run.rb', line 88

def definition
  @attributes[:definition]
end

#failed_operationsObject

int64 - Count of failed operations.



83
84
85
# File 'lib/files.com/models/automation_run.rb', line 83

def failed_operations
  @attributes[:failed_operations]
end

#idObject

int64 - ID.



13
14
15
# File 'lib/files.com/models/automation_run.rb', line 13

def id
  @attributes[:id]
end

#journal_urlObject

string - Link to the run journal artifact.



98
99
100
# File 'lib/files.com/models/automation_run.rb', line 98

def journal_url
  @attributes[:journal_url]
end

#node_statesObject

object - Status and execution stage for each node in this run. For performance reasons, this is not provided when listing Automation runs.



93
94
95
# File 'lib/files.com/models/automation_run.rb', line 93

def node_states
  @attributes[:node_states]
end

#retried_atObject

date-time - If set, this Automation run was retried due to failure or partial_failure.



53
54
55
# File 'lib/files.com/models/automation_run.rb', line 53

def retried_at
  @attributes[:retried_at]
end

#retried_in_run_idObject

int64 - ID of the run that is or will be retrying this run.



58
59
60
# File 'lib/files.com/models/automation_run.rb', line 58

def retried_in_run_id
  @attributes[:retried_in_run_id]
end

#retry_atObject

date-time - If set, this automation will be retried at this date/time due to failure or partial_failure.



48
49
50
# File 'lib/files.com/models/automation_run.rb', line 48

def retry_at
  @attributes[:retry_at]
end

#retry_of_run_idObject

int64 - ID of the original run that this run is retrying.



63
64
65
# File 'lib/files.com/models/automation_run.rb', line 63

def retry_of_run_id
  @attributes[:retry_of_run_id]
end

#runtimeObject

double - Automation run runtime.



68
69
70
# File 'lib/files.com/models/automation_run.rb', line 68

def runtime
  @attributes[:runtime]
end

#statusObject

string - The status of the AutomationRun. One of queued, running, success, partial_failure, failure, skipped, or canceled.



73
74
75
# File 'lib/files.com/models/automation_run.rb', line 73

def status
  @attributes[:status]
end

#status_messages_urlObject

string - Link to status messages log file.



103
104
105
# File 'lib/files.com/models/automation_run.rb', line 103

def status_messages_url
  @attributes[:status_messages_url]
end

#successful_operationsObject

int64 - Count of successful operations.



78
79
80
# File 'lib/files.com/models/automation_run.rb', line 78

def successful_operations
  @attributes[:successful_operations]
end

#workspace_idObject

int64 - Workspace ID.



28
29
30
# File 'lib/files.com/models/automation_run.rb', line 28

def workspace_id
  @attributes[:workspace_id]
end