Class: Files::EventChannel
- Inherits:
-
Object
- Object
- Files::EventChannel
- Defined in:
- lib/files.com/models/event_channel.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: name (required) - string - Event Channel name.
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Event Channel ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: name - string - Event Channel name.
Instance Method Summary collapse
-
#created_at ⇒ Object
date-time - Event Channel create date/time.
-
#default_channel ⇒ Object
boolean - Whether this Event Channel is the default destination for newly published events.
- #default_channel=(value) ⇒ Object
- #delete(params = {}) ⇒ Object
-
#description ⇒ Object
string - Event Channel description.
- #description=(value) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#enabled ⇒ Object
boolean - Whether this Event Channel can dispatch events.
- #enabled=(value) ⇒ Object
-
#id ⇒ Object
int64 - Event Channel ID.
- #id=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ EventChannel
constructor
A new instance of EventChannel.
-
#name ⇒ Object
string - Event Channel name.
- #name=(value) ⇒ Object
- #save ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: name - string - Event Channel name.
-
#updated_at ⇒ Object
date-time - Event Channel update date/time.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ EventChannel
Returns a new instance of EventChannel.
7 8 9 10 |
# File 'lib/files.com/models/event_channel.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/event_channel.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/event_channel.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
126 127 128 |
# File 'lib/files.com/models/event_channel.rb', line 126 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
name (required) - string - Event Channel name.
description - string - Event Channel description.
enabled - boolean - Whether this Event Channel can dispatch events.
default_channel - boolean - Whether this Event Channel is the default destination for newly published events.
151 152 153 154 155 156 157 158 |
# File 'lib/files.com/models/event_channel.rb', line 151 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: description must be an String") if params[:description] and !params[:description].is_a?(String) raise MissingParameterError.new("Parameter missing: name") unless params[:name] response, = Api.send_request("/event_channels", :post, params, ) EventChannel.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
177 178 179 180 181 182 183 184 185 |
# File 'lib/files.com/models/event_channel.rb', line 177 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/event_channels/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
187 188 189 190 |
# File 'lib/files.com/models/event_channel.rb', line 187 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Event Channel ID.
132 133 134 135 136 137 138 139 140 |
# File 'lib/files.com/models/event_channel.rb', line 132 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/event_channels/#{params[:id]}", :get, params, ) EventChannel.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
142 143 144 |
# File 'lib/files.com/models/event_channel.rb', line 142 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `enabled` and `default_channel`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `enabled` and `default_channel`.
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/files.com/models/event_channel.rb', line 115 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) List.new(EventChannel, params) do Api.send_request("/event_channels", :get, params, ) end end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
name - string - Event Channel name.
description - string - Event Channel description.
enabled - boolean - Whether this Event Channel can dispatch events.
default_channel - boolean - Whether this Event Channel is the default destination for newly published events.
165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/files.com/models/event_channel.rb', line 165 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: description must be an String") if params[:description] and !params[:description].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/event_channels/#{params[:id]}", :patch, params, ) EventChannel.new(response.data, ) end |
Instance Method Details
#created_at ⇒ Object
date-time - Event Channel create date/time.
58 59 60 |
# File 'lib/files.com/models/event_channel.rb', line 58 def created_at @attributes[:created_at] end |
#default_channel ⇒ Object
boolean - Whether this Event Channel is the default destination for newly published events.
49 50 51 |
# File 'lib/files.com/models/event_channel.rb', line 49 def default_channel @attributes[:default_channel] end |
#default_channel=(value) ⇒ Object
53 54 55 |
# File 'lib/files.com/models/event_channel.rb', line 53 def default_channel=(value) @attributes[:default_channel] = value end |
#delete(params = {}) ⇒ Object
84 85 86 87 88 89 90 91 92 |
# File 'lib/files.com/models/event_channel.rb', line 84 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/event_channels/#{@attributes[:id]}", :delete, params, @options) end |
#description ⇒ Object
string - Event Channel description.
31 32 33 |
# File 'lib/files.com/models/event_channel.rb', line 31 def description @attributes[:description] end |
#description=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/event_channel.rb', line 35 def description=(value) @attributes[:description] = value end |
#destroy(params = {}) ⇒ Object
94 95 96 97 |
# File 'lib/files.com/models/event_channel.rb', line 94 def destroy(params = {}) delete(params) nil end |
#enabled ⇒ Object
boolean - Whether this Event Channel can dispatch events.
40 41 42 |
# File 'lib/files.com/models/event_channel.rb', line 40 def enabled @attributes[:enabled] end |
#enabled=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/event_channel.rb', line 44 def enabled=(value) @attributes[:enabled] = value end |
#id ⇒ Object
int64 - Event Channel ID
13 14 15 |
# File 'lib/files.com/models/event_channel.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/event_channel.rb', line 17 def id=(value) @attributes[:id] = value end |
#name ⇒ Object
string - Event Channel name.
22 23 24 |
# File 'lib/files.com/models/event_channel.rb', line 22 def name @attributes[:name] end |
#name=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/event_channel.rb', line 26 def name=(value) @attributes[:name] = value end |
#save ⇒ Object
99 100 101 102 103 104 105 106 107 108 |
# File 'lib/files.com/models/event_channel.rb', line 99 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = EventChannel.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#update(params = {}) ⇒ Object
Parameters:
name - string - Event Channel name.
description - string - Event Channel description.
enabled - boolean - Whether this Event Channel can dispatch events.
default_channel - boolean - Whether this Event Channel is the default destination for newly published events.
72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/files.com/models/event_channel.rb', line 72 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: description must be an String") if params[:description] and !params[:description].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/event_channels/#{@attributes[:id]}", :patch, params, @options) end |
#updated_at ⇒ Object
date-time - Event Channel update date/time.
63 64 65 |
# File 'lib/files.com/models/event_channel.rb', line 63 def updated_at @attributes[:updated_at] end |