Class: Files::EventRecord
- Inherits:
-
Object
- Object
- Files::EventRecord
- Defined in:
- lib/files.com/models/event_record.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Event Record ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
Instance Method Summary collapse
-
#actor ⇒ Object
object - Actor associated with the event.
-
#created_at ⇒ Object
date-time - Event Record create date/time.
-
#event_type ⇒ Object
string - Versioned event type string.
-
#event_uuid ⇒ Object
string - Stable event UUID.
-
#human_fields ⇒ Object
array(object) - Human-readable event detail fields.
-
#human_summary ⇒ Object
string - Human-readable event summary.
-
#human_title ⇒ Object
string - Human-readable event title.
-
#id ⇒ Object
int64 - Event Record ID.
-
#initialize(attributes = {}, options = {}) ⇒ EventRecord
constructor
A new instance of EventRecord.
-
#occurred_at ⇒ Object
date-time - Event occurrence date/time.
-
#payload ⇒ Object
object - Event payload.
-
#resources ⇒ Object
array(object) - Resources associated with the event.
-
#severity ⇒ Object
string - Event severity.
-
#source_id ⇒ Object
int64 - Source record ID.
-
#source_type ⇒ Object
string - Source record type.
-
#workspace_id ⇒ Object
int64 - Workspace ID.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ EventRecord
Returns a new instance of EventRecord.
7 8 9 10 |
# File 'lib/files.com/models/event_record.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/event_record.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/event_record.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
113 114 115 |
# File 'lib/files.com/models/event_record.rb', line 113 def self.all(params = {}, = {}) list(params, ) end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Event Record ID.
119 120 121 122 123 124 125 126 127 |
# File 'lib/files.com/models/event_record.rb', line 119 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/event_records/#{params[:id]}", :get, params, ) EventRecord.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
129 130 131 |
# File 'lib/files.com/models/event_record.rb', line 129 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `event_type`, `created_at` or `workspace_id`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at`, `event_type` or `workspace_id`. Valid field combinations are `[ event_type, created_at ]`, `[ workspace_id, created_at ]`, `[ workspace_id, event_type ]` or `[ workspace_id, event_type, created_at ]`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `created_at`.
filter_prefix - object - If set, return records where the specified field is prefixed by the supplied value. Valid fields are `event_type`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `created_at`.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/files.com/models/event_record.rb', line 97 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_prefix must be an Hash") if params[:filter_prefix] and !params[:filter_prefix].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash) List.new(EventRecord, params) do Api.send_request("/event_records", :get, params, ) end end |
Instance Method Details
#actor ⇒ Object
object - Actor associated with the event.
68 69 70 |
# File 'lib/files.com/models/event_record.rb', line 68 def actor @attributes[:actor] end |
#created_at ⇒ Object
date-time - Event Record create date/time.
83 84 85 |
# File 'lib/files.com/models/event_record.rb', line 83 def created_at @attributes[:created_at] end |
#event_type ⇒ Object
string - Versioned event type string.
28 29 30 |
# File 'lib/files.com/models/event_record.rb', line 28 def event_type @attributes[:event_type] end |
#event_uuid ⇒ Object
string - Stable event UUID.
23 24 25 |
# File 'lib/files.com/models/event_record.rb', line 23 def event_uuid @attributes[:event_uuid] end |
#human_fields ⇒ Object
array(object) - Human-readable event detail fields.
63 64 65 |
# File 'lib/files.com/models/event_record.rb', line 63 def human_fields @attributes[:human_fields] end |
#human_summary ⇒ Object
string - Human-readable event summary.
58 59 60 |
# File 'lib/files.com/models/event_record.rb', line 58 def human_summary @attributes[:human_summary] end |
#human_title ⇒ Object
string - Human-readable event title.
53 54 55 |
# File 'lib/files.com/models/event_record.rb', line 53 def human_title @attributes[:human_title] end |
#id ⇒ Object
int64 - Event Record ID
13 14 15 |
# File 'lib/files.com/models/event_record.rb', line 13 def id @attributes[:id] end |
#occurred_at ⇒ Object
date-time - Event occurrence date/time.
48 49 50 |
# File 'lib/files.com/models/event_record.rb', line 48 def occurred_at @attributes[:occurred_at] end |
#payload ⇒ Object
object - Event payload.
78 79 80 |
# File 'lib/files.com/models/event_record.rb', line 78 def payload @attributes[:payload] end |
#resources ⇒ Object
array(object) - Resources associated with the event.
73 74 75 |
# File 'lib/files.com/models/event_record.rb', line 73 def resources @attributes[:resources] end |
#severity ⇒ Object
string - Event severity.
33 34 35 |
# File 'lib/files.com/models/event_record.rb', line 33 def severity @attributes[:severity] end |
#source_id ⇒ Object
int64 - Source record ID.
43 44 45 |
# File 'lib/files.com/models/event_record.rb', line 43 def source_id @attributes[:source_id] end |
#source_type ⇒ Object
string - Source record type.
38 39 40 |
# File 'lib/files.com/models/event_record.rb', line 38 def source_type @attributes[:source_type] end |
#workspace_id ⇒ Object
int64 - Workspace ID. 0 means the default workspace or site-wide.
18 19 20 |
# File 'lib/files.com/models/event_record.rb', line 18 def workspace_id @attributes[:workspace_id] end |