Class: Files::ExternalEvent
- Inherits:
-
Object
- Object
- Files::ExternalEvent
- Defined in:
- lib/files.com/models/external_event.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: status (required) - string - Status of event.
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - External Event ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
Instance Method Summary collapse
-
#body ⇒ Object
string - Event body.
- #body=(value) ⇒ Object
-
#body_url ⇒ Object
string - Link to log file.
- #body_url=(value) ⇒ Object
-
#created_at ⇒ Object
date-time - External event create date/time.
-
#event_type ⇒ Object
string - Type of event being recorded.
- #event_type=(value) ⇒ Object
-
#id ⇒ Object
int64 - Event ID.
- #id=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ ExternalEvent
constructor
A new instance of ExternalEvent.
- #save ⇒ Object
-
#status ⇒ Object
string - Status of event.
- #status=(value) ⇒ Object
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ ExternalEvent
Returns a new instance of ExternalEvent.
7 8 9 10 |
# File 'lib/files.com/models/external_event.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/external_event.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/external_event.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
97 98 99 |
# File 'lib/files.com/models/external_event.rb', line 97 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
status (required) - string - Status of event.
body (required) - string - Event body
120 121 122 123 124 125 126 127 128 |
# File 'lib/files.com/models/external_event.rb', line 120 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: status must be an String") if params[:status] and !params[:status].is_a?(String) raise InvalidParameterError.new("Bad parameter: body must be an String") if params[:body] and !params[:body].is_a?(String) raise MissingParameterError.new("Parameter missing: status") unless params[:status] raise MissingParameterError.new("Parameter missing: body") unless params[:body] response, = Api.send_request("/external_events", :post, params, ) ExternalEvent.new(response.data, ) end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - External Event ID.
103 104 105 106 107 108 109 110 111 |
# File 'lib/files.com/models/external_event.rb', line 103 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/external_events/#{params[:id]}", :get, params, ) ExternalEvent.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
113 114 115 |
# File 'lib/files.com/models/external_event.rb', line 113 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `created_at`, `status` or `event_type`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at` and `status`. Valid field combinations are `[ status, created_at ]`.
filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`.
filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `created_at`.
filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`.
filter_lteq - object - If set, return records where the specified field is less than or equal the supplied value. Valid fields are `created_at`.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/files.com/models/external_event.rb', line 82 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gt must be an Hash") if params[:filter_gt] and !params[:filter_gt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_gteq must be an Hash") if params[:filter_gteq] and !params[:filter_gteq].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lt must be an Hash") if params[:filter_lt] and !params[:filter_lt].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_lteq must be an Hash") if params[:filter_lteq] and !params[:filter_lteq].is_a?(Hash) List.new(ExternalEvent, params) do Api.send_request("/external_events", :get, params, ) end end |
Instance Method Details
#body ⇒ Object
string - Event body
40 41 42 |
# File 'lib/files.com/models/external_event.rb', line 40 def body @attributes[:body] end |
#body=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/external_event.rb', line 44 def body=(value) @attributes[:body] = value end |
#body_url ⇒ Object
string - Link to log file.
54 55 56 |
# File 'lib/files.com/models/external_event.rb', line 54 def body_url @attributes[:body_url] end |
#body_url=(value) ⇒ Object
58 59 60 |
# File 'lib/files.com/models/external_event.rb', line 58 def body_url=(value) @attributes[:body_url] = value end |
#created_at ⇒ Object
date-time - External event create date/time
49 50 51 |
# File 'lib/files.com/models/external_event.rb', line 49 def created_at @attributes[:created_at] end |
#event_type ⇒ Object
string - Type of event being recorded.
22 23 24 |
# File 'lib/files.com/models/external_event.rb', line 22 def event_type @attributes[:event_type] end |
#event_type=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/external_event.rb', line 26 def event_type=(value) @attributes[:event_type] = value end |
#id ⇒ Object
int64 - Event ID
13 14 15 |
# File 'lib/files.com/models/external_event.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/external_event.rb', line 17 def id=(value) @attributes[:id] = value end |
#save ⇒ Object
62 63 64 65 66 67 68 69 70 71 |
# File 'lib/files.com/models/external_event.rb', line 62 def save if @attributes[:id] raise NotImplementedError.new("The ExternalEvent object doesn't support updates.") else new_obj = ExternalEvent.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#status ⇒ Object
string - Status of event.
31 32 33 |
# File 'lib/files.com/models/external_event.rb', line 31 def status @attributes[:status] end |
#status=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/external_event.rb', line 35 def status=(value) @attributes[:status] = value end |