Class: Files::HolidayCalendar
- Inherits:
-
Object
- Object
- Files::HolidayCalendar
- Defined in:
- lib/files.com/models/holiday_calendar.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: name (required) - string - Holiday Calendar name.
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Holiday Calendar ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: name - string - Holiday Calendar name.
Instance Method Summary collapse
-
#created_at ⇒ Object
date-time - Creation time.
-
#definition ⇒ Object
object - Holiday rules for the calendar.
- #definition=(value) ⇒ Object
- #delete(params = {}) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#id ⇒ Object
int64 - Holiday Calendar ID.
- #id=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ HolidayCalendar
constructor
A new instance of HolidayCalendar.
-
#name ⇒ Object
string - Holiday Calendar name.
- #name=(value) ⇒ Object
- #save ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: name - string - Holiday Calendar name.
-
#updated_at ⇒ Object
date-time - Last update time.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ HolidayCalendar
Returns a new instance of HolidayCalendar.
7 8 9 10 |
# File 'lib/files.com/models/holiday_calendar.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/holiday_calendar.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/holiday_calendar.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
102 103 104 |
# File 'lib/files.com/models/holiday_calendar.rb', line 102 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
name (required) - string - Holiday Calendar name.
124 125 126 127 128 129 130 |
# File 'lib/files.com/models/holiday_calendar.rb', line 124 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise MissingParameterError.new("Parameter missing: name") unless params[:name] response, = Api.send_request("/holiday_calendars", :post, params, ) HolidayCalendar.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
145 146 147 148 149 150 151 152 153 |
# File 'lib/files.com/models/holiday_calendar.rb', line 145 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/holiday_calendars/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
155 156 157 158 |
# File 'lib/files.com/models/holiday_calendar.rb', line 155 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Holiday Calendar ID.
108 109 110 111 112 113 114 115 116 |
# File 'lib/files.com/models/holiday_calendar.rb', line 108 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/holiday_calendars/#{params[:id]}", :get, params, ) HolidayCalendar.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
118 119 120 |
# File 'lib/files.com/models/holiday_calendar.rb', line 118 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are .
92 93 94 95 96 97 98 99 100 |
# File 'lib/files.com/models/holiday_calendar.rb', line 92 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) List.new(HolidayCalendar, params) do Api.send_request("/holiday_calendars", :get, params, ) end end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
name - string - Holiday Calendar name.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/files.com/models/holiday_calendar.rb', line 134 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/holiday_calendars/#{params[:id]}", :patch, params, ) HolidayCalendar.new(response.data, ) end |
Instance Method Details
#created_at ⇒ Object
date-time - Creation time.
40 41 42 |
# File 'lib/files.com/models/holiday_calendar.rb', line 40 def created_at @attributes[:created_at] end |
#definition ⇒ Object
object - Holiday rules for the calendar. For more information, refer to the Holiday Calendars section of the Files.com documentation.
31 32 33 |
# File 'lib/files.com/models/holiday_calendar.rb', line 31 def definition @attributes[:definition] end |
#definition=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/holiday_calendar.rb', line 35 def definition=(value) @attributes[:definition] = value end |
#delete(params = {}) ⇒ Object
62 63 64 65 66 67 68 69 70 |
# File 'lib/files.com/models/holiday_calendar.rb', line 62 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/holiday_calendars/#{@attributes[:id]}", :delete, params, @options) end |
#destroy(params = {}) ⇒ Object
72 73 74 75 |
# File 'lib/files.com/models/holiday_calendar.rb', line 72 def destroy(params = {}) delete(params) nil end |
#id ⇒ Object
int64 - Holiday Calendar ID. Use custom_<id> as a scheduled resource's holiday_region.
13 14 15 |
# File 'lib/files.com/models/holiday_calendar.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/holiday_calendar.rb', line 17 def id=(value) @attributes[:id] = value end |
#name ⇒ Object
string - Holiday Calendar name.
22 23 24 |
# File 'lib/files.com/models/holiday_calendar.rb', line 22 def name @attributes[:name] end |
#name=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/holiday_calendar.rb', line 26 def name=(value) @attributes[:name] = value end |
#save ⇒ Object
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/files.com/models/holiday_calendar.rb', line 77 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = HolidayCalendar.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#update(params = {}) ⇒ Object
Parameters:
name - string - Holiday Calendar name.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/files.com/models/holiday_calendar.rb', line 51 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/holiday_calendars/#{@attributes[:id]}", :patch, params, @options) end |
#updated_at ⇒ Object
date-time - Last update time.
45 46 47 |
# File 'lib/files.com/models/holiday_calendar.rb', line 45 def updated_at @attributes[:updated_at] end |