Class: Files::HolidayRegion
- Inherits:
-
Object
- Object
- Files::HolidayRegion
- Defined in:
- lib/files.com/models/holiday_region.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
-
.get_supported(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
Instance Method Summary collapse
-
#code ⇒ Object
string - The code representing a region.
-
#initialize(attributes = {}, options = {}) ⇒ HolidayRegion
constructor
A new instance of HolidayRegion.
-
#name ⇒ Object
string - The name of the region.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ HolidayRegion
Returns a new instance of HolidayRegion.
7 8 9 10 |
# File 'lib/files.com/models/holiday_region.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/holiday_region.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/holiday_region.rb', line 5 def @options end |
Class Method Details
.get_supported(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
25 26 27 28 29 30 31 32 |
# File 'lib/files.com/models/holiday_region.rb', line 25 def self.get_supported(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) List.new(HolidayRegion, params) do Api.send_request("/holiday_regions/supported", :get, params, ) end end |
Instance Method Details
#code ⇒ Object
string - The code representing a region
13 14 15 |
# File 'lib/files.com/models/holiday_region.rb', line 13 def code @attributes[:code] end |
#name ⇒ Object
string - The name of the region
18 19 20 |
# File 'lib/files.com/models/holiday_region.rb', line 18 def name @attributes[:name] end |