Class: Files::Ip
- Inherits:
-
Object
- Object
- Files::Ip
- Defined in:
- lib/files.com/models/ip.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#assigned ⇒ Object
boolean - Flag to signal to other systems to use this config.
-
#custom_domains ⇒ Object
array(object) - Active Custom Domains for the site associated with this IP, with their attached SSL certificate content.
-
#external_ip ⇒ Object
string - Public IP of the server.
-
#ftp_enabled ⇒ Object
boolean.
-
#initialize(attributes = {}, options = {}) ⇒ Ip
constructor
A new instance of Ip.
-
#ip ⇒ Object
string - Private IP of the server.
-
#motd_text ⇒ Object
string - A message to show users when they connect via FTP or SFTP.
-
#motd_use_for_ftp ⇒ Object
boolean - Show message to users connecting via FTP.
-
#motd_use_for_sftp ⇒ Object
boolean - Show message to users connecting via SFTP.
-
#pair_type ⇒ Object
string - Pair type for General Use Public IPs.
-
#sftp_enabled ⇒ Object
boolean.
-
#sftp_host_key_private_key ⇒ Object
string - SFTP Host Key private key if using a custom key.
-
#sftp_host_key_type ⇒ Object
string - Which SFTP host key to use.
-
#site ⇒ Object
SslCertificate - SSL certificate information for the site associated with this IP, if available.
-
#site_id ⇒ Object
int64 - Site Id.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ Ip
Returns a new instance of Ip.
7 8 9 10 |
# File 'lib/files.com/models/ip.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/ip.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/ip.rb', line 5 def @options end |
Instance Method Details
#assigned ⇒ Object
boolean - Flag to signal to other systems to use this config
23 24 25 |
# File 'lib/files.com/models/ip.rb', line 23 def assigned @attributes[:assigned] end |
#custom_domains ⇒ Object
array(object) - Active Custom Domains for the site associated with this IP, with their attached SSL certificate content.
73 74 75 |
# File 'lib/files.com/models/ip.rb', line 73 def custom_domains @attributes[:custom_domains] end |
#external_ip ⇒ Object
string - Public IP of the server.
18 19 20 |
# File 'lib/files.com/models/ip.rb', line 18 def external_ip @attributes[:external_ip] end |
#ftp_enabled ⇒ Object
boolean
33 34 35 |
# File 'lib/files.com/models/ip.rb', line 33 def ftp_enabled @attributes[:ftp_enabled] end |
#ip ⇒ Object
string - Private IP of the server.
13 14 15 |
# File 'lib/files.com/models/ip.rb', line 13 def ip @attributes[:ip] end |
#motd_text ⇒ Object
string - A message to show users when they connect via FTP or SFTP.
58 59 60 |
# File 'lib/files.com/models/ip.rb', line 58 def motd_text @attributes[:motd_text] end |
#motd_use_for_ftp ⇒ Object
boolean - Show message to users connecting via FTP
63 64 65 |
# File 'lib/files.com/models/ip.rb', line 63 def motd_use_for_ftp @attributes[:motd_use_for_ftp] end |
#motd_use_for_sftp ⇒ Object
boolean - Show message to users connecting via SFTP
68 69 70 |
# File 'lib/files.com/models/ip.rb', line 68 def motd_use_for_sftp @attributes[:motd_use_for_sftp] end |
#pair_type ⇒ Object
string - Pair type for General Use Public IPs
78 79 80 |
# File 'lib/files.com/models/ip.rb', line 78 def pair_type @attributes[:pair_type] end |
#sftp_enabled ⇒ Object
boolean
38 39 40 |
# File 'lib/files.com/models/ip.rb', line 38 def sftp_enabled @attributes[:sftp_enabled] end |
#sftp_host_key_private_key ⇒ Object
string - SFTP Host Key private key if using a custom key.
48 49 50 |
# File 'lib/files.com/models/ip.rb', line 48 def sftp_host_key_private_key @attributes[:sftp_host_key_private_key] end |
#sftp_host_key_type ⇒ Object
string - Which SFTP host key to use.
43 44 45 |
# File 'lib/files.com/models/ip.rb', line 43 def sftp_host_key_type @attributes[:sftp_host_key_type] end |
#site ⇒ Object
SslCertificate - SSL certificate information for the site associated with this IP, if available.
28 29 30 |
# File 'lib/files.com/models/ip.rb', line 28 def site @attributes[:site] end |
#site_id ⇒ Object
int64 - Site Id
53 54 55 |
# File 'lib/files.com/models/ip.rb', line 53 def site_id @attributes[:site_id] end |