Class: Files::KeyLifecycleRule
- Inherits:
-
Object
- Object
- Files::KeyLifecycleRule
- Defined in:
- lib/files.com/models/key_lifecycle_rule.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: key_type - string - Key type for which the rule will apply (gpg or ssh).
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Key Lifecycle Rule ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: key_type - string - Key type for which the rule will apply (gpg or ssh).
Instance Method Summary collapse
- #delete(params = {}) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#id ⇒ Object
int64 - Key Lifecycle Rule ID.
- #id=(value) ⇒ Object
-
#inactivity_days ⇒ Object
int64 - Number of days of inactivity before the rule applies.
- #inactivity_days=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ KeyLifecycleRule
constructor
A new instance of KeyLifecycleRule.
-
#key_type ⇒ Object
string - Key type for which the rule will apply (gpg or ssh).
- #key_type=(value) ⇒ Object
-
#name ⇒ Object
string - Key Lifecycle Rule name.
- #name=(value) ⇒ Object
- #save ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: key_type - string - Key type for which the rule will apply (gpg or ssh).
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ KeyLifecycleRule
Returns a new instance of KeyLifecycleRule.
7 8 9 10 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
107 108 109 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 107 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
key_type - string - Key type for which the rule will apply (gpg or ssh).
inactivity_days - int64 - Number of days of inactivity before the rule applies.
name - string - Key Lifecycle Rule name
131 132 133 134 135 136 137 138 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 131 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: key_type must be an String") if params[:key_type] and !params[:key_type].is_a?(String) raise InvalidParameterError.new("Bad parameter: inactivity_days must be an Integer") if params[:inactivity_days] and !params[:inactivity_days].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) response, = Api.send_request("/key_lifecycle_rules", :post, params, ) KeyLifecycleRule.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
157 158 159 160 161 162 163 164 165 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 157 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/key_lifecycle_rules/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
167 168 169 170 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 167 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Key Lifecycle Rule ID.
113 114 115 116 117 118 119 120 121 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 113 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/key_lifecycle_rules/#{params[:id]}", :get, params, ) KeyLifecycleRule.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
123 124 125 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 123 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `key_type`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `key_type`.
96 97 98 99 100 101 102 103 104 105 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 96 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) List.new(KeyLifecycleRule, params) do Api.send_request("/key_lifecycle_rules", :get, params, ) end end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
key_type - string - Key type for which the rule will apply (gpg or ssh).
inactivity_days - int64 - Number of days of inactivity before the rule applies.
name - string - Key Lifecycle Rule name
144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 144 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: key_type must be an String") if params[:key_type] and !params[:key_type].is_a?(String) raise InvalidParameterError.new("Bad parameter: inactivity_days must be an Integer") if params[:inactivity_days] and !params[:inactivity_days].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/key_lifecycle_rules/#{params[:id]}", :patch, params, ) KeyLifecycleRule.new(response.data, ) end |
Instance Method Details
#delete(params = {}) ⇒ Object
65 66 67 68 69 70 71 72 73 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 65 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/key_lifecycle_rules/#{@attributes[:id]}", :delete, params, @options) end |
#destroy(params = {}) ⇒ Object
75 76 77 78 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 75 def destroy(params = {}) delete(params) nil end |
#id ⇒ Object
int64 - Key Lifecycle Rule ID
13 14 15 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 17 def id=(value) @attributes[:id] = value end |
#inactivity_days ⇒ Object
int64 - Number of days of inactivity before the rule applies.
31 32 33 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 31 def inactivity_days @attributes[:inactivity_days] end |
#inactivity_days=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 35 def inactivity_days=(value) @attributes[:inactivity_days] = value end |
#key_type ⇒ Object
string - Key type for which the rule will apply (gpg or ssh).
22 23 24 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 22 def key_type @attributes[:key_type] end |
#key_type=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 26 def key_type=(value) @attributes[:key_type] = value end |
#name ⇒ Object
string - Key Lifecycle Rule name
40 41 42 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 40 def name @attributes[:name] end |
#name=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 44 def name=(value) @attributes[:name] = value end |
#save ⇒ Object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 80 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = KeyLifecycleRule.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#update(params = {}) ⇒ Object
Parameters:
key_type - string - Key type for which the rule will apply (gpg or ssh).
inactivity_days - int64 - Number of days of inactivity before the rule applies.
name - string - Key Lifecycle Rule name
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/files.com/models/key_lifecycle_rule.rb', line 52 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: key_type must be an String") if params[:key_type] and !params[:key_type].is_a?(String) raise InvalidParameterError.new("Bad parameter: inactivity_days must be an Integer") if params[:inactivity_days] and !params[:inactivity_days].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/key_lifecycle_rules/#{@attributes[:id]}", :patch, params, @options) end |