Class: Files::Partner
- Inherits:
-
Object
- Object
- Files::Partner
- Defined in:
- lib/files.com/models/partner.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: allowed_ips - string - A list of allowed IPs for this Partner.
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Partner ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: allowed_ips - string - A list of allowed IPs for this Partner.
Instance Method Summary collapse
-
#allow_bypassing_2fa_policies ⇒ Object
boolean - Allow Partner Admins to change Two-Factor Authentication requirements for Partner Users.
- #allow_bypassing_2fa_policies=(value) ⇒ Object
-
#allow_credential_changes ⇒ Object
boolean - Allow Partner Admins to change or reset credentials for users belonging to this Partner.
- #allow_credential_changes=(value) ⇒ Object
-
#allow_providing_gpg_keys ⇒ Object
boolean - Allow Partner Admins to provide GPG keys.
- #allow_providing_gpg_keys=(value) ⇒ Object
-
#allow_user_creation ⇒ Object
boolean - Allow Partner Admins to create users.
- #allow_user_creation=(value) ⇒ Object
-
#allowed_ips ⇒ Object
string - A list of allowed IPs for this Partner.
- #allowed_ips=(value) ⇒ Object
-
#cc_emails_to_responsible_party ⇒ Object
boolean - When ‘true`, emails sent to Partner users are copied to the responsible User or Group.
- #cc_emails_to_responsible_party=(value) ⇒ Object
- #delete(params = {}) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#id ⇒ Object
int64 - The unique ID of the Partner.
- #id=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ Partner
constructor
A new instance of Partner.
-
#name ⇒ Object
string - The name of the Partner.
- #name=(value) ⇒ Object
-
#notes ⇒ Object
string - Notes about this Partner.
- #notes=(value) ⇒ Object
-
#partner_admin_ids ⇒ Object
array(int64) - Array of User IDs that are Partner Admins for this Partner.
- #partner_admin_ids=(value) ⇒ Object
-
#partnership_role ⇒ Object
string - This site’s role in Partner Site relationships for this Partner.
- #partnership_role=(value) ⇒ Object
-
#responsible_group_id ⇒ Object
int64 - ID of the Group responsible for this Partner.
- #responsible_group_id=(value) ⇒ Object
-
#responsible_user_id ⇒ Object
int64 - ID of the User responsible for this Partner.
- #responsible_user_id=(value) ⇒ Object
-
#root_folder ⇒ Object
string - The root folder path for this Partner.
- #root_folder=(value) ⇒ Object
- #save ⇒ Object
-
#tags ⇒ Object
string - Comma-separated list of Tags for this Partner.
- #tags=(value) ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: allowed_ips - string - A list of allowed IPs for this Partner.
-
#user_ids ⇒ Object
array(int64) - Array of User IDs that belong to this Partner.
- #user_ids=(value) ⇒ Object
-
#workspace_id ⇒ Object
int64 - ID of the Workspace associated with this Partner.
- #workspace_id=(value) ⇒ Object
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ Partner
Returns a new instance of Partner.
7 8 9 10 |
# File 'lib/files.com/models/partner.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/partner.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/partner.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
237 238 239 |
# File 'lib/files.com/models/partner.rb', line 237 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
allowed_ips - string - A list of allowed IPs for this Partner. Newline delimited. Partner User IP access is allowed when the IP matches the Partner, User, or Site allowed IP lists.
allow_bypassing_2fa_policies - boolean - Allow Partner Admins to change Two-Factor Authentication requirements for Partner Users.
allow_credential_changes - boolean - Allow Partner Admins to change or reset credentials for users belonging to this Partner.
allow_providing_gpg_keys - boolean - Allow Partner Admins to provide GPG keys.
allow_user_creation - boolean - Allow Partner Admins to create users.
cc_emails_to_responsible_party - boolean - When `true`, emails sent to Partner users are copied to the responsible User or Group.
notes - string - Notes about this Partner.
responsible_group_id - int64 - ID of the Group responsible for this Partner.
responsible_user_id - int64 - ID of the User responsible for this Partner.
tags - string - Comma-separated list of Tags for this Partner. Tags are used for other features, such as UserLifecycleRules, which can target specific tags. Tags must only contain lowercase letters, numbers, and hyphens.
name (required) - string - The name of the Partner.
root_folder (required) - string - The root folder path for this Partner.
workspace_id - int64 - ID of the Workspace associated with this Partner.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/files.com/models/partner.rb', line 271 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: allowed_ips must be an String") if params[:allowed_ips] and !params[:allowed_ips].is_a?(String) raise InvalidParameterError.new("Bad parameter: notes must be an String") if params[:notes] and !params[:notes].is_a?(String) raise InvalidParameterError.new("Bad parameter: responsible_group_id must be an Integer") if params[:responsible_group_id] and !params[:responsible_group_id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: responsible_user_id must be an Integer") if params[:responsible_user_id] and !params[:responsible_user_id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: tags must be an String") if params[:tags] and !params[:tags].is_a?(String) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: root_folder must be an String") if params[:root_folder] and !params[:root_folder].is_a?(String) raise InvalidParameterError.new("Bad parameter: workspace_id must be an Integer") if params[:workspace_id] and !params[:workspace_id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: name") unless params[:name] raise MissingParameterError.new("Parameter missing: root_folder") unless params[:root_folder] response, = Api.send_request("/partners", :post, params, ) Partner.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
317 318 319 320 321 322 323 324 325 |
# File 'lib/files.com/models/partner.rb', line 317 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/partners/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
327 328 329 330 |
# File 'lib/files.com/models/partner.rb', line 327 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Partner ID.
243 244 245 246 247 248 249 250 251 |
# File 'lib/files.com/models/partner.rb', line 243 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/partners/#{params[:id]}", :get, params, ) Partner.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
253 254 255 |
# File 'lib/files.com/models/partner.rb', line 253 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `workspace_id` and `id`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `workspace_id`.
226 227 228 229 230 231 232 233 234 235 |
# File 'lib/files.com/models/partner.rb', line 226 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) List.new(Partner, params) do Api.send_request("/partners", :get, params, ) end end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
allowed_ips - string - A list of allowed IPs for this Partner. Newline delimited. Partner User IP access is allowed when the IP matches the Partner, User, or Site allowed IP lists.
allow_bypassing_2fa_policies - boolean - Allow Partner Admins to change Two-Factor Authentication requirements for Partner Users.
allow_credential_changes - boolean - Allow Partner Admins to change or reset credentials for users belonging to this Partner.
allow_providing_gpg_keys - boolean - Allow Partner Admins to provide GPG keys.
allow_user_creation - boolean - Allow Partner Admins to create users.
cc_emails_to_responsible_party - boolean - When `true`, emails sent to Partner users are copied to the responsible User or Group.
notes - string - Notes about this Partner.
responsible_group_id - int64 - ID of the Group responsible for this Partner.
responsible_user_id - int64 - ID of the User responsible for this Partner.
tags - string - Comma-separated list of Tags for this Partner. Tags are used for other features, such as UserLifecycleRules, which can target specific tags. Tags must only contain lowercase letters, numbers, and hyphens.
name - string - The name of the Partner.
root_folder - string - The root folder path for this Partner.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/files.com/models/partner.rb', line 300 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: allowed_ips must be an String") if params[:allowed_ips] and !params[:allowed_ips].is_a?(String) raise InvalidParameterError.new("Bad parameter: notes must be an String") if params[:notes] and !params[:notes].is_a?(String) raise InvalidParameterError.new("Bad parameter: responsible_group_id must be an Integer") if params[:responsible_group_id] and !params[:responsible_group_id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: responsible_user_id must be an Integer") if params[:responsible_user_id] and !params[:responsible_user_id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: tags must be an String") if params[:tags] and !params[:tags].is_a?(String) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: root_folder must be an String") if params[:root_folder] and !params[:root_folder].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/partners/#{params[:id]}", :patch, params, ) Partner.new(response.data, ) end |
Instance Method Details
#allow_bypassing_2fa_policies ⇒ Object
boolean - Allow Partner Admins to change Two-Factor Authentication requirements for Partner Users.
13 14 15 |
# File 'lib/files.com/models/partner.rb', line 13 def allow_bypassing_2fa_policies @attributes[:allow_bypassing_2fa_policies] end |
#allow_bypassing_2fa_policies=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/partner.rb', line 17 def allow_bypassing_2fa_policies=(value) @attributes[:allow_bypassing_2fa_policies] = value end |
#allow_credential_changes ⇒ Object
boolean - Allow Partner Admins to change or reset credentials for users belonging to this Partner.
31 32 33 |
# File 'lib/files.com/models/partner.rb', line 31 def allow_credential_changes @attributes[:allow_credential_changes] end |
#allow_credential_changes=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/partner.rb', line 35 def allow_credential_changes=(value) @attributes[:allow_credential_changes] = value end |
#allow_providing_gpg_keys ⇒ Object
boolean - Allow Partner Admins to provide GPG keys.
40 41 42 |
# File 'lib/files.com/models/partner.rb', line 40 def allow_providing_gpg_keys @attributes[:allow_providing_gpg_keys] end |
#allow_providing_gpg_keys=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/partner.rb', line 44 def allow_providing_gpg_keys=(value) @attributes[:allow_providing_gpg_keys] = value end |
#allow_user_creation ⇒ Object
boolean - Allow Partner Admins to create users.
49 50 51 |
# File 'lib/files.com/models/partner.rb', line 49 def allow_user_creation @attributes[:allow_user_creation] end |
#allow_user_creation=(value) ⇒ Object
53 54 55 |
# File 'lib/files.com/models/partner.rb', line 53 def allow_user_creation=(value) @attributes[:allow_user_creation] = value end |
#allowed_ips ⇒ Object
string - A list of allowed IPs for this Partner. Newline delimited. Partner User IP access is allowed when the IP matches the Partner, User, or Site allowed IP lists.
22 23 24 |
# File 'lib/files.com/models/partner.rb', line 22 def allowed_ips @attributes[:allowed_ips] end |
#allowed_ips=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/partner.rb', line 26 def allowed_ips=(value) @attributes[:allowed_ips] = value end |
#cc_emails_to_responsible_party ⇒ Object
boolean - When ‘true`, emails sent to Partner users are copied to the responsible User or Group.
58 59 60 |
# File 'lib/files.com/models/partner.rb', line 58 def cc_emails_to_responsible_party @attributes[:cc_emails_to_responsible_party] end |
#cc_emails_to_responsible_party=(value) ⇒ Object
62 63 64 |
# File 'lib/files.com/models/partner.rb', line 62 def cc_emails_to_responsible_party=(value) @attributes[:cc_emails_to_responsible_party] = value end |
#delete(params = {}) ⇒ Object
195 196 197 198 199 200 201 202 203 |
# File 'lib/files.com/models/partner.rb', line 195 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/partners/#{@attributes[:id]}", :delete, params, @options) end |
#destroy(params = {}) ⇒ Object
205 206 207 208 |
# File 'lib/files.com/models/partner.rb', line 205 def destroy(params = {}) delete(params) nil end |
#id ⇒ Object
int64 - The unique ID of the Partner.
67 68 69 |
# File 'lib/files.com/models/partner.rb', line 67 def id @attributes[:id] end |
#id=(value) ⇒ Object
71 72 73 |
# File 'lib/files.com/models/partner.rb', line 71 def id=(value) @attributes[:id] = value end |
#name ⇒ Object
string - The name of the Partner.
85 86 87 |
# File 'lib/files.com/models/partner.rb', line 85 def name @attributes[:name] end |
#name=(value) ⇒ Object
89 90 91 |
# File 'lib/files.com/models/partner.rb', line 89 def name=(value) @attributes[:name] = value end |
#notes ⇒ Object
string - Notes about this Partner.
94 95 96 |
# File 'lib/files.com/models/partner.rb', line 94 def notes @attributes[:notes] end |
#notes=(value) ⇒ Object
98 99 100 |
# File 'lib/files.com/models/partner.rb', line 98 def notes=(value) @attributes[:notes] = value end |
#partner_admin_ids ⇒ Object
array(int64) - Array of User IDs that are Partner Admins for this Partner.
103 104 105 |
# File 'lib/files.com/models/partner.rb', line 103 def partner_admin_ids @attributes[:partner_admin_ids] end |
#partner_admin_ids=(value) ⇒ Object
107 108 109 |
# File 'lib/files.com/models/partner.rb', line 107 def partner_admin_ids=(value) @attributes[:partner_admin_ids] = value end |
#partnership_role ⇒ Object
string - This site’s role in Partner Site relationships for this Partner. Can be ‘host`, `guest`, `host_and_guest`, or null.
112 113 114 |
# File 'lib/files.com/models/partner.rb', line 112 def partnership_role @attributes[:partnership_role] end |
#partnership_role=(value) ⇒ Object
116 117 118 |
# File 'lib/files.com/models/partner.rb', line 116 def partnership_role=(value) @attributes[:partnership_role] = value end |
#responsible_group_id ⇒ Object
int64 - ID of the Group responsible for this Partner.
121 122 123 |
# File 'lib/files.com/models/partner.rb', line 121 def responsible_group_id @attributes[:responsible_group_id] end |
#responsible_group_id=(value) ⇒ Object
125 126 127 |
# File 'lib/files.com/models/partner.rb', line 125 def responsible_group_id=(value) @attributes[:responsible_group_id] = value end |
#responsible_user_id ⇒ Object
int64 - ID of the User responsible for this Partner.
130 131 132 |
# File 'lib/files.com/models/partner.rb', line 130 def responsible_user_id @attributes[:responsible_user_id] end |
#responsible_user_id=(value) ⇒ Object
134 135 136 |
# File 'lib/files.com/models/partner.rb', line 134 def responsible_user_id=(value) @attributes[:responsible_user_id] = value end |
#root_folder ⇒ Object
string - The root folder path for this Partner.
139 140 141 |
# File 'lib/files.com/models/partner.rb', line 139 def root_folder @attributes[:root_folder] end |
#root_folder=(value) ⇒ Object
143 144 145 |
# File 'lib/files.com/models/partner.rb', line 143 def root_folder=(value) @attributes[:root_folder] = value end |
#save ⇒ Object
210 211 212 213 214 215 216 217 218 219 |
# File 'lib/files.com/models/partner.rb', line 210 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = Partner.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#tags ⇒ Object
string - Comma-separated list of Tags for this Partner. Tags are used for other features, such as UserLifecycleRules, which can target specific tags. Tags must only contain lowercase letters, numbers, and hyphens.
148 149 150 |
# File 'lib/files.com/models/partner.rb', line 148 def @attributes[:tags] end |
#tags=(value) ⇒ Object
152 153 154 |
# File 'lib/files.com/models/partner.rb', line 152 def (value) @attributes[:tags] = value end |
#update(params = {}) ⇒ Object
Parameters:
allowed_ips - string - A list of allowed IPs for this Partner. Newline delimited. Partner User IP access is allowed when the IP matches the Partner, User, or Site allowed IP lists.
allow_bypassing_2fa_policies - boolean - Allow Partner Admins to change Two-Factor Authentication requirements for Partner Users.
allow_credential_changes - boolean - Allow Partner Admins to change or reset credentials for users belonging to this Partner.
allow_providing_gpg_keys - boolean - Allow Partner Admins to provide GPG keys.
allow_user_creation - boolean - Allow Partner Admins to create users.
cc_emails_to_responsible_party - boolean - When `true`, emails sent to Partner users are copied to the responsible User or Group.
notes - string - Notes about this Partner.
responsible_group_id - int64 - ID of the Group responsible for this Partner.
responsible_user_id - int64 - ID of the User responsible for this Partner.
tags - string - Comma-separated list of Tags for this Partner. Tags are used for other features, such as UserLifecycleRules, which can target specific tags. Tags must only contain lowercase letters, numbers, and hyphens.
name - string - The name of the Partner.
root_folder - string - The root folder path for this Partner.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/files.com/models/partner.rb', line 178 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: allowed_ips must be an String") if params[:allowed_ips] and !params[:allowed_ips].is_a?(String) raise InvalidParameterError.new("Bad parameter: notes must be an String") if params[:notes] and !params[:notes].is_a?(String) raise InvalidParameterError.new("Bad parameter: responsible_group_id must be an Integer") if params[:responsible_group_id] and !params[:responsible_group_id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: responsible_user_id must be an Integer") if params[:responsible_user_id] and !params[:responsible_user_id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: tags must be an String") if params[:tags] and !params[:tags].is_a?(String) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise InvalidParameterError.new("Bad parameter: root_folder must be an String") if params[:root_folder] and !params[:root_folder].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/partners/#{@attributes[:id]}", :patch, params, @options) end |
#user_ids ⇒ Object
array(int64) - Array of User IDs that belong to this Partner.
157 158 159 |
# File 'lib/files.com/models/partner.rb', line 157 def user_ids @attributes[:user_ids] end |
#user_ids=(value) ⇒ Object
161 162 163 |
# File 'lib/files.com/models/partner.rb', line 161 def user_ids=(value) @attributes[:user_ids] = value end |
#workspace_id ⇒ Object
int64 - ID of the Workspace associated with this Partner.
76 77 78 |
# File 'lib/files.com/models/partner.rb', line 76 def workspace_id @attributes[:workspace_id] end |
#workspace_id=(value) ⇒ Object
80 81 82 |
# File 'lib/files.com/models/partner.rb', line 80 def workspace_id=(value) @attributes[:workspace_id] = value end |