Class: Files::PartnerSite

Inherits:
Object
  • Object
show all
Defined in:
lib/files.com/models/partner_site.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}, options = {}) ⇒ PartnerSite

Returns a new instance of PartnerSite.



7
8
9
10
# File 'lib/files.com/models/partner_site.rb', line 7

def initialize(attributes = {}, options = {})
  @attributes = attributes || {}
  @options = options || {}
end

Instance Attribute Details

#attributesObject (readonly)

Returns the value of attribute attributes.



5
6
7
# File 'lib/files.com/models/partner_site.rb', line 5

def attributes
  @attributes
end

#optionsObject (readonly)

Returns the value of attribute options.



5
6
7
# File 'lib/files.com/models/partner_site.rb', line 5

def options
  @options
end

Class Method Details

.all(params = {}, options = {}) ⇒ Object



61
62
63
# File 'lib/files.com/models/partner_site.rb', line 61

def self.all(params = {}, options = {})
  list(params, options)
end

.linkeds(params = {}, options = {}) ⇒ Object



42
43
44
45
46
47
# File 'lib/files.com/models/partner_site.rb', line 42

def self.linkeds(params = {}, options = {})
  response, options = Api.send_request("/partner_sites/linked_partner_sites", :get, params, options)
  response.data.map do |entity_data|
    PartnerSite.new(entity_data, options)
  end
end

.list(params = {}, options = {}) ⇒ Object

Parameters:

cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).


52
53
54
55
56
57
58
59
# File 'lib/files.com/models/partner_site.rb', line 52

def self.list(params = {}, options = {})
  raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String)
  raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer)

  List.new(PartnerSite, params) do
    Api.send_request("/partner_sites", :get, params, options)
  end
end

Instance Method Details

#linked_site_idObject

int64 - Linked Site ID



23
24
25
# File 'lib/files.com/models/partner_site.rb', line 23

def linked_site_id
  @attributes[:linked_site_id]
end

#linked_site_nameObject

string - Linked Site Name



28
29
30
# File 'lib/files.com/models/partner_site.rb', line 28

def linked_site_name
  @attributes[:linked_site_name]
end

#main_site_idObject

int64 - Main Site ID



33
34
35
# File 'lib/files.com/models/partner_site.rb', line 33

def main_site_id
  @attributes[:main_site_id]
end

#main_site_nameObject

string - Main Site Name



38
39
40
# File 'lib/files.com/models/partner_site.rb', line 38

def main_site_name
  @attributes[:main_site_name]
end

#partner_idObject

int64 - Partner ID



13
14
15
# File 'lib/files.com/models/partner_site.rb', line 13

def partner_id
  @attributes[:partner_id]
end

#partner_nameObject

string - Partner Name



18
19
20
# File 'lib/files.com/models/partner_site.rb', line 18

def partner_name
  @attributes[:partner_name]
end