Class: Files::SslCertificate
- Inherits:
-
Object
- Object
- Files::SslCertificate
- Defined in:
- lib/files.com/models/ssl_certificate.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#certificate ⇒ Object
string - The text of the certificate itself.
-
#domain_hsts_header ⇒ Object
boolean - True if a HSTS header should be rendered for the site.
-
#domains ⇒ Object
array(string) - Domains associated with this certificate.
-
#ftps_enabled ⇒ Object
boolean - Whether or not this certificate can be used for FTPS.
-
#https_enabled ⇒ Object
boolean - Whether or not this certificate can be used for HTTPS.
-
#id ⇒ Object
int64 - ID of the site associated with this certificate, including group id if available.
-
#initialize(attributes = {}, options = {}) ⇒ SslCertificate
constructor
A new instance of SslCertificate.
-
#intermediates ⇒ Object
string - Intermediate certificates, if available.
-
#key ⇒ Object
object - Private key encrypted with our secret key.
-
#name ⇒ Object
string - The name of the site associated with this SSL certificate.
-
#private_key ⇒ Object
string - Private key used to generate the certificate.
-
#sftp_insecure_ciphers ⇒ Object
boolean - True if the site associated with this certificate has the "Allow Insecure SFTP Ciphers" feature turned on.
-
#subdomain ⇒ Object
string - Site subdomain.
-
#tls_disabled ⇒ Object
boolean - True if the site associated with this certificate has the "Security Opt Out" feature turned on.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ SslCertificate
Returns a new instance of SslCertificate.
7 8 9 10 |
# File 'lib/files.com/models/ssl_certificate.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/ssl_certificate.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/ssl_certificate.rb', line 5 def @options end |
Instance Method Details
#certificate ⇒ Object
string - The text of the certificate itself.
18 19 20 |
# File 'lib/files.com/models/ssl_certificate.rb', line 18 def certificate @attributes[:certificate] end |
#domain_hsts_header ⇒ Object
boolean - True if a HSTS header should be rendered for the site
43 44 45 |
# File 'lib/files.com/models/ssl_certificate.rb', line 43 def domain_hsts_header @attributes[:domain_hsts_header] end |
#domains ⇒ Object
array(string) - Domains associated with this certificate.
73 74 75 |
# File 'lib/files.com/models/ssl_certificate.rb', line 73 def domains @attributes[:domains] end |
#ftps_enabled ⇒ Object
boolean - Whether or not this certificate can be used for FTPS.
48 49 50 |
# File 'lib/files.com/models/ssl_certificate.rb', line 48 def ftps_enabled @attributes[:ftps_enabled] end |
#https_enabled ⇒ Object
boolean - Whether or not this certificate can be used for HTTPS. Always true.
53 54 55 |
# File 'lib/files.com/models/ssl_certificate.rb', line 53 def https_enabled @attributes[:https_enabled] end |
#id ⇒ Object
int64 - ID of the site associated with this certificate, including group id if available.
38 39 40 |
# File 'lib/files.com/models/ssl_certificate.rb', line 38 def id @attributes[:id] end |
#intermediates ⇒ Object
string - Intermediate certificates, if available.
33 34 35 |
# File 'lib/files.com/models/ssl_certificate.rb', line 33 def intermediates @attributes[:intermediates] end |
#key ⇒ Object
object - Private key encrypted with our secret key.
28 29 30 |
# File 'lib/files.com/models/ssl_certificate.rb', line 28 def key @attributes[:key] end |
#name ⇒ Object
string - The name of the site associated with this SSL certificate.
13 14 15 |
# File 'lib/files.com/models/ssl_certificate.rb', line 13 def name @attributes[:name] end |
#private_key ⇒ Object
string - Private key used to generate the certificate.
23 24 25 |
# File 'lib/files.com/models/ssl_certificate.rb', line 23 def private_key @attributes[:private_key] end |
#sftp_insecure_ciphers ⇒ Object
boolean - True if the site associated with this certificate has the "Allow Insecure SFTP Ciphers" feature turned on.
58 59 60 |
# File 'lib/files.com/models/ssl_certificate.rb', line 58 def sftp_insecure_ciphers @attributes[:sftp_insecure_ciphers] end |
#subdomain ⇒ Object
string - Site subdomain.
68 69 70 |
# File 'lib/files.com/models/ssl_certificate.rb', line 68 def subdomain @attributes[:subdomain] end |
#tls_disabled ⇒ Object
boolean - True if the site associated with this certificate has the "Security Opt Out" feature turned on.
63 64 65 |
# File 'lib/files.com/models/ssl_certificate.rb', line 63 def tls_disabled @attributes[:tls_disabled] end |