Class: Files::SyncApiUsageSnapshotReport
- Inherits:
-
Object
- Object
- Files::SyncApiUsageSnapshotReport
- Defined in:
- lib/files.com/models/sync_api_usage_snapshot_report.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
-
.create(params = {}, options = {}) ⇒ Object
Parameters: start_time - string - start time of statistics collection end_time - string - end time of statistics collection uuid - string - Unique ID for this entry auth_cache_hits - int64 - Numbers of hits of the authentication cache auth_cache_misses - int64 - Numbers of misses of the authentication cache auth_api_requests_for_sftp - int64 - A count of api authentications requests for SFTP auth_api_requests_for_ftp - int64 - A count of api authentications requests for FTP auth_api_requests_for_dav - int64 - A count of api authentications requests for DAV auth_api_requests_for_desktop - int64 - A count of api authentications requests for Desktop auth_api_requests_for_restapi - int64 - A count of api authentications requests for Restapi number_of_sync_api_usage_snapshots - int64 - A count of the number of api usage logs sync_api_usage_snapshots - array(object).
Instance Method Summary collapse
-
#auth_api_requests_for_dav ⇒ Object
int64 - A count of api authentications requests for DAV.
- #auth_api_requests_for_dav=(value) ⇒ Object
-
#auth_api_requests_for_desktop ⇒ Object
int64 - A count of api authentications requests for Desktop.
- #auth_api_requests_for_desktop=(value) ⇒ Object
-
#auth_api_requests_for_ftp ⇒ Object
int64 - A count of api authentications requests for FTP.
- #auth_api_requests_for_ftp=(value) ⇒ Object
-
#auth_api_requests_for_restapi ⇒ Object
int64 - A count of api authentications requests for Restapi.
- #auth_api_requests_for_restapi=(value) ⇒ Object
-
#auth_api_requests_for_sftp ⇒ Object
int64 - A count of api authentications requests for SFTP.
- #auth_api_requests_for_sftp=(value) ⇒ Object
-
#auth_cache_hits ⇒ Object
int64 - Numbers of hits of the authentication cache.
- #auth_cache_hits=(value) ⇒ Object
-
#auth_cache_misses ⇒ Object
int64 - Numbers of misses of the authentication cache.
- #auth_cache_misses=(value) ⇒ Object
-
#end_time ⇒ Object
date-time - end time of statistics collection.
- #end_time=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ SyncApiUsageSnapshotReport
constructor
A new instance of SyncApiUsageSnapshotReport.
-
#number_of_sync_api_usage_snapshots ⇒ Object
int64 - A count of the number of api usage logs.
- #number_of_sync_api_usage_snapshots=(value) ⇒ Object
- #save ⇒ Object
-
#start_time ⇒ Object
date-time - start time of statistics collection.
- #start_time=(value) ⇒ Object
-
#sync_api_usage_snapshots ⇒ Object
array(object) - A list of all the api usage logs.
- #sync_api_usage_snapshots=(value) ⇒ Object
-
#uuid ⇒ Object
string - Unique ID for this entry.
- #uuid=(value) ⇒ Object
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ SyncApiUsageSnapshotReport
Returns a new instance of SyncApiUsageSnapshotReport.
7 8 9 10 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 5 def @options end |
Class Method Details
.create(params = {}, options = {}) ⇒ Object
Parameters:
start_time - string - start time of statistics collection
end_time - string - end time of statistics collection
uuid - string - Unique ID for this entry
auth_cache_hits - int64 - Numbers of hits of the authentication cache
auth_cache_misses - int64 - Numbers of misses of the authentication cache
auth_api_requests_for_sftp - int64 - A count of api authentications requests for SFTP
auth_api_requests_for_ftp - int64 - A count of api authentications requests for FTP
auth_api_requests_for_dav - int64 - A count of api authentications requests for DAV
auth_api_requests_for_desktop - int64 - A count of api authentications requests for Desktop
auth_api_requests_for_restapi - int64 - A count of api authentications requests for Restapi
number_of_sync_api_usage_snapshots - int64 - A count of the number of api usage logs
sync_api_usage_snapshots - array(object)
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 144 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: start_time must be an String") if params[:start_time] and !params[:start_time].is_a?(String) raise InvalidParameterError.new("Bad parameter: end_time must be an String") if params[:end_time] and !params[:end_time].is_a?(String) raise InvalidParameterError.new("Bad parameter: uuid must be an String") if params[:uuid] and !params[:uuid].is_a?(String) raise InvalidParameterError.new("Bad parameter: auth_cache_hits must be an Integer") if params[:auth_cache_hits] and !params[:auth_cache_hits].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: auth_cache_misses must be an Integer") if params[:auth_cache_misses] and !params[:auth_cache_misses].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: auth_api_requests_for_sftp must be an Integer") if params[:auth_api_requests_for_sftp] and !params[:auth_api_requests_for_sftp].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: auth_api_requests_for_ftp must be an Integer") if params[:auth_api_requests_for_ftp] and !params[:auth_api_requests_for_ftp].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: auth_api_requests_for_dav must be an Integer") if params[:auth_api_requests_for_dav] and !params[:auth_api_requests_for_dav].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: auth_api_requests_for_desktop must be an Integer") if params[:auth_api_requests_for_desktop] and !params[:auth_api_requests_for_desktop].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: auth_api_requests_for_restapi must be an Integer") if params[:auth_api_requests_for_restapi] and !params[:auth_api_requests_for_restapi].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: number_of_sync_api_usage_snapshots must be an Integer") if params[:number_of_sync_api_usage_snapshots] and !params[:number_of_sync_api_usage_snapshots].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sync_api_usage_snapshots must be an Array") if params[:sync_api_usage_snapshots] and !params[:sync_api_usage_snapshots].is_a?(Array) response, = Api.send_request("/sync_api_usage_snapshot_reports", :post, params, ) SyncApiUsageSnapshotReport.new(response.data, ) end |
Instance Method Details
#auth_api_requests_for_dav ⇒ Object
int64 - A count of api authentications requests for DAV
76 77 78 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 76 def auth_api_requests_for_dav @attributes[:auth_api_requests_for_dav] end |
#auth_api_requests_for_dav=(value) ⇒ Object
80 81 82 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 80 def auth_api_requests_for_dav=(value) @attributes[:auth_api_requests_for_dav] = value end |
#auth_api_requests_for_desktop ⇒ Object
int64 - A count of api authentications requests for Desktop
85 86 87 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 85 def auth_api_requests_for_desktop @attributes[:auth_api_requests_for_desktop] end |
#auth_api_requests_for_desktop=(value) ⇒ Object
89 90 91 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 89 def auth_api_requests_for_desktop=(value) @attributes[:auth_api_requests_for_desktop] = value end |
#auth_api_requests_for_ftp ⇒ Object
int64 - A count of api authentications requests for FTP
67 68 69 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 67 def auth_api_requests_for_ftp @attributes[:auth_api_requests_for_ftp] end |
#auth_api_requests_for_ftp=(value) ⇒ Object
71 72 73 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 71 def auth_api_requests_for_ftp=(value) @attributes[:auth_api_requests_for_ftp] = value end |
#auth_api_requests_for_restapi ⇒ Object
int64 - A count of api authentications requests for Restapi
94 95 96 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 94 def auth_api_requests_for_restapi @attributes[:auth_api_requests_for_restapi] end |
#auth_api_requests_for_restapi=(value) ⇒ Object
98 99 100 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 98 def auth_api_requests_for_restapi=(value) @attributes[:auth_api_requests_for_restapi] = value end |
#auth_api_requests_for_sftp ⇒ Object
int64 - A count of api authentications requests for SFTP
58 59 60 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 58 def auth_api_requests_for_sftp @attributes[:auth_api_requests_for_sftp] end |
#auth_api_requests_for_sftp=(value) ⇒ Object
62 63 64 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 62 def auth_api_requests_for_sftp=(value) @attributes[:auth_api_requests_for_sftp] = value end |
#auth_cache_hits ⇒ Object
int64 - Numbers of hits of the authentication cache
40 41 42 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 40 def auth_cache_hits @attributes[:auth_cache_hits] end |
#auth_cache_hits=(value) ⇒ Object
44 45 46 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 44 def auth_cache_hits=(value) @attributes[:auth_cache_hits] = value end |
#auth_cache_misses ⇒ Object
int64 - Numbers of misses of the authentication cache
49 50 51 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 49 def auth_cache_misses @attributes[:auth_cache_misses] end |
#auth_cache_misses=(value) ⇒ Object
53 54 55 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 53 def auth_cache_misses=(value) @attributes[:auth_cache_misses] = value end |
#end_time ⇒ Object
date-time - end time of statistics collection
22 23 24 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 22 def end_time @attributes[:end_time] end |
#end_time=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 26 def end_time=(value) @attributes[:end_time] = value end |
#number_of_sync_api_usage_snapshots ⇒ Object
int64 - A count of the number of api usage logs
103 104 105 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 103 def number_of_sync_api_usage_snapshots @attributes[:number_of_sync_api_usage_snapshots] end |
#number_of_sync_api_usage_snapshots=(value) ⇒ Object
107 108 109 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 107 def number_of_sync_api_usage_snapshots=(value) @attributes[:number_of_sync_api_usage_snapshots] = value end |
#save ⇒ Object
120 121 122 123 124 125 126 127 128 129 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 120 def save if @attributes[:id] raise NotImplementedError.new("The SyncApiUsageSnapshotReport object doesn't support updates.") else new_obj = SyncApiUsageSnapshotReport.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#start_time ⇒ Object
date-time - start time of statistics collection
13 14 15 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 13 def start_time @attributes[:start_time] end |
#start_time=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 17 def start_time=(value) @attributes[:start_time] = value end |
#sync_api_usage_snapshots ⇒ Object
array(object) - A list of all the api usage logs
112 113 114 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 112 def sync_api_usage_snapshots @attributes[:sync_api_usage_snapshots] end |
#sync_api_usage_snapshots=(value) ⇒ Object
116 117 118 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 116 def sync_api_usage_snapshots=(value) @attributes[:sync_api_usage_snapshots] = value end |
#uuid ⇒ Object
string - Unique ID for this entry
31 32 33 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 31 def uuid @attributes[:uuid] end |
#uuid=(value) ⇒ Object
35 36 37 |
# File 'lib/files.com/models/sync_api_usage_snapshot_report.rb', line 35 def uuid=(value) @attributes[:uuid] = value end |