Class: Files::Warning
- Inherits:
-
Object
- Object
- Files::Warning
- Defined in:
- lib/files.com/models/warning.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
- .create_export(params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
Instance Method Summary collapse
-
#initialize(attributes = {}, options = {}) ⇒ Warning
constructor
A new instance of Warning.
-
#warnings ⇒ Object
array(object) - A list of warnings.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ Warning
Returns a new instance of Warning.
7 8 9 10 |
# File 'lib/files.com/models/warning.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/warning.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/warning.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
29 30 31 |
# File 'lib/files.com/models/warning.rb', line 29 def self.all(params = {}, = {}) list(params, ) end |
.create_export(params = {}, options = {}) ⇒ Object
33 34 35 36 |
# File 'lib/files.com/models/warning.rb', line 33 def self.create_export(params = {}, = {}) response, = Api.send_request("/warnings/create_export", :post, params, ) Export.new(response.data, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10000, 1,000 or less is recommended).
20 21 22 23 24 25 26 27 |
# File 'lib/files.com/models/warning.rb', line 20 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) List.new(Warning, params) do Api.send_request("/warnings", :get, params, ) end end |
Instance Method Details
#warnings ⇒ Object
array(object) - A list of warnings
13 14 15 |
# File 'lib/files.com/models/warning.rb', line 13 def warnings @attributes[:warnings] end |