Class: Files::Workspace
- Inherits:
-
Object
- Object
- Files::Workspace
- Defined in:
- lib/files.com/models/workspace.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Returns the value of attribute attributes.
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Class Method Summary collapse
- .all(params = {}, options = {}) ⇒ Object
-
.create(params = {}, options = {}) ⇒ Object
Parameters: name - string - Workspace name.
- .delete(id, params = {}, options = {}) ⇒ Object
- .destroy(id, params = {}, options = {}) ⇒ Object
-
.find(id, params = {}, options = {}) ⇒ Object
Parameters: id (required) - int64 - Workspace ID.
- .get(id, params = {}, options = {}) ⇒ Object
-
.list(params = {}, options = {}) ⇒ Object
Parameters: cursor - string - Used for pagination.
-
.update(id, params = {}, options = {}) ⇒ Object
Parameters: name - string - Workspace name.
Instance Method Summary collapse
- #delete(params = {}) ⇒ Object
- #destroy(params = {}) ⇒ Object
-
#id ⇒ Object
int64 - Workspace ID.
- #id=(value) ⇒ Object
-
#initialize(attributes = {}, options = {}) ⇒ Workspace
constructor
A new instance of Workspace.
-
#name ⇒ Object
string - Workspace name.
- #name=(value) ⇒ Object
- #save ⇒ Object
-
#update(params = {}) ⇒ Object
Parameters: name - string - Workspace name.
Constructor Details
#initialize(attributes = {}, options = {}) ⇒ Workspace
Returns a new instance of Workspace.
7 8 9 10 |
# File 'lib/files.com/models/workspace.rb', line 7 def initialize(attributes = {}, = {}) @attributes = attributes || {} @options = || {} end |
Instance Attribute Details
#attributes ⇒ Object (readonly)
Returns the value of attribute attributes.
5 6 7 |
# File 'lib/files.com/models/workspace.rb', line 5 def attributes @attributes end |
#options ⇒ Object (readonly)
Returns the value of attribute options.
5 6 7 |
# File 'lib/files.com/models/workspace.rb', line 5 def @options end |
Class Method Details
.all(params = {}, options = {}) ⇒ Object
87 88 89 |
# File 'lib/files.com/models/workspace.rb', line 87 def self.all(params = {}, = {}) list(params, ) end |
.create(params = {}, options = {}) ⇒ Object
Parameters:
name - string - Workspace name
109 110 111 112 113 114 |
# File 'lib/files.com/models/workspace.rb', line 109 def self.create(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) response, = Api.send_request("/workspaces", :post, params, ) Workspace.new(response.data, ) end |
.delete(id, params = {}, options = {}) ⇒ Object
129 130 131 132 133 134 135 136 137 |
# File 'lib/files.com/models/workspace.rb', line 129 def self.delete(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/workspaces/#{params[:id]}", :delete, params, ) nil end |
.destroy(id, params = {}, options = {}) ⇒ Object
139 140 141 142 |
# File 'lib/files.com/models/workspace.rb', line 139 def self.destroy(id, params = {}, = {}) delete(id, params, ) nil end |
.find(id, params = {}, options = {}) ⇒ Object
Parameters:
id (required) - int64 - Workspace ID.
93 94 95 96 97 98 99 100 101 |
# File 'lib/files.com/models/workspace.rb', line 93 def self.find(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/workspaces/#{params[:id]}", :get, params, ) Workspace.new(response.data, ) end |
.get(id, params = {}, options = {}) ⇒ Object
103 104 105 |
# File 'lib/files.com/models/workspace.rb', line 103 def self.get(id, params = {}, = {}) find(id, params, ) end |
.list(params = {}, options = {}) ⇒ Object
Parameters:
cursor - string - Used for pagination. When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`. Send one of those cursor value here to resume an existing list from the next available record. Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
per_page - int64 - Number of records to show per page. (Max: 10,000, 1,000 or less is recommended).
sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `name`.
filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `name`.
filter_prefix - object - If set, return records where the specified field is prefixed by the supplied value. Valid fields are `name`.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/files.com/models/workspace.rb', line 75 def self.list(params = {}, = {}) raise InvalidParameterError.new("Bad parameter: cursor must be an String") if params[:cursor] and !params[:cursor].is_a?(String) raise InvalidParameterError.new("Bad parameter: per_page must be an Integer") if params[:per_page] and !params[:per_page].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: sort_by must be an Hash") if params[:sort_by] and !params[:sort_by].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter must be an Hash") if params[:filter] and !params[:filter].is_a?(Hash) raise InvalidParameterError.new("Bad parameter: filter_prefix must be an Hash") if params[:filter_prefix] and !params[:filter_prefix].is_a?(Hash) List.new(Workspace, params) do Api.send_request("/workspaces", :get, params, ) end end |
.update(id, params = {}, options = {}) ⇒ Object
Parameters:
name - string - Workspace name
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/files.com/models/workspace.rb', line 118 def self.update(id, params = {}, = {}) params ||= {} params[:id] = id raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] response, = Api.send_request("/workspaces/#{params[:id]}", :patch, params, ) Workspace.new(response.data, ) end |
Instance Method Details
#delete(params = {}) ⇒ Object
43 44 45 46 47 48 49 50 51 |
# File 'lib/files.com/models/workspace.rb', line 43 def delete(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/workspaces/#{@attributes[:id]}", :delete, params, @options) end |
#destroy(params = {}) ⇒ Object
53 54 55 56 |
# File 'lib/files.com/models/workspace.rb', line 53 def destroy(params = {}) delete(params) nil end |
#id ⇒ Object
int64 - Workspace ID
13 14 15 |
# File 'lib/files.com/models/workspace.rb', line 13 def id @attributes[:id] end |
#id=(value) ⇒ Object
17 18 19 |
# File 'lib/files.com/models/workspace.rb', line 17 def id=(value) @attributes[:id] = value end |
#name ⇒ Object
string - Workspace name
22 23 24 |
# File 'lib/files.com/models/workspace.rb', line 22 def name @attributes[:name] end |
#name=(value) ⇒ Object
26 27 28 |
# File 'lib/files.com/models/workspace.rb', line 26 def name=(value) @attributes[:name] = value end |
#save ⇒ Object
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/files.com/models/workspace.rb', line 58 def save if @attributes[:id] new_obj = update(@attributes) else new_obj = Workspace.create(@attributes, @options) end @attributes = new_obj.attributes true end |
#update(params = {}) ⇒ Object
Parameters:
name - string - Workspace name
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/files.com/models/workspace.rb', line 32 def update(params = {}) params ||= {} params[:id] = @attributes[:id] raise MissingParameterError.new("Current object doesn't have a id") unless @attributes[:id] raise InvalidParameterError.new("Bad parameter: id must be an Integer") if params[:id] and !params[:id].is_a?(Integer) raise InvalidParameterError.new("Bad parameter: name must be an String") if params[:name] and !params[:name].is_a?(String) raise MissingParameterError.new("Parameter missing: id") unless params[:id] Api.send_request("/workspaces/#{@attributes[:id]}", :patch, params, @options) end |